Class: Google::Apis::RunV1::ConfigurationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ConfigurationSpec holds the desired state of the Configuration (from the client).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigurationSpec

Returns a new instance of ConfigurationSpec.



486
487
488
# File 'lib/google/apis/run_v1/classes.rb', line 486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#templateGoogle::Apis::RunV1::RevisionTemplate

RevisionTemplateSpec describes the data a revision should have when created from a template. Corresponds to the JSON property template



484
485
486
# File 'lib/google/apis/run_v1/classes.rb', line 484

def template
  @template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



491
492
493
# File 'lib/google/apis/run_v1/classes.rb', line 491

def update!(**args)
  @template = args[:template] if args.key?(:template)
end