Class: Google::Apis::RunV1::ConfigurationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ConfigurationStatus communicates the observed state of the Configuration (from the controller).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigurationStatus

Returns a new instance of ConfigurationStatus.



529
530
531
# File 'lib/google/apis/run_v1/classes.rb', line 529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. Corresponds to the JSON property conditions



505
506
507
# File 'lib/google/apis/run_v1/classes.rb', line 505

def conditions
  @conditions
end

#latest_created_revision_nameString

LatestCreatedRevisionName is the last revision that was created from this Configuration. It might not be ready yet, so for the latest ready revision, use LatestReadyRevisionName. Corresponds to the JSON property latestCreatedRevisionName

Returns:

  • (String)


512
513
514
# File 'lib/google/apis/run_v1/classes.rb', line 512

def latest_created_revision_name
  @latest_created_revision_name
end

#latest_ready_revision_nameString

LatestReadyRevisionName holds the name of the latest Revision stamped out from this Configuration that has had its "Ready" condition become "True". Corresponds to the JSON property latestReadyRevisionName

Returns:

  • (String)


518
519
520
# File 'lib/google/apis/run_v1/classes.rb', line 518

def latest_ready_revision_name
  @latest_ready_revision_name
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the Configuration that was last processed by the controller. The observed generation is updated even if the controller failed to process the spec and create the Revision. Clients polling for completed reconciliation should poll until observedGeneration = metadata. generation, and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


527
528
529
# File 'lib/google/apis/run_v1/classes.rb', line 527

def observed_generation
  @observed_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



534
535
536
537
538
539
# File 'lib/google/apis/run_v1/classes.rb', line 534

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name)
  @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
end