Class: Google::Apis::RunV1::ContainerOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Per container override specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerOverride

Returns a new instance of ContainerOverride.



719
720
721
# File 'lib/google/apis/run_v1/classes.rb', line 719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Arguments to the entrypoint. The specified arguments replace and override any existing entrypoint arguments. Must be empty if clear_args is set to true. Corresponds to the JSON property args

Returns:

  • (Array<String>)


698
699
700
# File 'lib/google/apis/run_v1/classes.rb', line 698

def args
  @args
end

#clear_argsBoolean Also known as: clear_args?

Optional. Set to True to clear all existing arguments. Corresponds to the JSON property clearArgs

Returns:

  • (Boolean)


703
704
705
# File 'lib/google/apis/run_v1/classes.rb', line 703

def clear_args
  @clear_args
end

#envArray<Google::Apis::RunV1::EnvVar>

List of environment variables to set in the container. All specified environment variables are merged with existing environment variables. When the specified environment variables exist, these values override any existing values. Corresponds to the JSON property env

Returns:



712
713
714
# File 'lib/google/apis/run_v1/classes.rb', line 712

def env
  @env
end

#nameString

The name of the container specified as a DNS_LABEL. Corresponds to the JSON property name

Returns:

  • (String)


717
718
719
# File 'lib/google/apis/run_v1/classes.rb', line 717

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



724
725
726
727
728
729
# File 'lib/google/apis/run_v1/classes.rb', line 724

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @clear_args = args[:clear_args] if args.key?(:clear_args)
  @env = args[:env] if args.key?(:env)
  @name = args[:name] if args.key?(:name)
end