Class: Google::Apis::RunV1::ContainerPort

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ContainerPort represents a network port in a single container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerPort

Returns a new instance of ContainerPort.



762
763
764
# File 'lib/google/apis/run_v1/classes.rb', line 762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_portFixnum

Port number the container listens on. If present, this must be a valid port number, 0 < x < 65536. If not present, it will default to port 8080. For more information, see https://cloud.google.com/run/docs/container-contract#port Corresponds to the JSON property containerPort

Returns:

  • (Fixnum)


749
750
751
# File 'lib/google/apis/run_v1/classes.rb', line 749

def container_port
  @container_port
end

#nameString

If specified, used to specify which protocol to use. Allowed values are "http1" and "h2c". Corresponds to the JSON property name

Returns:

  • (String)


755
756
757
# File 'lib/google/apis/run_v1/classes.rb', line 755

def name
  @name
end

#protocolString

Protocol for port. Must be "TCP". Defaults to "TCP". Corresponds to the JSON property protocol

Returns:

  • (String)


760
761
762
# File 'lib/google/apis/run_v1/classes.rb', line 760

def protocol
  @protocol
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



767
768
769
770
771
# File 'lib/google/apis/run_v1/classes.rb', line 767

def update!(**args)
  @container_port = args[:container_port] if args.key?(:container_port)
  @name = args[:name] if args.key?(:name)
  @protocol = args[:protocol] if args.key?(:protocol)
end