Class: Google::Apis::RunV1::DomainMapping
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::DomainMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Resource to hold the state and status of a user's domain mapping. NOTE: This resource is currently in Beta.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "domains.cloudrun.com/v1".
-
#kind ⇒ String
The kind of resource, in this case "DomainMapping".
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::DomainMappingSpec
The desired state of the Domain Mapping.
-
#status ⇒ Google::Apis::RunV1::DomainMappingStatus
The current state of the Domain Mapping.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainMapping
constructor
A new instance of DomainMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainMapping
Returns a new instance of DomainMapping.
805 806 807 |
# File 'lib/google/apis/run_v1/classes.rb', line 805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "domains.cloudrun.com/v1".
Corresponds to the JSON property apiVersion
782 783 784 |
# File 'lib/google/apis/run_v1/classes.rb', line 782 def api_version @api_version end |
#kind ⇒ String
The kind of resource, in this case "DomainMapping".
Corresponds to the JSON property kind
787 788 789 |
# File 'lib/google/apis/run_v1/classes.rb', line 787 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
793 794 795 |
# File 'lib/google/apis/run_v1/classes.rb', line 793 def @metadata end |
#spec ⇒ Google::Apis::RunV1::DomainMappingSpec
The desired state of the Domain Mapping.
Corresponds to the JSON property spec
798 799 800 |
# File 'lib/google/apis/run_v1/classes.rb', line 798 def spec @spec end |
#status ⇒ Google::Apis::RunV1::DomainMappingStatus
The current state of the Domain Mapping.
Corresponds to the JSON property status
803 804 805 |
# File 'lib/google/apis/run_v1/classes.rb', line 803 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
810 811 812 813 814 815 816 |
# File 'lib/google/apis/run_v1/classes.rb', line 810 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |