Class: Google::Apis::RunV1::ExecutionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ExecutionSpec describes how the execution will look.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionSpec

Returns a new instance of ExecutionSpec.



1201
1202
1203
# File 'lib/google/apis/run_v1/classes.rb', line 1201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delay_executionBoolean Also known as: delay_execution?

Optional. If true, the system will start the execution within the next 12 hours depending on available capacity. Corresponds to the JSON property delayExecution

Returns:

  • (Boolean)


1175
1176
1177
# File 'lib/google/apis/run_v1/classes.rb', line 1175

def delay_execution
  @delay_execution
end

#parallelismFixnum

Optional. Specifies the maximum desired number of tasks the execution should run at given time. When the job is run, if this field is 0 or unset, the maximum possible value will be used for that execution. The actual number of tasks running in steady state will be less than this number when there are fewer tasks waiting to be completed, i.e. when the work left to do is less than max parallelism. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


1186
1187
1188
# File 'lib/google/apis/run_v1/classes.rb', line 1186

def parallelism
  @parallelism
end

#task_countFixnum

Optional. Specifies the desired number of tasks the execution should run. Setting to 1 means that parallelism is limited to 1 and the success of that task signals the success of the execution. Defaults to 1. Corresponds to the JSON property taskCount

Returns:

  • (Fixnum)


1193
1194
1195
# File 'lib/google/apis/run_v1/classes.rb', line 1193

def task_count
  @task_count
end

#templateGoogle::Apis::RunV1::TaskTemplateSpec

TaskTemplateSpec describes the data a task should have when created from a template. Corresponds to the JSON property template



1199
1200
1201
# File 'lib/google/apis/run_v1/classes.rb', line 1199

def template
  @template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1206
1207
1208
1209
1210
1211
# File 'lib/google/apis/run_v1/classes.rb', line 1206

def update!(**args)
  @delay_execution = args[:delay_execution] if args.key?(:delay_execution)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
  @task_count = args[:task_count] if args.key?(:task_count)
  @template = args[:template] if args.key?(:template)
end