Class: Google::Apis::RunV1::ExecutionTemplateSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionTemplateSpec

Returns a new instance of ExecutionTemplateSpec.



1305
1306
1307
# File 'lib/google/apis/run_v1/classes.rb', line 1305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



1298
1299
1300
# File 'lib/google/apis/run_v1/classes.rb', line 1298

def 
  @metadata
end

#specGoogle::Apis::RunV1::ExecutionSpec

ExecutionSpec describes how the execution will look. Corresponds to the JSON property spec



1303
1304
1305
# File 'lib/google/apis/run_v1/classes.rb', line 1303

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1310
1311
1312
1313
# File 'lib/google/apis/run_v1/classes.rb', line 1310

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
end