Class: Google::Apis::RunV1::GoogleCloudRunV1Condition
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleCloudRunV1Condition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Conditions show the status of reconciliation progress on a given resource. Most resource use a top-level condition type "Ready" or "Completed" to show overall status with other conditions to checkpoint each stage of reconciliation. Note that if metadata.Generation does not equal status. ObservedGeneration, the conditions shown may not be relevant for the current spec.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Optional.
-
#message ⇒ String
Optional.
-
#reason ⇒ String
Optional.
-
#severity ⇒ String
Optional.
-
#status ⇒ String
Status of the condition, one of True, False, Unknown.
-
#type ⇒ String
type is used to communicate the status of the reconciliation process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV1Condition
constructor
A new instance of GoogleCloudRunV1Condition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV1Condition
Returns a new instance of GoogleCloudRunV1Condition.
1449 1450 1451 |
# File 'lib/google/apis/run_v1/classes.rb', line 1449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Optional. Last time the condition transitioned from one status to another.
Corresponds to the JSON property lastTransitionTime
1416 1417 1418 |
# File 'lib/google/apis/run_v1/classes.rb', line 1416 def last_transition_time @last_transition_time end |
#message ⇒ String
Optional. Human readable message indicating details about the current status.
Corresponds to the JSON property message
1421 1422 1423 |
# File 'lib/google/apis/run_v1/classes.rb', line 1421 def @message end |
#reason ⇒ String
Optional. One-word CamelCase reason for the condition's last transition. These
are intended to be stable, unique values which the client may use to trigger
error handling logic, whereas messages which may be changed later by the
server.
Corresponds to the JSON property reason
1429 1430 1431 |
# File 'lib/google/apis/run_v1/classes.rb', line 1429 def reason @reason end |
#severity ⇒ String
Optional. How to interpret this condition. One of Error, Warning, or Info.
Conditions of severity Info do not contribute to resource readiness.
Corresponds to the JSON property severity
1435 1436 1437 |
# File 'lib/google/apis/run_v1/classes.rb', line 1435 def severity @severity end |
#status ⇒ String
Status of the condition, one of True, False, Unknown.
Corresponds to the JSON property status
1440 1441 1442 |
# File 'lib/google/apis/run_v1/classes.rb', line 1440 def status @status end |
#type ⇒ String
type is used to communicate the status of the reconciliation process. Types
common to all resources include: * "Ready" or "Completed": True when the
Resource is ready.
Corresponds to the JSON property type
1447 1448 1449 |
# File 'lib/google/apis/run_v1/classes.rb', line 1447 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1454 1455 1456 1457 1458 1459 1460 1461 |
# File 'lib/google/apis/run_v1/classes.rb', line 1454 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @severity = args[:severity] if args.key?(:severity) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |