Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ArtifactObjects

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ArtifactObjects

Returns a new instance of GoogleDevtoolsCloudbuildV1ArtifactObjects.



1556
1557
1558
# File 'lib/google/apis/run_v1/classes.rb', line 1556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Cloud Storage bucket and optional object path, in the form "gs://bucket/path/ to/somewhere/". (see Bucket Name Requirements). Files in the workspace matching any path pattern will be uploaded to Cloud Storage with this location as a prefix. Corresponds to the JSON property location

Returns:

  • (String)


1544
1545
1546
# File 'lib/google/apis/run_v1/classes.rb', line 1544

def location
  @location
end

#pathsArray<String>

Path globs used to match files in the build's workspace. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


1549
1550
1551
# File 'lib/google/apis/run_v1/classes.rb', line 1549

def paths
  @paths
end

#timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property timing



1554
1555
1556
# File 'lib/google/apis/run_v1/classes.rb', line 1554

def timing
  @timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1561
1562
1563
1564
1565
# File 'lib/google/apis/run_v1/classes.rb', line 1561

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @paths = args[:paths] if args.key?(:paths)
  @timing = args[:timing] if args.key?(:timing)
end