Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildApproval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

BuildApproval describes a build's approval configuration, state, and result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildApproval

Returns a new instance of GoogleDevtoolsCloudbuildV1BuildApproval.



1912
1913
1914
# File 'lib/google/apis/run_v1/classes.rb', line 1912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalConfig

ApprovalConfig describes configuration for manual approval of a build. Corresponds to the JSON property config



1899
1900
1901
# File 'lib/google/apis/run_v1/classes.rb', line 1899

def config
  @config
end

#resultGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalResult

ApprovalResult describes the decision and associated metadata of a manual approval of a build. Corresponds to the JSON property result



1905
1906
1907
# File 'lib/google/apis/run_v1/classes.rb', line 1905

def result
  @result
end

#stateString

Output only. The state of this build's approval. Corresponds to the JSON property state

Returns:

  • (String)


1910
1911
1912
# File 'lib/google/apis/run_v1/classes.rb', line 1910

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1917
1918
1919
1920
1921
# File 'lib/google/apis/run_v1/classes.rb', line 1917

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @result = args[:result] if args.key?(:result)
  @state = args[:state] if args.key?(:state)
end