Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Dependency
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Dependency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A dependency that the Cloud Build worker will fetch before executing user steps.
Instance Attribute Summary collapse
-
#empty ⇒ Boolean
(also: #empty?)
If set to true disable all dependency fetching (ignoring the default source as well).
-
#generic_artifact ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GenericArtifactDependency
Represents a generic artifact as a build dependency.
-
#git_source ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
constructor
A new instance of GoogleDevtoolsCloudbuildV1Dependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.
2373 2374 2375 |
# File 'lib/google/apis/run_v1/classes.rb', line 2373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#empty ⇒ Boolean Also known as: empty?
If set to true disable all dependency fetching (ignoring the default source as
well).
Corresponds to the JSON property empty
2360 2361 2362 |
# File 'lib/google/apis/run_v1/classes.rb', line 2360 def empty @empty end |
#generic_artifact ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GenericArtifactDependency
Represents a generic artifact as a build dependency.
Corresponds to the JSON property genericArtifact
2366 2367 2368 |
# File 'lib/google/apis/run_v1/classes.rb', line 2366 def generic_artifact @generic_artifact end |
#git_source ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Corresponds to the JSON property gitSource
2371 2372 2373 |
# File 'lib/google/apis/run_v1/classes.rb', line 2371 def git_source @git_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2378 2379 2380 2381 2382 |
# File 'lib/google/apis/run_v1/classes.rb', line 2378 def update!(**args) @empty = args[:empty] if args.key?(:empty) @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact) @git_source = args[:git_source] if args.key?(:git_source) end |