Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FailureInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FailureInfo

Returns a new instance of GoogleDevtoolsCloudbuildV1FailureInfo.



2407
2408
2409
# File 'lib/google/apis/run_v1/classes.rb', line 2407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/run_v1/classes.rb', line 2400

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


2405
2406
2407
# File 'lib/google/apis/run_v1/classes.rb', line 2405

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2412
2413
2414
2415
# File 'lib/google/apis/run_v1/classes.rb', line 2412

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end