Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Generic artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GenericArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1GenericArtifact.



2481
2482
2483
# File 'lib/google/apis/run_v1/classes.rb', line 2481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderString

Required. Path to the generic artifact in the build's workspace to be uploaded to Artifact Registry. Corresponds to the JSON property folder

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/run_v1/classes.rb', line 2472

def folder
  @folder
end

#registry_pathString

Required. Registry path to upload the generic artifact to, in the form projects/$PROJECT/locations/$LOCATION/repositories/$REPO/packages/$PACKAGE/ versions/$VERSION Corresponds to the JSON property registryPath

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/run_v1/classes.rb', line 2479

def registry_path
  @registry_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2486
2487
2488
2489
# File 'lib/google/apis/run_v1/classes.rb', line 2486

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @registry_path = args[:registry_path] if args.key?(:registry_path)
end