Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Location of the source in any accessible Git repository.
Instance Attribute Summary collapse
-
#dir ⇒ String
Optional.
-
#revision ⇒ String
Optional.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSource
constructor
A new instance of GoogleDevtoolsCloudbuildV1GitSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSource
Returns a new instance of GoogleDevtoolsCloudbuildV1GitSource.
2454 2455 2456 |
# File 'lib/google/apis/run_v1/classes.rb', line 2454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dir ⇒ String
Optional. Directory, relative to the source root, in which to run the build.
This must be a relative path. If a step's dir is specified and is an
absolute path, this value is ignored for that step's execution.
Corresponds to the JSON property dir
2435 2436 2437 |
# File 'lib/google/apis/run_v1/classes.rb', line 2435 def dir @dir end |
#revision ⇒ String
Optional. The revision to fetch from the Git repository such as a branch, a
tag, a commit SHA, or any Git ref. Cloud Build uses git fetch to fetch the
revision from the Git repository; therefore make sure that the string you
provide for revision is parsable by the command. For information on string
values accepted by git fetch, see https://git-scm.com/docs/gitrevisions#
_specifying_revisions. For information on git fetch, see https://git-scm.com/
docs/git-fetch.
Corresponds to the JSON property revision
2446 2447 2448 |
# File 'lib/google/apis/run_v1/classes.rb', line 2446 def revision @revision end |
#url ⇒ String
Required. Location of the Git repo to build. This will be used as a git
remote, see https://git-scm.com/docs/git-remote.
Corresponds to the JSON property url
2452 2453 2454 |
# File 'lib/google/apis/run_v1/classes.rb', line 2452 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2459 2460 2461 2462 2463 |
# File 'lib/google/apis/run_v1/classes.rb', line 2459 def update!(**args) @dir = args[:dir] if args.key?(:dir) @revision = args[:revision] if args.key?(:revision) @url = args[:url] if args.key?(:url) end |