Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency

Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.



2632
2633
2634
# File 'lib/google/apis/run_v1/classes.rb', line 2632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2601
2602
2603
# File 'lib/google/apis/run_v1/classes.rb', line 2601

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2606
2607
2608
# File 'lib/google/apis/run_v1/classes.rb', line 2606

def dest_path
  @dest_path
end

#fetch_tagsBoolean Also known as: fetch_tags?

Optional. True if remote tags should be fetched too (default false). Note: when depth is 1 (default), git fetch only retrieves tags pointing to commits within the shallow boundary. Set depth to -1 to fetch all historical tags. Corresponds to the JSON property fetchTags

Returns:

  • (Boolean)


2613
2614
2615
# File 'lib/google/apis/run_v1/classes.rb', line 2613

def fetch_tags
  @fetch_tags
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2619
2620
2621
# File 'lib/google/apis/run_v1/classes.rb', line 2619

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2625
2626
2627
# File 'lib/google/apis/run_v1/classes.rb', line 2625

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2630
2631
2632
# File 'lib/google/apis/run_v1/classes.rb', line 2630

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2637
2638
2639
2640
2641
2642
2643
2644
# File 'lib/google/apis/run_v1/classes.rb', line 2637

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @fetch_tags = args[:fetch_tags] if args.key?(:fetch_tags)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end