Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1InlineSecret
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1InlineSecret
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Pairs a set of secret environment variables mapped to encrypted values with the Cloud KMS key to use to decrypt the value.
Instance Attribute Summary collapse
-
#env_map ⇒ Hash<String,String>
Map of environment variable name to its encrypted value.
-
#kms_key_name ⇒ String
Resource name of Cloud KMS crypto key to decrypt the encrypted value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1InlineSecret
constructor
A new instance of GoogleDevtoolsCloudbuildV1InlineSecret.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1InlineSecret
Returns a new instance of GoogleDevtoolsCloudbuildV1InlineSecret.
2798 2799 2800 |
# File 'lib/google/apis/run_v1/classes.rb', line 2798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#env_map ⇒ Hash<String,String>
Map of environment variable name to its encrypted value. Secret environment
variables must be unique across all of a build's secrets, and must be used by
at least one build step. Values can be at most 64 KB in size. There can be at
most 100 secret values across all of a build's secrets.
Corresponds to the JSON property envMap
2790 2791 2792 |
# File 'lib/google/apis/run_v1/classes.rb', line 2790 def env_map @env_map end |
#kms_key_name ⇒ String
Resource name of Cloud KMS crypto key to decrypt the encrypted value. In
format: projects//locations//keyRings//cryptoKeys/
Corresponds to the JSON property kmsKeyName
2796 2797 2798 |
# File 'lib/google/apis/run_v1/classes.rb', line 2796 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2803 2804 2805 2806 |
# File 'lib/google/apis/run_v1/classes.rb', line 2803 def update!(**args) @env_map = args[:env_map] if args.key?(:env_map) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |