Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1NpmPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Npm package to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1NpmPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1NpmPackage.



2868
2869
2870
# File 'lib/google/apis/run_v1/classes.rb', line 2868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#package_pathString

Optional. Path to the package.json. e.g. workspace/path/to/package Only one of archive or package_path can be specified. Corresponds to the JSON property packagePath

Returns:

  • (String)


2859
2860
2861
# File 'lib/google/apis/run_v1/classes.rb', line 2859

def package_path
  @package_path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-npm.pkg.dev/$ PROJECT/$REPOSITORY" Npm package in the workspace specified by path will be zipped and uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/run_v1/classes.rb', line 2866

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2873
2874
2875
2876
# File 'lib/google/apis/run_v1/classes.rb', line 2873

def update!(**args)
  @package_path = args[:package_path] if args.key?(:package_path)
  @repository = args[:repository] if args.key?(:repository)
end