Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Oci

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

OCI image to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Oci

Returns a new instance of GoogleDevtoolsCloudbuildV1Oci.



2893
2894
2895
# File 'lib/google/apis/run_v1/classes.rb', line 2893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Required. Path on the local file system where to find the container to upload. e.g. /workspace/my-image.tar Corresponds to the JSON property file

Returns:

  • (String)


2880
2881
2882
# File 'lib/google/apis/run_v1/classes.rb', line 2880

def file
  @file
end

#registry_pathString

Required. Registry path to upload the container to. e.g. us-east1-docker.pkg. dev/my-project/my-repo/my-image Corresponds to the JSON property registryPath

Returns:

  • (String)


2886
2887
2888
# File 'lib/google/apis/run_v1/classes.rb', line 2886

def registry_path
  @registry_path
end

#tagsArray<String>

Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0 Corresponds to the JSON property tags

Returns:

  • (Array<String>)


2891
2892
2893
# File 'lib/google/apis/run_v1/classes.rb', line 2891

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2898
2899
2900
2901
2902
# File 'lib/google/apis/run_v1/classes.rb', line 2898

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @registry_path = args[:registry_path] if args.key?(:registry_path)
  @tags = args[:tags] if args.key?(:tags)
end