Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results

Returns a new instance of GoogleDevtoolsCloudbuildV1Results.



3126
3127
3128
# File 'lib/google/apis/run_v1/classes.rb', line 3126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


3062
3063
3064
# File 'lib/google/apis/run_v1/classes.rb', line 3062

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



3067
3068
3069
# File 'lib/google/apis/run_v1/classes.rb', line 3067

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


3072
3073
3074
# File 'lib/google/apis/run_v1/classes.rb', line 3072

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


3081
3082
3083
# File 'lib/google/apis/run_v1/classes.rb', line 3081

def build_step_outputs
  @build_step_outputs
end

#build_step_resultsHash<String,Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildStepResults>

Results for build steps. step_id -> Corresponds to the JSON property buildStepResults



3086
3087
3088
# File 'lib/google/apis/run_v1/classes.rb', line 3086

def build_step_results
  @build_step_results
end

#generic_artifactsArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>

Output only. Generic artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property genericArtifacts



3092
3093
3094
# File 'lib/google/apis/run_v1/classes.rb', line 3092

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



3098
3099
3100
# File 'lib/google/apis/run_v1/classes.rb', line 3098

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



3103
3104
3105
# File 'lib/google/apis/run_v1/classes.rb', line 3103

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



3108
3109
3110
# File 'lib/google/apis/run_v1/classes.rb', line 3108

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



3113
3114
3115
# File 'lib/google/apis/run_v1/classes.rb', line 3113

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


3119
3120
3121
# File 'lib/google/apis/run_v1/classes.rb', line 3119

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



3124
3125
3126
# File 'lib/google/apis/run_v1/classes.rb', line 3124

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
# File 'lib/google/apis/run_v1/classes.rb', line 3131

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @build_step_results = args[:build_step_results] if args.key?(:build_step_results)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end