Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Secret
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Secret
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Pairs a set of secret environment variables containing encrypted values with
the Cloud KMS key to use to decrypt the value. Note: Use kmsKeyName with
available_secrets instead of using kmsKeyName with secret. For
instructions see: https://cloud.google.com/cloud-build/docs/securing-builds/
use-encrypted-credentials.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Cloud KMS key name to use to decrypt these envs.
-
#secret_env ⇒ Hash<String,String>
Map of environment variable name to its encrypted value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Secret
constructor
A new instance of GoogleDevtoolsCloudbuildV1Secret.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Secret
Returns a new instance of GoogleDevtoolsCloudbuildV1Secret.
2985 2986 2987 |
# File 'lib/google/apis/run_v1/classes.rb', line 2985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Cloud KMS key name to use to decrypt these envs.
Corresponds to the JSON property kmsKeyName
2975 2976 2977 |
# File 'lib/google/apis/run_v1/classes.rb', line 2975 def kms_key_name @kms_key_name end |
#secret_env ⇒ Hash<String,String>
Map of environment variable name to its encrypted value. Secret environment
variables must be unique across all of a build's secrets, and must be used by
at least one build step. Values can be at most 64 KB in size. There can be at
most 100 secret values across all of a build's secrets.
Corresponds to the JSON property secretEnv
2983 2984 2985 |
# File 'lib/google/apis/run_v1/classes.rb', line 2983 def secret_env @secret_env end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2990 2991 2992 2993 |
# File 'lib/google/apis/run_v1/classes.rb', line 2990 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @secret_env = args[:secret_env] if args.key?(:secret_env) end |