Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Location of the source in a supported storage service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source

Returns a new instance of GoogleDevtoolsCloudbuildV1Source.



3250
3251
3252
# File 'lib/google/apis/run_v1/classes.rb', line 3250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoryGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property connectedRepository



3221
3222
3223
# File 'lib/google/apis/run_v1/classes.rb', line 3221

def connected_repository
  @connected_repository
end

#developer_connect_configGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

This config defines the location of a source through Developer Connect. Corresponds to the JSON property developerConnectConfig



3226
3227
3228
# File 'lib/google/apis/run_v1/classes.rb', line 3226

def developer_connect_config
  @developer_connect_config
end

#git_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property gitSource



3231
3232
3233
# File 'lib/google/apis/run_v1/classes.rb', line 3231

def git_source
  @git_source
end

#repo_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property repoSource



3236
3237
3238
# File 'lib/google/apis/run_v1/classes.rb', line 3236

def repo_source
  @repo_source
end

#storage_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property storageSource



3241
3242
3243
# File 'lib/google/apis/run_v1/classes.rb', line 3241

def storage_source
  @storage_source
end

#storage_source_manifestGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property storageSourceManifest



3248
3249
3250
# File 'lib/google/apis/run_v1/classes.rb', line 3248

def storage_source_manifest
  @storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3255
3256
3257
3258
3259
3260
3261
3262
# File 'lib/google/apis/run_v1/classes.rb', line 3255

def update!(**args)
  @connected_repository = args[:connected_repository] if args.key?(:connected_repository)
  @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config)
  @git_source = args[:git_source] if args.key?(:git_source)
  @repo_source = args[:repo_source] if args.key?(:repo_source)
  @storage_source = args[:storage_source] if args.key?(:storage_source)
  @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest)
end