Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Location of the source in an archive file in Cloud Storage.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
-
#generation ⇒ Fixnum
Optional.
-
#object ⇒ String
Required.
-
#source_fetcher ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1StorageSource
constructor
A new instance of GoogleDevtoolsCloudbuildV1StorageSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1StorageSource
Returns a new instance of GoogleDevtoolsCloudbuildV1StorageSource.
3184 3185 3186 |
# File 'lib/google/apis/run_v1/classes.rb', line 3184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Cloud Storage bucket containing the source (see Bucket Name Requirements).
Corresponds to the JSON property bucket
3165 3166 3167 |
# File 'lib/google/apis/run_v1/classes.rb', line 3165 def bucket @bucket end |
#generation ⇒ Fixnum
Optional. Cloud Storage generation for the object. If the generation is
omitted, the latest generation will be used.
Corresponds to the JSON property generation
3171 3172 3173 |
# File 'lib/google/apis/run_v1/classes.rb', line 3171 def generation @generation end |
#object ⇒ String
Required. Cloud Storage object containing the source. This object must be a
zipped (.zip) or gzipped archive file (.tar.gz) containing source to build.
Corresponds to the JSON property object
3177 3178 3179 |
# File 'lib/google/apis/run_v1/classes.rb', line 3177 def object @object end |
#source_fetcher ⇒ String
Optional. Option to specify the tool to fetch the source file for the build.
Corresponds to the JSON property sourceFetcher
3182 3183 3184 |
# File 'lib/google/apis/run_v1/classes.rb', line 3182 def source_fetcher @source_fetcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3189 3190 3191 3192 3193 3194 |
# File 'lib/google/apis/run_v1/classes.rb', line 3189 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @generation = args[:generation] if args.key?(:generation) @object = args[:object] if args.key?(:object) @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher) end |