Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A Go module artifact uploaded to Artifact Registry using the GoModule directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.



3545
3546
3547
# File 'lib/google/apis/run_v1/classes.rb', line 3545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3527
3528
3529
# File 'lib/google/apis/run_v1/classes.rb', line 3527

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3533
3534
3535
# File 'lib/google/apis/run_v1/classes.rb', line 3533

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3538
3539
3540
# File 'lib/google/apis/run_v1/classes.rb', line 3538

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3543
3544
3545
# File 'lib/google/apis/run_v1/classes.rb', line 3543

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3550
3551
3552
3553
3554
3555
# File 'lib/google/apis/run_v1/classes.rb', line 3550

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end