Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.



3621
3622
3623
# File 'lib/google/apis/run_v1/classes.rb', line 3621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/run_v1/classes.rb', line 3603

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3609
3610
3611
# File 'lib/google/apis/run_v1/classes.rb', line 3609

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3614
3615
3616
# File 'lib/google/apis/run_v1/classes.rb', line 3614

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/run_v1/classes.rb', line 3619

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3626
3627
3628
3629
3630
3631
# File 'lib/google/apis/run_v1/classes.rb', line 3626

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end