Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Volume
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Volume
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the volume to mount.
-
#path ⇒ String
Path at which to mount the volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Volume
constructor
A new instance of GoogleDevtoolsCloudbuildV1Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Volume
Returns a new instance of GoogleDevtoolsCloudbuildV1Volume.
3691 3692 3693 |
# File 'lib/google/apis/run_v1/classes.rb', line 3691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the volume to mount. Volume names must be unique per build step and
must be valid names for Docker volumes. Each named volume must be used by at
least two build steps.
Corresponds to the JSON property name
3682 3683 3684 |
# File 'lib/google/apis/run_v1/classes.rb', line 3682 def name @name end |
#path ⇒ String
Path at which to mount the volume. Paths must be absolute and cannot conflict
with other volume paths on the same build step or with certain reserved volume
paths.
Corresponds to the JSON property path
3689 3690 3691 |
# File 'lib/google/apis/run_v1/classes.rb', line 3689 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3696 3697 3698 3699 |
# File 'lib/google/apis/run_v1/classes.rb', line 3696 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |