Class: Google::Apis::RunV1::GoogleLongrunningWaitOperationRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleLongrunningWaitOperationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The request message for Operations.WaitOperation.
Instance Attribute Summary collapse
-
#timeout ⇒ String
The maximum duration to wait before timing out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningWaitOperationRequest
constructor
A new instance of GoogleLongrunningWaitOperationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningWaitOperationRequest
Returns a new instance of GoogleLongrunningWaitOperationRequest.
3574 3575 3576 |
# File 'lib/google/apis/run_v1/classes.rb', line 3574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#timeout ⇒ String
The maximum duration to wait before timing out. If left blank, the wait will
be at most the time permitted by the underlying HTTP/RPC protocol. If RPC
context deadline is also specified, the shorter one will be used.
Corresponds to the JSON property timeout
3572 3573 3574 |
# File 'lib/google/apis/run_v1/classes.rb', line 3572 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3579 3580 3581 |
# File 'lib/google/apis/run_v1/classes.rb', line 3579 def update!(**args) @timeout = args[:timeout] if args.key?(:timeout) end |