Class: Google::Apis::RunV1::GrpcAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

GRPCAction describes an action involving a GRPC port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcAction

Returns a new instance of GrpcAction.



1393
1394
1395
# File 'lib/google/apis/run_v1/classes.rb', line 1393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

Port number of the gRPC service. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1385
1386
1387
# File 'lib/google/apis/run_v1/classes.rb', line 1385

def port
  @port
end

#serviceString

Service is the name of the service to place in the gRPC HealthCheckRequest. If this is not specified, the default behavior is defined by gRPC. Corresponds to the JSON property service

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/run_v1/classes.rb', line 1391

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1398
1399
1400
1401
# File 'lib/google/apis/run_v1/classes.rb', line 1398

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @service = args[:service] if args.key?(:service)
end