Class: Google::Apis::RunV1::InstanceSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

InstanceSpec describes how the Instance will look.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceSpec

Returns a new instance of InstanceSpec.



4036
4037
4038
# File 'lib/google/apis/run_v1/classes.rb', line 4036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::RunV1::Container>

Optional. List of containers belonging to the Instance. We disallow a number of fields on this Container. Corresponds to the JSON property containers

Returns:



4008
4009
4010
# File 'lib/google/apis/run_v1/classes.rb', line 4008

def containers
  @containers
end

#node_selectorHash<String,String>

Optional. The Node Selector configuration. Map of selector key to a value which matches a node. Corresponds to the JSON property nodeSelector

Returns:

  • (Hash<String,String>)


4014
4015
4016
# File 'lib/google/apis/run_v1/classes.rb', line 4014

def node_selector
  @node_selector
end

#restart_policyString

Optional. Restart policy for the Instance. Allowable values are 'Always', ' OnFailure', or 'Never'. Corresponds to the JSON property restartPolicy

Returns:

  • (String)


4020
4021
4022
# File 'lib/google/apis/run_v1/classes.rb', line 4020

def restart_policy
  @restart_policy
end

#service_account_nameString

Optional. Email address of the IAM service account associated with the Instance. The service account represents the identity of the running container, and determines what permissions the Instance has. If not provided, the Instance will use the project's default service account. Corresponds to the JSON property serviceAccountName

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/run_v1/classes.rb', line 4028

def 
  @service_account_name
end

#volumesArray<Google::Apis::RunV1::Volume>

Optional. List of volumes that can be mounted by containers belonging to the Instance. Corresponds to the JSON property volumes

Returns:



4034
4035
4036
# File 'lib/google/apis/run_v1/classes.rb', line 4034

def volumes
  @volumes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4041
4042
4043
4044
4045
4046
4047
# File 'lib/google/apis/run_v1/classes.rb', line 4041

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @restart_policy = args[:restart_policy] if args.key?(:restart_policy)
  @service_account_name = args[:service_account_name] if args.key?(:service_account_name)
  @volumes = args[:volumes] if args.key?(:volumes)
end