Class: Google::Apis::RunV1::KeyToPath
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::KeyToPath
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Maps a string key to a path within a volume.
Instance Attribute Summary collapse
-
#key ⇒ String
The Cloud Secret Manager secret version.
-
#mode ⇒ Fixnum
(Optional) Mode bits to use on this file, must be a value between 01 and 0777 ( octal).
-
#path ⇒ String
The relative path of the file to map the key to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyToPath
constructor
A new instance of KeyToPath.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyToPath
Returns a new instance of KeyToPath.
4283 4284 4285 |
# File 'lib/google/apis/run_v1/classes.rb', line 4283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
The Cloud Secret Manager secret version. Can be 'latest' for the latest value,
or an integer or a secret alias for a specific version. The key to project.
Corresponds to the JSON property key
4261 4262 4263 |
# File 'lib/google/apis/run_v1/classes.rb', line 4261 def key @key end |
#mode ⇒ Fixnum
(Optional) Mode bits to use on this file, must be a value between 01 and 0777 (
octal). If 0 or not set, the Volume's default mode will be used. Notes *
Internally, a umask of 0222 will be applied to any non-zero value. * This is
an integer representation of the mode bits. So, the octal integer value should
look exactly as the chmod numeric notation with a leading zero. Some examples:
for chmod 777 (a=rwx), set to 0777 (octal) or 511 (base-10). For chmod 640 (u=
rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 (u=rwx,g=rx,o=rx),
set to 0755 (octal) or 493 (base-10). * This might be in conflict with other
options that affect the file mode, like fsGroup, and the result can be other
mode bits set.
Corresponds to the JSON property mode
4275 4276 4277 |
# File 'lib/google/apis/run_v1/classes.rb', line 4275 def mode @mode end |
#path ⇒ String
The relative path of the file to map the key to. May not be an absolute path.
May not contain the path element '..'. May not start with the string '..'.
Corresponds to the JSON property path
4281 4282 4283 |
# File 'lib/google/apis/run_v1/classes.rb', line 4281 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4288 4289 4290 4291 4292 |
# File 'lib/google/apis/run_v1/classes.rb', line 4288 def update!(**args) @key = args[:key] if args.key?(:key) @mode = args[:mode] if args.key?(:mode) @path = args[:path] if args.key?(:path) end |