Class: Google::Apis::RunV1::ListDomainMappingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListDomainMappingsResponse is a list of DomainMapping resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainMappingsResponse

Returns a new instance of ListDomainMappingsResponse.



4377
4378
4379
# File 'lib/google/apis/run_v1/classes.rb', line 4377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "domains.cloudrun.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4354
4355
4356
# File 'lib/google/apis/run_v1/classes.rb', line 4354

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::DomainMapping>

List of DomainMappings. Corresponds to the JSON property items



4359
4360
4361
# File 'lib/google/apis/run_v1/classes.rb', line 4359

def items
  @items
end

#kindString

The kind of this resource, in this case "DomainMappingList". Corresponds to the JSON property kind

Returns:

  • (String)


4364
4365
4366
# File 'lib/google/apis/run_v1/classes.rb', line 4364

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4370
4371
4372
# File 'lib/google/apis/run_v1/classes.rb', line 4370

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4375
4376
4377
# File 'lib/google/apis/run_v1/classes.rb', line 4375

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4382
4383
4384
4385
4386
4387
4388
# File 'lib/google/apis/run_v1/classes.rb', line 4382

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end