Class: Google::Apis::RunV1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListInstancesResponse is a list of Instances resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



4457
4458
4459
# File 'lib/google/apis/run_v1/classes.rb', line 4457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4434
4435
4436
# File 'lib/google/apis/run_v1/classes.rb', line 4434

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Instance>

List of Instances. Corresponds to the JSON property items

Returns:



4439
4440
4441
# File 'lib/google/apis/run_v1/classes.rb', line 4439

def items
  @items
end

#kindString

The kind of this resource, in this case "InstancesList". Corresponds to the JSON property kind

Returns:

  • (String)


4444
4445
4446
# File 'lib/google/apis/run_v1/classes.rb', line 4444

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4450
4451
4452
# File 'lib/google/apis/run_v1/classes.rb', line 4450

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4455
4456
4457
# File 'lib/google/apis/run_v1/classes.rb', line 4455

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4462
4463
4464
4465
4466
4467
4468
# File 'lib/google/apis/run_v1/classes.rb', line 4462

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end