Class: Google::Apis::RunV1::ListJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListJobsResponse is a list of Jobs resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListJobsResponse

Returns a new instance of ListJobsResponse.



4526
4527
4528
# File 'lib/google/apis/run_v1/classes.rb', line 4526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/run_v1/classes.rb', line 4503

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Job>

List of Jobs. Corresponds to the JSON property items

Returns:



4508
4509
4510
# File 'lib/google/apis/run_v1/classes.rb', line 4508

def items
  @items
end

#kindString

The kind of this resource, in this case "JobsList". Corresponds to the JSON property kind

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/run_v1/classes.rb', line 4513

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4519
4520
4521
# File 'lib/google/apis/run_v1/classes.rb', line 4519

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4524
4525
4526
# File 'lib/google/apis/run_v1/classes.rb', line 4524

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4531
4532
4533
4534
4535
4536
4537
# File 'lib/google/apis/run_v1/classes.rb', line 4531

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end