Class: Google::Apis::RunV1::ListRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListRevisionsResponse is a list of Revision resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Revision>
List of Revisions.
-
#kind ⇒ String
The kind of this resource, in this case "RevisionList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRevisionsResponse
constructor
A new instance of ListRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRevisionsResponse
Returns a new instance of ListRevisionsResponse.
4614 4615 4616 |
# File 'lib/google/apis/run_v1/classes.rb', line 4614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
4591 4592 4593 |
# File 'lib/google/apis/run_v1/classes.rb', line 4591 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Revision>
List of Revisions.
Corresponds to the JSON property items
4596 4597 4598 |
# File 'lib/google/apis/run_v1/classes.rb', line 4596 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "RevisionList".
Corresponds to the JSON property kind
4601 4602 4603 |
# File 'lib/google/apis/run_v1/classes.rb', line 4601 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4607 4608 4609 |
# File 'lib/google/apis/run_v1/classes.rb', line 4607 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4612 4613 4614 |
# File 'lib/google/apis/run_v1/classes.rb', line 4612 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/google/apis/run_v1/classes.rb', line 4619 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |