Class: Google::Apis::RunV1::ListTasksResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListTasksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListTasksResponse is a list of Tasks resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "run.googleapis.com/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Task>
List of Tasks.
-
#kind ⇒ String
The kind of this resource, in this case "TasksList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTasksResponse
constructor
A new instance of ListTasksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTasksResponse
Returns a new instance of ListTasksResponse.
4739 4740 4741 |
# File 'lib/google/apis/run_v1/classes.rb', line 4739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
4716 4717 4718 |
# File 'lib/google/apis/run_v1/classes.rb', line 4716 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Task>
List of Tasks.
Corresponds to the JSON property items
4721 4722 4723 |
# File 'lib/google/apis/run_v1/classes.rb', line 4721 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "TasksList".
Corresponds to the JSON property kind
4726 4727 4728 |
# File 'lib/google/apis/run_v1/classes.rb', line 4726 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4732 4733 4734 |
# File 'lib/google/apis/run_v1/classes.rb', line 4732 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4737 4738 4739 |
# File 'lib/google/apis/run_v1/classes.rb', line 4737 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/google/apis/run_v1/classes.rb', line 4744 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |