Class: Google::Apis::RunV1::ObjectMeta

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectMeta

Returns a new instance of ObjectMeta.



5056
5057
5058
# File 'lib/google/apis/run_v1/classes.rb', line 5056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. In Cloud Run, annotations with ' run.googleapis.com/' and 'autoscaling.knative.dev' are restricted, and the accepted annotations will be different depending on the resource type. * autoscaling.knative.dev/maxScale: Revision. * autoscaling.knative.dev/ minScale: Revision. * run.googleapis.com/base-images: Service, Revision . * run.googleapis.com/binary-authorization-breakglass: Service, Job, * run. googleapis.com/binary-authorization: Service, Job, Execution. * run. googleapis.com/build-base-image: Service. * run.googleapis.com/build-enable- automatic-updates: Service. * run.googleapis.com/build-environment-variables : Service. * run.googleapis.com/build-function-target: Service, Revision. * run.googleapis.com/build-id: Service, Revision. * run.googleapis.com/build- image-uri: Service. * run.googleapis.com/build-name: Service. * run. googleapis.com/build-service-account: Service. * run.googleapis.com/build- source-location: Service, Revision. * run.googleapis.com/build-worker-pool: Service. * run.googleapis.com/client-name: All resources. * run.googleapis. com/cloudsql-instances: Revision, Execution, Instance. * run.googleapis.com/ container-dependencies: Revision, Instance . * run.googleapis.com/cpu- throttling: Revision. * run.googleapis.com/custom-audiences: Service. * run.googleapis.com/default-url-disabled: Service. * run.googleapis.com/ description: Service. * run.googleapis.com/encryption-key-shutdown-hours: Revision * run.googleapis.com/encryption-key: Revision, Execution, Instance.

  • run.googleapis.com/execution-environment: Revision, Execution. * run. googleapis.com/gc-traffic-tags: Service. * run.googleapis.com/gpu-zonal- redundancy-disabled: Revision. * run.googleapis.com/health-check-disabled: Revision. * run.googleapis.com/ingress: Service, Instance. * run.googleapis. com/invoker-iam-disabled: Service, Instance. * run.googleapis.com/launch- stage: Service, Job. * run.googleapis.com/minScale: Service. * run. googleapis.com/maxScale: Service. * run.googleapis.com/manualInstanceCount: Service. * run.googleapis.com/network-interfaces: Revision, Execution, Instance. * run.googleapis.com/post-key-revocation-action-type: Revision. run.googleapis.com/scalingMode: Service. * run.googleapis.com/secrets: Revision, Execution. * run.googleapis.com/secure-session-agent: Revision. * run.googleapis.com/sessionAffinity: Revision. * run.googleapis.com/startup- cpu-boost: Revision. * run.googleapis.com/vpc-access-connector: Revision, Execution. * run.googleapis.com/vpc-access-egress: Revision, Execution, Instance. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


4969
4970
4971
# File 'lib/google/apis/run_v1/classes.rb', line 4969

def annotations
  @annotations
end

#cluster_nameString

Not supported by Cloud Run Corresponds to the JSON property clusterName

Returns:

  • (String)


4974
4975
4976
# File 'lib/google/apis/run_v1/classes.rb', line 4974

def cluster_name
  @cluster_name
end

#creation_timestampString

UTC timestamp representing the server time when this object was created. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


4979
4980
4981
# File 'lib/google/apis/run_v1/classes.rb', line 4979

def creation_timestamp
  @creation_timestamp
end

#deletion_grace_period_secondsFixnum

Not supported by Cloud Run Corresponds to the JSON property deletionGracePeriodSeconds

Returns:

  • (Fixnum)


4984
4985
4986
# File 'lib/google/apis/run_v1/classes.rb', line 4984

def deletion_grace_period_seconds
  @deletion_grace_period_seconds
end

#deletion_timestampString

The read-only soft deletion timestamp for this resource. In Cloud Run, users are not able to set this field. Instead, they must call the corresponding Delete API. Corresponds to the JSON property deletionTimestamp

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/run_v1/classes.rb', line 4991

def deletion_timestamp
  @deletion_timestamp
end

#finalizersArray<String>

Not supported by Cloud Run Corresponds to the JSON property finalizers

Returns:

  • (Array<String>)


4996
4997
4998
# File 'lib/google/apis/run_v1/classes.rb', line 4996

def finalizers
  @finalizers
end

#generate_nameString

Optional. A prefix for the resource name if not provided in the create request. Must be less than 31 characters to allow for a random suffix. Corresponds to the JSON property generateName

Returns:

  • (String)


5002
5003
5004
# File 'lib/google/apis/run_v1/classes.rb', line 5002

def generate_name
  @generate_name
end

#generationFixnum

A system-provided sequence number representing a specific generation of the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


5008
5009
5010
# File 'lib/google/apis/run_v1/classes.rb', line 5008

def generation
  @generation
end

#labelsHash<String,String>

Map of string keys and values that can be used to organize and categorize ( scope and select) objects. May match selectors of replication controllers and routes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5015
5016
5017
# File 'lib/google/apis/run_v1/classes.rb', line 5015

def labels
  @labels
end

#nameString

Optional. The name of the resource. A name for creating top-level resources ( Service, Job, WorkerPool). Must be unique within a Cloud Run project/region, and cannot be changed once created. If omitted, a default name will be generated. Corresponds to the JSON property name

Returns:

  • (String)


5023
5024
5025
# File 'lib/google/apis/run_v1/classes.rb', line 5023

def name
  @name
end

#namespaceString

Required. Defines the space within each name must be unique within a Cloud Run region. In Cloud Run, it must be project ID or number. Corresponds to the JSON property namespace

Returns:

  • (String)


5029
5030
5031
# File 'lib/google/apis/run_v1/classes.rb', line 5029

def namespace
  @namespace
end

#owner_referencesArray<Google::Apis::RunV1::OwnerReference>

Not supported by Cloud Run Corresponds to the JSON property ownerReferences



5034
5035
5036
# File 'lib/google/apis/run_v1/classes.rb', line 5034

def owner_references
  @owner_references
end

#resource_versionString

Opaque, system-generated value that represents the internal version of this object that can be used by clients to determine when objects have changed. May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server or omit the value to disable conflict- detection. Corresponds to the JSON property resourceVersion

Returns:

  • (String)


5044
5045
5046
# File 'lib/google/apis/run_v1/classes.rb', line 5044

def resource_version
  @resource_version
end

URL representing this object. Corresponds to the JSON property selfLink

Returns:

  • (String)


5049
5050
5051
# File 'lib/google/apis/run_v1/classes.rb', line 5049

def self_link
  @self_link
end

#uidString

Unique, system-generated identifier for this resource. Corresponds to the JSON property uid

Returns:

  • (String)


5054
5055
5056
# File 'lib/google/apis/run_v1/classes.rb', line 5054

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
# File 'lib/google/apis/run_v1/classes.rb', line 5061

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_grace_period_seconds = args[:deletion_grace_period_seconds] if args.key?(:deletion_grace_period_seconds)
  @deletion_timestamp = args[:deletion_timestamp] if args.key?(:deletion_timestamp)
  @finalizers = args[:finalizers] if args.key?(:finalizers)
  @generate_name = args[:generate_name] if args.key?(:generate_name)
  @generation = args[:generation] if args.key?(:generation)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace = args[:namespace] if args.key?(:namespace)
  @owner_references = args[:owner_references] if args.key?(:owner_references)
  @resource_version = args[:resource_version] if args.key?(:resource_version)
  @self_link = args[:self_link] if args.key?(:self_link)
  @uid = args[:uid] if args.key?(:uid)
end