Class: Google::Apis::RunV1::OwnerReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

This is not supported or used by Cloud Run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OwnerReference

Returns a new instance of OwnerReference.



5158
5159
5160
# File 'lib/google/apis/run_v1/classes.rb', line 5158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

This is not supported or used by Cloud Run. Corresponds to the JSON property apiVersion

Returns:

  • (String)


5129
5130
5131
# File 'lib/google/apis/run_v1/classes.rb', line 5129

def api_version
  @api_version
end

#block_owner_deletionBoolean Also known as: block_owner_deletion?

This is not supported or used by Cloud Run. Corresponds to the JSON property blockOwnerDeletion

Returns:

  • (Boolean)


5134
5135
5136
# File 'lib/google/apis/run_v1/classes.rb', line 5134

def block_owner_deletion
  @block_owner_deletion
end

#controllerBoolean Also known as: controller?

This is not supported or used by Cloud Run. Corresponds to the JSON property controller

Returns:

  • (Boolean)


5140
5141
5142
# File 'lib/google/apis/run_v1/classes.rb', line 5140

def controller
  @controller
end

#kindString

This is not supported or used by Cloud Run. Corresponds to the JSON property kind

Returns:

  • (String)


5146
5147
5148
# File 'lib/google/apis/run_v1/classes.rb', line 5146

def kind
  @kind
end

#nameString

This is not supported or used by Cloud Run. Corresponds to the JSON property name

Returns:

  • (String)


5151
5152
5153
# File 'lib/google/apis/run_v1/classes.rb', line 5151

def name
  @name
end

#uidString

This is not supported or used by Cloud Run. Corresponds to the JSON property uid

Returns:

  • (String)


5156
5157
5158
# File 'lib/google/apis/run_v1/classes.rb', line 5156

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5163
5164
5165
5166
5167
5168
5169
5170
# File 'lib/google/apis/run_v1/classes.rb', line 5163

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @block_owner_deletion = args[:block_owner_deletion] if args.key?(:block_owner_deletion)
  @controller = args[:controller] if args.key?(:controller)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
end