Class: Google::Apis::RunV1::Revision
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Revision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Revision is an immutable snapshot of code and configuration. A revision references one or more container images. Revisions are created by updates to a Service.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#kind ⇒ String
The kind of this resource, in this case "Revision".
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::RevisionSpec
RevisionSpec holds the desired state of the Revision (from the client).
-
#status ⇒ Google::Apis::RunV1::RevisionStatus
RevisionStatus communicates the observed state of the Revision (from the controller).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Revision
constructor
A new instance of Revision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Revision
Returns a new instance of Revision.
5444 5445 5446 |
# File 'lib/google/apis/run_v1/classes.rb', line 5444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
5420 5421 5422 |
# File 'lib/google/apis/run_v1/classes.rb', line 5420 def api_version @api_version end |
#kind ⇒ String
The kind of this resource, in this case "Revision".
Corresponds to the JSON property kind
5425 5426 5427 |
# File 'lib/google/apis/run_v1/classes.rb', line 5425 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
5431 5432 5433 |
# File 'lib/google/apis/run_v1/classes.rb', line 5431 def @metadata end |
#spec ⇒ Google::Apis::RunV1::RevisionSpec
RevisionSpec holds the desired state of the Revision (from the client).
Corresponds to the JSON property spec
5436 5437 5438 |
# File 'lib/google/apis/run_v1/classes.rb', line 5436 def spec @spec end |
#status ⇒ Google::Apis::RunV1::RevisionStatus
RevisionStatus communicates the observed state of the Revision (from the
controller).
Corresponds to the JSON property status
5442 5443 5444 |
# File 'lib/google/apis/run_v1/classes.rb', line 5442 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/google/apis/run_v1/classes.rb', line 5449 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |