Class: Google::Apis::RunV1::RevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionStatus communicates the observed state of the Revision (from the controller).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionStatus

Returns a new instance of RevisionStatus.



5561
5562
5563
# File 'lib/google/apis/run_v1/classes.rb', line 5561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. As a Revision is being prepared, it will incrementally update conditions. Revision-specific conditions include: * ResourcesAvailable: True when underlying resources have been provisioned. * ContainerHealthy: True when the Revision readiness check completes. * Active: True when the Revision may receive traffic. Corresponds to the JSON property conditions



5525
5526
5527
# File 'lib/google/apis/run_v1/classes.rb', line 5525

def conditions
  @conditions
end

#desired_replicasFixnum

Output only. The configured number of instances running this revision. For Cloud Run, this only includes instances provisioned using the minScale annotation. It does not include instances created by autoscaling. Corresponds to the JSON property desiredReplicas

Returns:

  • (Fixnum)


5532
5533
5534
# File 'lib/google/apis/run_v1/classes.rb', line 5532

def desired_replicas
  @desired_replicas
end

#image_digestString

ImageDigest holds the resolved digest for the image specified within .Spec. Container.Image. The digest is resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object. Corresponds to the JSON property imageDigest

Returns:

  • (String)


5540
5541
5542
# File 'lib/google/apis/run_v1/classes.rb', line 5540

def image_digest
  @image_digest
end

#log_urlString

Optional. Specifies the generated logging url for this particular revision based on the revision url template specified in the controller's config. Corresponds to the JSON property logUrl

Returns:

  • (String)


5546
5547
5548
# File 'lib/google/apis/run_v1/classes.rb', line 5546

def log_url
  @log_url
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the Revision that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation, and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


5554
5555
5556
# File 'lib/google/apis/run_v1/classes.rb', line 5554

def observed_generation
  @observed_generation
end

#service_nameString

Not currently used by Cloud Run. Corresponds to the JSON property serviceName

Returns:

  • (String)


5559
5560
5561
# File 'lib/google/apis/run_v1/classes.rb', line 5559

def service_name
  @service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5566
5567
5568
5569
5570
5571
5572
5573
# File 'lib/google/apis/run_v1/classes.rb', line 5566

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @desired_replicas = args[:desired_replicas] if args.key?(:desired_replicas)
  @image_digest = args[:image_digest] if args.key?(:image_digest)
  @log_url = args[:log_url] if args.key?(:log_url)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @service_name = args[:service_name] if args.key?(:service_name)
end