Class: Google::Apis::RunV1::RevisionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionTemplateSpec describes the data a revision should have when created from a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionTemplate

Returns a new instance of RevisionTemplate.



5597
5598
5599
# File 'lib/google/apis/run_v1/classes.rb', line 5597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5590
5591
5592
# File 'lib/google/apis/run_v1/classes.rb', line 5590

def 
  @metadata
end

#specGoogle::Apis::RunV1::RevisionSpec

RevisionSpec holds the desired state of the Revision (from the client). Corresponds to the JSON property spec



5595
5596
5597
# File 'lib/google/apis/run_v1/classes.rb', line 5595

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5602
5603
5604
5605
# File 'lib/google/apis/run_v1/classes.rb', line 5602

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
end