Class: Google::Apis::RunV1::Route

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Route is responsible for configuring ingress over a collection of Revisions. Some of the Revisions a Route distributes traffic over may be specified by referencing the Configuration responsible for creating them; in these cases the Route is additionally responsible for monitoring the Configuration for " latest ready" revision changes, and smoothly rolling out latest revisions. Cloud Run currently supports referencing a single Configuration to automatically deploy the "latest ready" Revision from that Configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



5664
5665
5666
# File 'lib/google/apis/run_v1/classes.rb', line 5664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


5641
5642
5643
# File 'lib/google/apis/run_v1/classes.rb', line 5641

def api_version
  @api_version
end

#kindString

The kind of this resource, in this case always "Route". Corresponds to the JSON property kind

Returns:

  • (String)


5646
5647
5648
# File 'lib/google/apis/run_v1/classes.rb', line 5646

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5652
5653
5654
# File 'lib/google/apis/run_v1/classes.rb', line 5652

def 
  @metadata
end

#specGoogle::Apis::RunV1::RouteSpec

RouteSpec holds the desired state of the Route (from the client). Corresponds to the JSON property spec



5657
5658
5659
# File 'lib/google/apis/run_v1/classes.rb', line 5657

def spec
  @spec
end

#statusGoogle::Apis::RunV1::RouteStatus

RouteStatus communicates the observed state of the Route (from the controller). Corresponds to the JSON property status



5662
5663
5664
# File 'lib/google/apis/run_v1/classes.rb', line 5662

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5669
5670
5671
5672
5673
5674
5675
# File 'lib/google/apis/run_v1/classes.rb', line 5669

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end