Class: Google::Apis::RunV1::RunJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Request message for creating a new execution of a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunJobRequest

Returns a new instance of RunJobRequest.



5493
5494
5495
# File 'lib/google/apis/run_v1/classes.rb', line 5493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#overridesGoogle::Apis::RunV1::Overrides

RunJob Overrides that contains Execution fields to be overridden on the go. Corresponds to the JSON property overrides



5491
5492
5493
# File 'lib/google/apis/run_v1/classes.rb', line 5491

def overrides
  @overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5498
5499
5500
# File 'lib/google/apis/run_v1/classes.rb', line 5498

def update!(**args)
  @overrides = args[:overrides] if args.key?(:overrides)
end