Class: Google::Apis::RunV1::SecretEnvSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Not supported by Cloud Run. SecretEnvSource selects a Secret to populate the environment variables with. The contents of the target Secret's Data field will represent the key-value pairs as environment variables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvSource

Returns a new instance of SecretEnvSource.



5341
5342
5343
# File 'lib/google/apis/run_v1/classes.rb', line 5341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#local_object_referenceGoogle::Apis::RunV1::LocalObjectReference

Not supported by Cloud Run. LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace. Corresponds to the JSON property localObjectReference



5328
5329
5330
# File 'lib/google/apis/run_v1/classes.rb', line 5328

def local_object_reference
  @local_object_reference
end

#nameString

The Secret to select from. Corresponds to the JSON property name

Returns:

  • (String)


5333
5334
5335
# File 'lib/google/apis/run_v1/classes.rb', line 5333

def name
  @name
end

#optionalBoolean Also known as: optional?

Specify whether the Secret must be defined Corresponds to the JSON property optional

Returns:

  • (Boolean)


5338
5339
5340
# File 'lib/google/apis/run_v1/classes.rb', line 5338

def optional
  @optional
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5346
5347
5348
5349
5350
# File 'lib/google/apis/run_v1/classes.rb', line 5346

def update!(**args)
  @local_object_reference = args[:local_object_reference] if args.key?(:local_object_reference)
  @name = args[:name] if args.key?(:name)
  @optional = args[:optional] if args.key?(:optional)
end