Class: Google::Apis::RunV1::SecretKeySelector
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::SecretKeySelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
SecretKeySelector selects a key of a Secret.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#local_object_reference ⇒ Google::Apis::RunV1::LocalObjectReference
Not supported by Cloud Run.
-
#name ⇒ String
The name of the secret in Cloud Secret Manager.
-
#optional ⇒ Boolean
(also: #optional?)
Specify whether the Secret or its key must be defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretKeySelector
constructor
A new instance of SecretKeySelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretKeySelector
Returns a new instance of SecretKeySelector.
5840 5841 5842 |
# File 'lib/google/apis/run_v1/classes.rb', line 5840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. A Cloud Secret Manager secret version. Must be 'latest' for the
latest version, an integer for a specific version, or a version alias. The key
of the secret to select from. Must be a valid secret key.
Corresponds to the JSON property key
5816 5817 5818 |
# File 'lib/google/apis/run_v1/classes.rb', line 5816 def key @key end |
#local_object_reference ⇒ Google::Apis::RunV1::LocalObjectReference
Not supported by Cloud Run. LocalObjectReference contains enough information
to let you locate the referenced object inside the same namespace.
Corresponds to the JSON property localObjectReference
5822 5823 5824 |
# File 'lib/google/apis/run_v1/classes.rb', line 5822 def local_object_reference @local_object_reference end |
#name ⇒ String
The name of the secret in Cloud Secret Manager. By default, the secret is
assumed to be in the same project. If the secret is in another project, you
must define an alias. An alias definition has the form: :projects//secrets/.
If multiple alias definitions are needed, they must be separated by commas.
The alias definitions must be set on the run.googleapis.com/secrets annotation.
The name of the secret in the pod's namespace to select from.
Corresponds to the JSON property name
5832 5833 5834 |
# File 'lib/google/apis/run_v1/classes.rb', line 5832 def name @name end |
#optional ⇒ Boolean Also known as: optional?
Specify whether the Secret or its key must be defined.
Corresponds to the JSON property optional
5837 5838 5839 |
# File 'lib/google/apis/run_v1/classes.rb', line 5837 def optional @optional end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5845 5846 5847 5848 5849 5850 |
# File 'lib/google/apis/run_v1/classes.rb', line 5845 def update!(**args) @key = args[:key] if args.key?(:key) @local_object_reference = args[:local_object_reference] if args.key?(:local_object_reference) @name = args[:name] if args.key?(:name) @optional = args[:optional] if args.key?(:optional) end |