Class: Google::Apis::RunV1::ServiceSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceSpec

Returns a new instance of ServiceSpec.



6009
6010
6011
# File 'lib/google/apis/run_v1/classes.rb', line 6009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#templateGoogle::Apis::RunV1::RevisionTemplate

RevisionTemplateSpec describes the data a revision should have when created from a template. Corresponds to the JSON property template



6001
6002
6003
# File 'lib/google/apis/run_v1/classes.rb', line 6001

def template
  @template
end

#trafficArray<Google::Apis::RunV1::TrafficTarget>

Specifies how to distribute traffic over a collection of Knative Revisions and Configurations to the Service's main URL. Corresponds to the JSON property traffic



6007
6008
6009
# File 'lib/google/apis/run_v1/classes.rb', line 6007

def traffic
  @traffic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6014
6015
6016
6017
# File 'lib/google/apis/run_v1/classes.rb', line 6014

def update!(**args)
  @template = args[:template] if args.key?(:template)
  @traffic = args[:traffic] if args.key?(:traffic)
end