Class: Google::Apis::RunV1::ServiceStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

The current state of the Service. Output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceStatus

Returns a new instance of ServiceStatus.



6071
6072
6073
# File 'lib/google/apis/run_v1/classes.rb', line 6071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressGoogle::Apis::RunV1::Addressable

Information for connecting over HTTP(s). Corresponds to the JSON property address



6027
6028
6029
# File 'lib/google/apis/run_v1/classes.rb', line 6027

def address
  @address
end

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicate information about ongoing/complete reconciliation processes that bring the spec inline with the observed state of the world. Service-specific conditions include: * ConfigurationsReady: True when the underlying Configuration is ready. * RoutesReady: True when the underlying Route is ready. * Ready: True when all underlying resources are ready. Corresponds to the JSON property conditions



6036
6037
6038
# File 'lib/google/apis/run_v1/classes.rb', line 6036

def conditions
  @conditions
end

#latest_created_revision_nameString

Name of the last revision that was created from this Service's Configuration. It might not be ready yet, for that use LatestReadyRevisionName. Corresponds to the JSON property latestCreatedRevisionName

Returns:

  • (String)


6042
6043
6044
# File 'lib/google/apis/run_v1/classes.rb', line 6042

def latest_created_revision_name
  @latest_created_revision_name
end

#latest_ready_revision_nameString

Name of the latest Revision from this Service's Configuration that has had its Ready condition become True. Corresponds to the JSON property latestReadyRevisionName

Returns:

  • (String)


6048
6049
6050
# File 'lib/google/apis/run_v1/classes.rb', line 6048

def latest_ready_revision_name
  @latest_ready_revision_name
end

#observed_generationFixnum

Returns the generation last seen by the system. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


6055
6056
6057
# File 'lib/google/apis/run_v1/classes.rb', line 6055

def observed_generation
  @observed_generation
end

#trafficArray<Google::Apis::RunV1::TrafficTarget>

Holds the configured traffic distribution. These entries will always contain RevisionName references. When ConfigurationName appears in the spec, this will hold the LatestReadyRevisionName that we last observed. Corresponds to the JSON property traffic



6062
6063
6064
# File 'lib/google/apis/run_v1/classes.rb', line 6062

def traffic
  @traffic
end

#urlString

URL that will distribute traffic over the provided traffic targets. It generally has the form https://route-hash-project-hash-cluster-level- suffix.a.run.app Corresponds to the JSON property url

Returns:

  • (String)


6069
6070
6071
# File 'lib/google/apis/run_v1/classes.rb', line 6069

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6076
6077
6078
6079
6080
6081
6082
6083
6084
# File 'lib/google/apis/run_v1/classes.rb', line 6076

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @conditions = args[:conditions] if args.key?(:conditions)
  @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name)
  @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @traffic = args[:traffic] if args.key?(:traffic)
  @url = args[:url] if args.key?(:url)
end