Class: Google::Apis::RunV1::Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Task represents a single run of a container to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Task

Returns a new instance of Task.



6393
6394
6395
# File 'lib/google/apis/run_v1/classes.rb', line 6393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


6368
6369
6370
# File 'lib/google/apis/run_v1/classes.rb', line 6368

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


6375
6376
6377
# File 'lib/google/apis/run_v1/classes.rb', line 6375

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



6381
6382
6383
# File 'lib/google/apis/run_v1/classes.rb', line 6381

def 
  @metadata
end

#specGoogle::Apis::RunV1::TaskSpec

TaskSpec is a description of a task. Corresponds to the JSON property spec



6386
6387
6388
# File 'lib/google/apis/run_v1/classes.rb', line 6386

def spec
  @spec
end

#statusGoogle::Apis::RunV1::TaskStatus

TaskStatus represents the status of a task. Corresponds to the JSON property status



6391
6392
6393
# File 'lib/google/apis/run_v1/classes.rb', line 6391

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6398
6399
6400
6401
6402
6403
6404
# File 'lib/google/apis/run_v1/classes.rb', line 6398

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end