Class: Google::Apis::RunV1::TaskSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

TaskSpec is a description of a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskSpec

Returns a new instance of TaskSpec.



6492
6493
6494
# File 'lib/google/apis/run_v1/classes.rb', line 6492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::RunV1::Container>

Optional. List of containers belonging to the task. We disallow a number of fields on this Container. Corresponds to the JSON property containers

Returns:



6456
6457
6458
# File 'lib/google/apis/run_v1/classes.rb', line 6456

def containers
  @containers
end

#max_retriesFixnum

Optional. Number of retries allowed per task, before marking this job failed. Defaults to 3. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


6462
6463
6464
# File 'lib/google/apis/run_v1/classes.rb', line 6462

def max_retries
  @max_retries
end

#node_selectorHash<String,String>

Optional. The Node Selector configuration. Map of selector key to a value which matches a node. Corresponds to the JSON property nodeSelector

Returns:

  • (Hash<String,String>)


6468
6469
6470
# File 'lib/google/apis/run_v1/classes.rb', line 6468

def node_selector
  @node_selector
end

#service_account_nameString

Optional. Email address of the IAM service account associated with the task of a job execution. The service account represents the identity of the running task, and determines what permissions the task has. If not provided, the task will use the project's default service account. Corresponds to the JSON property serviceAccountName

Returns:

  • (String)


6476
6477
6478
# File 'lib/google/apis/run_v1/classes.rb', line 6476

def 
  @service_account_name
end

#timeout_secondsFixnum

Optional. Duration in seconds the task may be active before the system will actively try to mark it failed and kill associated containers. This applies per attempt of a task, meaning each retry can run for the full timeout. Defaults to 600 seconds. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


6484
6485
6486
# File 'lib/google/apis/run_v1/classes.rb', line 6484

def timeout_seconds
  @timeout_seconds
end

#volumesArray<Google::Apis::RunV1::Volume>

Optional. List of volumes that can be mounted by containers belonging to the task. Corresponds to the JSON property volumes

Returns:



6490
6491
6492
# File 'lib/google/apis/run_v1/classes.rb', line 6490

def volumes
  @volumes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/google/apis/run_v1/classes.rb', line 6497

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @service_account_name = args[:service_account_name] if args.key?(:service_account_name)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
  @volumes = args[:volumes] if args.key?(:volumes)
end