Class: Google::Apis::RunV1::TaskStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

TaskStatus represents the status of a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskStatus

Returns a new instance of TaskStatus.



6278
6279
6280
# File 'lib/google/apis/run_v1/classes.rb', line 6278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeString

Optional. Represents time when the task was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC. Corresponds to the JSON property completionTime

Returns:

  • (String)


6233
6234
6235
# File 'lib/google/apis/run_v1/classes.rb', line 6233

def completion_time
  @completion_time
end

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Optional. Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. Task-specific conditions include: * Started: True when the task has started to execute. * Completed: True when the task has succeeded. False when the task has failed. Corresponds to the JSON property conditions



6242
6243
6244
# File 'lib/google/apis/run_v1/classes.rb', line 6242

def conditions
  @conditions
end

#indexFixnum

Required. Index of the task, unique per execution, and beginning at 0. Corresponds to the JSON property index

Returns:

  • (Fixnum)


6247
6248
6249
# File 'lib/google/apis/run_v1/classes.rb', line 6247

def index
  @index
end

#last_attempt_resultGoogle::Apis::RunV1::TaskAttemptResult

Result of a task attempt. Corresponds to the JSON property lastAttemptResult



6252
6253
6254
# File 'lib/google/apis/run_v1/classes.rb', line 6252

def last_attempt_result
  @last_attempt_result
end

#log_uriString

Optional. URI where logs for this task can be found in Cloud Console. Corresponds to the JSON property logUri

Returns:

  • (String)


6257
6258
6259
# File 'lib/google/apis/run_v1/classes.rb', line 6257

def log_uri
  @log_uri
end

#observed_generationFixnum

Optional. The 'generation' of the task that was last processed by the controller. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


6263
6264
6265
# File 'lib/google/apis/run_v1/classes.rb', line 6263

def observed_generation
  @observed_generation
end

#retriedFixnum

Optional. The number of times this task was retried. Instances are retried when they fail up to the maxRetries limit. Corresponds to the JSON property retried

Returns:

  • (Fixnum)


6269
6270
6271
# File 'lib/google/apis/run_v1/classes.rb', line 6269

def retried
  @retried
end

#start_timeString

Optional. Represents time when the task started to run. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC. Corresponds to the JSON property startTime

Returns:

  • (String)


6276
6277
6278
# File 'lib/google/apis/run_v1/classes.rb', line 6276

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
# File 'lib/google/apis/run_v1/classes.rb', line 6283

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @conditions = args[:conditions] if args.key?(:conditions)
  @index = args[:index] if args.key?(:index)
  @last_attempt_result = args[:last_attempt_result] if args.key?(:last_attempt_result)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @retried = args[:retried] if args.key?(:retried)
  @start_time = args[:start_time] if args.key?(:start_time)
end