Class: Google::Apis::RunV1::Volume

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Volume represents a named volume in a container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Volume

Returns a new instance of Volume.



6743
6744
6745
# File 'lib/google/apis/run_v1/classes.rb', line 6743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_mapGoogle::Apis::RunV1::ConfigMapVolumeSource

Not supported by Cloud Run. Adapts a ConfigMap into a volume. The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Corresponds to the JSON property configMap



6708
6709
6710
# File 'lib/google/apis/run_v1/classes.rb', line 6708

def config_map
  @config_map
end

#csiGoogle::Apis::RunV1::CsiVolumeSource

Storage volume source using the Container Storage Interface. Corresponds to the JSON property csi



6713
6714
6715
# File 'lib/google/apis/run_v1/classes.rb', line 6713

def csi
  @csi
end

#empty_dirGoogle::Apis::RunV1::EmptyDirVolumeSource

In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs). Corresponds to the JSON property emptyDir



6720
6721
6722
# File 'lib/google/apis/run_v1/classes.rb', line 6720

def empty_dir
  @empty_dir
end

#nameString

Volume's name. In Cloud Run Fully Managed, the name 'cloudsql' is reserved. Corresponds to the JSON property name

Returns:

  • (String)


6725
6726
6727
# File 'lib/google/apis/run_v1/classes.rb', line 6725

def name
  @name
end

#nfsGoogle::Apis::RunV1::NfsVolumeSource

Represents a persistent volume that will be mounted using NFS. This volume will be shared between all instances of the resource and data will not be deleted when the instance is shut down. Corresponds to the JSON property nfs



6732
6733
6734
# File 'lib/google/apis/run_v1/classes.rb', line 6732

def nfs
  @nfs
end

#secretGoogle::Apis::RunV1::SecretVolumeSource

A volume representing a secret stored in Google Secret Manager. The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret_name. The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Corresponds to the JSON property secret



6741
6742
6743
# File 'lib/google/apis/run_v1/classes.rb', line 6741

def secret
  @secret
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6748
6749
6750
6751
6752
6753
6754
6755
# File 'lib/google/apis/run_v1/classes.rb', line 6748

def update!(**args)
  @config_map = args[:config_map] if args.key?(:config_map)
  @csi = args[:csi] if args.key?(:csi)
  @empty_dir = args[:empty_dir] if args.key?(:empty_dir)
  @name = args[:name] if args.key?(:name)
  @nfs = args[:nfs] if args.key?(:nfs)
  @secret = args[:secret] if args.key?(:secret)
end