Class: Google::Apis::RunV1::WorkerPool
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
WorkerPool acts as a top-level container that manages a set instance splits among a set of Revisions and a template for creating new Revisions.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call.
-
#kind ⇒ String
The kind of resource.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and instance splits.
-
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPool
constructor
A new instance of WorkerPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPool
Returns a new instance of WorkerPool.
6798 6799 6800 |
# File 'lib/google/apis/run_v1/classes.rb', line 6798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call. It must be "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
6774 6775 6776 |
# File 'lib/google/apis/run_v1/classes.rb', line 6774 def api_version @api_version end |
#kind ⇒ String
The kind of resource. It must be "WorkerPool".
Corresponds to the JSON property kind
6779 6780 6781 |
# File 'lib/google/apis/run_v1/classes.rb', line 6779 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
6785 6786 6787 |
# File 'lib/google/apis/run_v1/classes.rb', line 6785 def @metadata end |
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and
instance splits.
Corresponds to the JSON property spec
6791 6792 6793 |
# File 'lib/google/apis/run_v1/classes.rb', line 6791 def spec @spec end |
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool. Output only.
Corresponds to the JSON property status
6796 6797 6798 |
# File 'lib/google/apis/run_v1/classes.rb', line 6796 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6803 6804 6805 6806 6807 6808 6809 |
# File 'lib/google/apis/run_v1/classes.rb', line 6803 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |