Class: Google::Apis::RunV1::Configuration
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Configuration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Configuration represents the "floating HEAD" of a linear history of Revisions, and optionally how the containers those revisions reference are built. Users create new Revisions by updating the Configuration's spec. The "latest created" revision's name is available under status, as is the "latest ready" revision' s name.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#kind ⇒ String
The kind of resource, in this case always "Configuration".
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::ConfigurationSpec
ConfigurationSpec holds the desired state of the Configuration (from the client).
-
#status ⇒ Google::Apis::RunV1::ConfigurationStatus
ConfigurationStatus communicates the observed state of the Configuration (from the controller).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Configuration
constructor
A new instance of Configuration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Configuration
Returns a new instance of Configuration.
461 462 463 |
# File 'lib/google/apis/run_v1/classes.rb', line 461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
436 437 438 |
# File 'lib/google/apis/run_v1/classes.rb', line 436 def api_version @api_version end |
#kind ⇒ String
The kind of resource, in this case always "Configuration".
Corresponds to the JSON property kind
441 442 443 |
# File 'lib/google/apis/run_v1/classes.rb', line 441 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
447 448 449 |
# File 'lib/google/apis/run_v1/classes.rb', line 447 def @metadata end |
#spec ⇒ Google::Apis::RunV1::ConfigurationSpec
ConfigurationSpec holds the desired state of the Configuration (from the
client).
Corresponds to the JSON property spec
453 454 455 |
# File 'lib/google/apis/run_v1/classes.rb', line 453 def spec @spec end |
#status ⇒ Google::Apis::RunV1::ConfigurationStatus
ConfigurationStatus communicates the observed state of the Configuration (from
the controller).
Corresponds to the JSON property status
459 460 461 |
# File 'lib/google/apis/run_v1/classes.rb', line 459 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
466 467 468 469 470 471 472 |
# File 'lib/google/apis/run_v1/classes.rb', line 466 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |