Class: Google::Apis::RunV1::DomainMappingStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

The current state of the Domain Mapping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DomainMappingStatus

Returns a new instance of DomainMappingStatus.



882
883
884
# File 'lib/google/apis/run_v1/classes.rb', line 882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Array of observed DomainMappingConditions, indicating the current state of the DomainMapping. Corresponds to the JSON property conditions



855
856
857
# File 'lib/google/apis/run_v1/classes.rb', line 855

def conditions
  @conditions
end

#mapped_route_nameString

The name of the route that the mapping currently points to. Corresponds to the JSON property mappedRouteName

Returns:

  • (String)


860
861
862
# File 'lib/google/apis/run_v1/classes.rb', line 860

def mapped_route_name
  @mapped_route_name
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the DomainMapping that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


868
869
870
# File 'lib/google/apis/run_v1/classes.rb', line 868

def observed_generation
  @observed_generation
end

#resource_recordsArray<Google::Apis::RunV1::ResourceRecord>

The resource records required to configure this domain mapping. These records must be added to the domain's DNS configuration in order to serve the application via this domain mapping. Corresponds to the JSON property resourceRecords



875
876
877
# File 'lib/google/apis/run_v1/classes.rb', line 875

def resource_records
  @resource_records
end

#urlString

Optional. Not supported by Cloud Run. Corresponds to the JSON property url

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/run_v1/classes.rb', line 880

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



887
888
889
890
891
892
893
# File 'lib/google/apis/run_v1/classes.rb', line 887

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @mapped_route_name = args[:mapped_route_name] if args.key?(:mapped_route_name)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @resource_records = args[:resource_records] if args.key?(:resource_records)
  @url = args[:url] if args.key?(:url)
end