Class: Google::Apis::RunV1::EmptyDirVolumeSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::EmptyDirVolumeSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs).
Instance Attribute Summary collapse
-
#medium ⇒ String
The medium on which the data is stored.
-
#size_limit ⇒ String
Limit on the storage usable by this EmptyDir volume.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmptyDirVolumeSource
constructor
A new instance of EmptyDirVolumeSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmptyDirVolumeSource
Returns a new instance of EmptyDirVolumeSource.
944 945 946 |
# File 'lib/google/apis/run_v1/classes.rb', line 944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#medium ⇒ String
The medium on which the data is stored. The default is "" which means to use
the node's default medium. Must be an empty string (default) or Memory. More
info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir
Corresponds to the JSON property medium
931 932 933 |
# File 'lib/google/apis/run_v1/classes.rb', line 931 def medium @medium end |
#size_limit ⇒ String
Limit on the storage usable by this EmptyDir volume. The size limit is also
applicable for memory medium. The maximum usage on memory medium EmptyDir
would be the minimum value between the SizeLimit specified here and the sum of
memory limits of all containers. The default is nil which means that the limit
is undefined. More info: https://cloud.google.com/run/docs/configuring/in-
memory-volumes#configure-volume. Info in Kubernetes: https://kubernetes.io/
docs/concepts/storage/volumes/#emptydir
Corresponds to the JSON property sizeLimit
942 943 944 |
# File 'lib/google/apis/run_v1/classes.rb', line 942 def size_limit @size_limit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
949 950 951 952 |
# File 'lib/google/apis/run_v1/classes.rb', line 949 def update!(**args) @medium = args[:medium] if args.key?(:medium) @size_limit = args[:size_limit] if args.key?(:size_limit) end |