Class: Google::Apis::RunV1::Execution
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Execution represents the configuration of a single execution. An execution is an immutable resource that references a container image which is run to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
-
#status ⇒ Google::Apis::RunV1::ExecutionStatus
ExecutionStatus represents the current state of an Execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Execution
constructor
A new instance of Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Execution
Returns a new instance of Execution.
1109 1110 1111 |
# File 'lib/google/apis/run_v1/classes.rb', line 1109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
1084 1085 1086 |
# File 'lib/google/apis/run_v1/classes.rb', line 1084 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
1091 1092 1093 |
# File 'lib/google/apis/run_v1/classes.rb', line 1091 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
1097 1098 1099 |
# File 'lib/google/apis/run_v1/classes.rb', line 1097 def @metadata end |
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
Corresponds to the JSON property spec
1102 1103 1104 |
# File 'lib/google/apis/run_v1/classes.rb', line 1102 def spec @spec end |
#status ⇒ Google::Apis::RunV1::ExecutionStatus
ExecutionStatus represents the current state of an Execution.
Corresponds to the JSON property status
1107 1108 1109 |
# File 'lib/google/apis/run_v1/classes.rb', line 1107 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/google/apis/run_v1/classes.rb', line 1114 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |