Class: Google::Apis::RunV1::Execution
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Execution represents the configuration of a single execution. An execution is an immutable resource that references a container image which is run to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
-
#status ⇒ Google::Apis::RunV1::ExecutionStatus
ExecutionStatus represents the current state of an Execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Execution
constructor
A new instance of Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Execution
Returns a new instance of Execution.
1101 1102 1103 |
# File 'lib/google/apis/run_v1/classes.rb', line 1101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
1076 1077 1078 |
# File 'lib/google/apis/run_v1/classes.rb', line 1076 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
1083 1084 1085 |
# File 'lib/google/apis/run_v1/classes.rb', line 1083 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
1089 1090 1091 |
# File 'lib/google/apis/run_v1/classes.rb', line 1089 def @metadata end |
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
Corresponds to the JSON property spec
1094 1095 1096 |
# File 'lib/google/apis/run_v1/classes.rb', line 1094 def spec @spec end |
#status ⇒ Google::Apis::RunV1::ExecutionStatus
ExecutionStatus represents the current state of an Execution.
Corresponds to the JSON property status
1099 1100 1101 |
# File 'lib/google/apis/run_v1/classes.rb', line 1099 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/google/apis/run_v1/classes.rb', line 1106 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |