Class: Google::Apis::RunV1::ExecutionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ExecutionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ExecutionSpec describes how the execution will look.
Instance Attribute Summary collapse
-
#parallelism ⇒ Fixnum
Optional.
-
#task_count ⇒ Fixnum
Optional.
-
#template ⇒ Google::Apis::RunV1::TaskTemplateSpec
TaskTemplateSpec describes the data a task should have when created from a template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutionSpec
constructor
A new instance of ExecutionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutionSpec
Returns a new instance of ExecutionSpec.
1186 1187 1188 |
# File 'lib/google/apis/run_v1/classes.rb', line 1186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parallelism ⇒ Fixnum
Optional. Specifies the maximum desired number of tasks the execution should
run at given time. When the job is run, if this field is 0 or unset, the
maximum possible value will be used for that execution. The actual number of
tasks running in steady state will be less than this number when there are
fewer tasks waiting to be completed, i.e. when the work left to do is less
than max parallelism.
Corresponds to the JSON property parallelism
1171 1172 1173 |
# File 'lib/google/apis/run_v1/classes.rb', line 1171 def parallelism @parallelism end |
#task_count ⇒ Fixnum
Optional. Specifies the desired number of tasks the execution should run.
Setting to 1 means that parallelism is limited to 1 and the success of that
task signals the success of the execution. Defaults to 1.
Corresponds to the JSON property taskCount
1178 1179 1180 |
# File 'lib/google/apis/run_v1/classes.rb', line 1178 def task_count @task_count end |
#template ⇒ Google::Apis::RunV1::TaskTemplateSpec
TaskTemplateSpec describes the data a task should have when created from a
template.
Corresponds to the JSON property template
1184 1185 1186 |
# File 'lib/google/apis/run_v1/classes.rb', line 1184 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1191 1192 1193 1194 1195 |
# File 'lib/google/apis/run_v1/classes.rb', line 1191 def update!(**args) @parallelism = args[:parallelism] if args.key?(:parallelism) @task_count = args[:task_count] if args.key?(:task_count) @template = args[:template] if args.key?(:template) end |