Class: Google::Apis::RunV1::ExecutionTemplateSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ExecutionTemplateSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.
Instance Attribute Summary collapse
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutionTemplateSpec
constructor
A new instance of ExecutionTemplateSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutionTemplateSpec
Returns a new instance of ExecutionTemplateSpec.
1297 1298 1299 |
# File 'lib/google/apis/run_v1/classes.rb', line 1297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
1290 1291 1292 |
# File 'lib/google/apis/run_v1/classes.rb', line 1290 def @metadata end |
#spec ⇒ Google::Apis::RunV1::ExecutionSpec
ExecutionSpec describes how the execution will look.
Corresponds to the JSON property spec
1295 1296 1297 |
# File 'lib/google/apis/run_v1/classes.rb', line 1295 def spec @spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1302 1303 1304 1305 |
# File 'lib/google/apis/run_v1/classes.rb', line 1302 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) end |