Class: Google::Apis::RunV1::GoogleCloudRunV1Condition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Conditions show the status of reconciliation progress on a given resource. Most resource use a top-level condition type "Ready" or "Completed" to show overall status with other conditions to checkpoint each stage of reconciliation. Note that if metadata.Generation does not equal status. ObservedGeneration, the conditions shown may not be relevant for the current spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV1Condition

Returns a new instance of GoogleCloudRunV1Condition.



1441
1442
1443
# File 'lib/google/apis/run_v1/classes.rb', line 1441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Optional. Last time the condition transitioned from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/run_v1/classes.rb', line 1408

def last_transition_time
  @last_transition_time
end

#messageString

Optional. Human readable message indicating details about the current status. Corresponds to the JSON property message

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/run_v1/classes.rb', line 1413

def message
  @message
end

#reasonString

Optional. One-word CamelCase reason for the condition's last transition. These are intended to be stable, unique values which the client may use to trigger error handling logic, whereas messages which may be changed later by the server. Corresponds to the JSON property reason

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/run_v1/classes.rb', line 1421

def reason
  @reason
end

#severityString

Optional. How to interpret this condition. One of Error, Warning, or Info. Conditions of severity Info do not contribute to resource readiness. Corresponds to the JSON property severity

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/run_v1/classes.rb', line 1427

def severity
  @severity
end

#statusString

Status of the condition, one of True, False, Unknown. Corresponds to the JSON property status

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/run_v1/classes.rb', line 1432

def status
  @status
end

#typeString

type is used to communicate the status of the reconciliation process. Types common to all resources include: * "Ready" or "Completed": True when the Resource is ready. Corresponds to the JSON property type

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/run_v1/classes.rb', line 1439

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1446
1447
1448
1449
1450
1451
1452
1453
# File 'lib/google/apis/run_v1/classes.rb', line 1446

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @severity = args[:severity] if args.key?(:severity)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end