Class: Google::Apis::RunV1::GoogleCloudRunV1Condition
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleCloudRunV1Condition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Conditions show the status of reconciliation progress on a given resource. Most resource use a top-level condition type "Ready" or "Completed" to show overall status with other conditions to checkpoint each stage of reconciliation. Note that if metadata.Generation does not equal status. ObservedGeneration, the conditions shown may not be relevant for the current spec.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Optional.
-
#message ⇒ String
Optional.
-
#reason ⇒ String
Optional.
-
#severity ⇒ String
Optional.
-
#status ⇒ String
Status of the condition, one of True, False, Unknown.
-
#type ⇒ String
type is used to communicate the status of the reconciliation process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV1Condition
constructor
A new instance of GoogleCloudRunV1Condition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV1Condition
Returns a new instance of GoogleCloudRunV1Condition.
1433 1434 1435 |
# File 'lib/google/apis/run_v1/classes.rb', line 1433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Optional. Last time the condition transitioned from one status to another.
Corresponds to the JSON property lastTransitionTime
1400 1401 1402 |
# File 'lib/google/apis/run_v1/classes.rb', line 1400 def last_transition_time @last_transition_time end |
#message ⇒ String
Optional. Human readable message indicating details about the current status.
Corresponds to the JSON property message
1405 1406 1407 |
# File 'lib/google/apis/run_v1/classes.rb', line 1405 def @message end |
#reason ⇒ String
Optional. One-word CamelCase reason for the condition's last transition. These
are intended to be stable, unique values which the client may use to trigger
error handling logic, whereas messages which may be changed later by the
server.
Corresponds to the JSON property reason
1413 1414 1415 |
# File 'lib/google/apis/run_v1/classes.rb', line 1413 def reason @reason end |
#severity ⇒ String
Optional. How to interpret this condition. One of Error, Warning, or Info.
Conditions of severity Info do not contribute to resource readiness.
Corresponds to the JSON property severity
1419 1420 1421 |
# File 'lib/google/apis/run_v1/classes.rb', line 1419 def severity @severity end |
#status ⇒ String
Status of the condition, one of True, False, Unknown.
Corresponds to the JSON property status
1424 1425 1426 |
# File 'lib/google/apis/run_v1/classes.rb', line 1424 def status @status end |
#type ⇒ String
type is used to communicate the status of the reconciliation process. Types
common to all resources include: * "Ready" or "Completed": True when the
Resource is ready.
Corresponds to the JSON property type
1431 1432 1433 |
# File 'lib/google/apis/run_v1/classes.rb', line 1431 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1438 1439 1440 1441 1442 1443 1444 1445 |
# File 'lib/google/apis/run_v1/classes.rb', line 1438 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @severity = args[:severity] if args.key?(:severity) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |