Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Artifacts
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Artifacts
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GoModule>
Optional.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#objects ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
-
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts
constructor
A new instance of GoogleDevtoolsCloudbuildV1Artifacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts
Returns a new instance of GoogleDevtoolsCloudbuildV1Artifacts.
1605 1606 1607 |
# File 'lib/google/apis/run_v1/classes.rb', line 1605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GoModule>
Optional. A list of Go modules to be uploaded to Artifact Registry upon
successful completion of all build steps. If any objects fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property goModules
1562 1563 1564 |
# File 'lib/google/apis/run_v1/classes.rb', line 1562 def go_modules @go_modules end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images will be pushed using the builder service account's
credentials. The digests of the pushed images will be stored in the Build
resource's results field. If any of the images fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property images
1571 1572 1573 |
# File 'lib/google/apis/run_v1/classes.rb', line 1571 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful
completion of all build steps. Artifacts in the workspace matching specified
paths globs will be uploaded to the specified Artifact Registry repository
using the builder service account's credentials. If any artifacts fail to be
pushed, the build is marked FAILURE.
Corresponds to the JSON property mavenArtifacts
1580 1581 1582 |
# File 'lib/google/apis/run_v1/classes.rb', line 1580 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful
completion of all build steps. Npm packages in the specified paths will be
uploaded to the specified Artifact Registry repository using the builder
service account's credentials. If any packages fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property npmPackages
1589 1590 1591 |
# File 'lib/google/apis/run_v1/classes.rb', line 1589 def npm_packages @npm_packages end |
#objects ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion
of all build steps.
Corresponds to the JSON property objects
1595 1596 1597 |
# File 'lib/google/apis/run_v1/classes.rb', line 1595 def objects @objects end |
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful
completion of all build steps. The build service account credentials will be
used to perform the upload. If any objects fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property pythonPackages
1603 1604 1605 |
# File 'lib/google/apis/run_v1/classes.rb', line 1603 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1610 1611 1612 1613 1614 1615 1616 1617 |
# File 'lib/google/apis/run_v1/classes.rb', line 1610 def update!(**args) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @objects = args[:objects] if args.key?(:objects) @python_packages = args[:python_packages] if args.key?(:python_packages) end |