Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildApproval
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildApproval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
BuildApproval describes a build's approval configuration, state, and result.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalConfig
ApprovalConfig describes configuration for manual approval of a build.
-
#result ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalResult
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildApproval
constructor
A new instance of GoogleDevtoolsCloudbuildV1BuildApproval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildApproval
Returns a new instance of GoogleDevtoolsCloudbuildV1BuildApproval.
1878 1879 1880 |
# File 'lib/google/apis/run_v1/classes.rb', line 1878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalConfig
ApprovalConfig describes configuration for manual approval of a build.
Corresponds to the JSON property config
1865 1866 1867 |
# File 'lib/google/apis/run_v1/classes.rb', line 1865 def config @config end |
#result ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ApprovalResult
ApprovalResult describes the decision and associated metadata of a manual
approval of a build.
Corresponds to the JSON property result
1871 1872 1873 |
# File 'lib/google/apis/run_v1/classes.rb', line 1871 def result @result end |
#state ⇒ String
Output only. The state of this build's approval.
Corresponds to the JSON property state
1876 1877 1878 |
# File 'lib/google/apis/run_v1/classes.rb', line 1876 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1883 1884 1885 1886 1887 |
# File 'lib/google/apis/run_v1/classes.rb', line 1883 def update!(**args) @config = args[:config] if args.key?(:config) @result = args[:result] if args.key?(:result) @state = args[:state] if args.key?(:state) end |