Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildOptions
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Optional arguments to enable specific features of builds.
Instance Attribute Summary collapse
-
#automap_substitutions ⇒ Boolean
(also: #automap_substitutions?)
Option to include built-in and custom substitutions as env variables for all build steps.
-
#default_logs_bucket_behavior ⇒ String
Optional.
-
#disk_size_gb ⇒ Fixnum
Requested disk size for the VM that runs the build.
-
#dynamic_substitutions ⇒ Boolean
(also: #dynamic_substitutions?)
Option to specify whether or not to apply bash style string operations to the substitutions.
-
#enable_structured_logging ⇒ Boolean
(also: #enable_structured_logging?)
Optional.
-
#env ⇒ Array<String>
A list of global environment variable definitions that will exist for all build steps in this build.
-
#log_streaming_option ⇒ String
Option to define build log streaming behavior to Cloud Storage.
-
#logging ⇒ String
Option to specify the logging mode, which determines if and where build logs are stored.
-
#machine_type ⇒ String
Compute Engine machine type on which to run the build.
-
#pool ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1PoolOption
Details about how a build should be executed on a
WorkerPool. -
#pubsub_topic ⇒ String
Optional.
-
#requested_verify_option ⇒ String
Requested verifiability options.
-
#secret_env ⇒ Array<String>
A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key.
-
#source_provenance_hash ⇒ Array<String>
Requested hash for SourceProvenance.
-
#substitution_option ⇒ String
Option to specify behavior when there is an error in the substitution checks.
-
#volumes ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Volume>
Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process.
-
#worker_pool ⇒ String
This field deprecated; please use
pool.nameinstead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildOptions
constructor
A new instance of GoogleDevtoolsCloudbuildV1BuildOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildOptions
Returns a new instance of GoogleDevtoolsCloudbuildV1BuildOptions.
2055 2056 2057 |
# File 'lib/google/apis/run_v1/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automap_substitutions ⇒ Boolean Also known as: automap_substitutions?
Option to include built-in and custom substitutions as env variables for all
build steps.
Corresponds to the JSON property automapSubstitutions
1946 1947 1948 |
# File 'lib/google/apis/run_v1/classes.rb', line 1946 def automap_substitutions @automap_substitutions end |
#default_logs_bucket_behavior ⇒ String
Optional. Option to specify how default logs buckets are setup.
Corresponds to the JSON property defaultLogsBucketBehavior
1952 1953 1954 |
# File 'lib/google/apis/run_v1/classes.rb', line 1952 def default_logs_bucket_behavior @default_logs_bucket_behavior end |
#disk_size_gb ⇒ Fixnum
Requested disk size for the VM that runs the build. Note that this is NOT "
disk free"; some of the space will be used by the operating system and build
utilities. Also note that this is the minimum disk size that will be allocated
for the build -- the build may run with a larger disk than requested. At
present, the maximum disk size is 4000GB; builds that request more than the
maximum are rejected with an error.
Corresponds to the JSON property diskSizeGb
1962 1963 1964 |
# File 'lib/google/apis/run_v1/classes.rb', line 1962 def disk_size_gb @disk_size_gb end |
#dynamic_substitutions ⇒ Boolean Also known as: dynamic_substitutions?
Option to specify whether or not to apply bash style string operations to the
substitutions. NOTE: this is always enabled for triggered builds and cannot be
overridden in the build configuration file.
Corresponds to the JSON property dynamicSubstitutions
1969 1970 1971 |
# File 'lib/google/apis/run_v1/classes.rb', line 1969 def dynamic_substitutions @dynamic_substitutions end |
#enable_structured_logging ⇒ Boolean Also known as: enable_structured_logging?
Optional. Option to specify whether structured logging is enabled. If true,
JSON-formatted logs are parsed as structured logs.
Corresponds to the JSON property enableStructuredLogging
1976 1977 1978 |
# File 'lib/google/apis/run_v1/classes.rb', line 1976 def enable_structured_logging @enable_structured_logging end |
#env ⇒ Array<String>
A list of global environment variable definitions that will exist for all
build steps in this build. If a variable is defined in both globally and in a
build step, the variable will use the build step value. The elements are of
the form "KEY=VALUE" for the environment variable "KEY" being given the value "
VALUE".
Corresponds to the JSON property env
1986 1987 1988 |
# File 'lib/google/apis/run_v1/classes.rb', line 1986 def env @env end |
#log_streaming_option ⇒ String
Option to define build log streaming behavior to Cloud Storage.
Corresponds to the JSON property logStreamingOption
1991 1992 1993 |
# File 'lib/google/apis/run_v1/classes.rb', line 1991 def log_streaming_option @log_streaming_option end |
#logging ⇒ String
Option to specify the logging mode, which determines if and where build logs
are stored.
Corresponds to the JSON property logging
1997 1998 1999 |
# File 'lib/google/apis/run_v1/classes.rb', line 1997 def logging @logging end |
#machine_type ⇒ String
Compute Engine machine type on which to run the build.
Corresponds to the JSON property machineType
2002 2003 2004 |
# File 'lib/google/apis/run_v1/classes.rb', line 2002 def machine_type @machine_type end |
#pool ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1PoolOption
Details about how a build should be executed on a WorkerPool. See running
builds in a private pool for more information.
Corresponds to the JSON property pool
2009 2010 2011 |
# File 'lib/google/apis/run_v1/classes.rb', line 2009 def pool @pool end |
#pubsub_topic ⇒ String
Optional. Option to specify the Pub/Sub topic to receive build status updates.
Corresponds to the JSON property pubsubTopic
2014 2015 2016 |
# File 'lib/google/apis/run_v1/classes.rb', line 2014 def pubsub_topic @pubsub_topic end |
#requested_verify_option ⇒ String
Requested verifiability options.
Corresponds to the JSON property requestedVerifyOption
2019 2020 2021 |
# File 'lib/google/apis/run_v1/classes.rb', line 2019 def requested_verify_option @requested_verify_option end |
#secret_env ⇒ Array<String>
A list of global environment variables, which are encrypted using a Cloud Key
Management Service crypto key. These values must be specified in the build's
Secret. These variables will be available to all build steps in this build.
Corresponds to the JSON property secretEnv
2026 2027 2028 |
# File 'lib/google/apis/run_v1/classes.rb', line 2026 def secret_env @secret_env end |
#source_provenance_hash ⇒ Array<String>
Requested hash for SourceProvenance.
Corresponds to the JSON property sourceProvenanceHash
2031 2032 2033 |
# File 'lib/google/apis/run_v1/classes.rb', line 2031 def source_provenance_hash @source_provenance_hash end |
#substitution_option ⇒ String
Option to specify behavior when there is an error in the substitution checks.
NOTE: this is always set to ALLOW_LOOSE for triggered builds and cannot be
overridden in the build configuration file.
Corresponds to the JSON property substitutionOption
2038 2039 2040 |
# File 'lib/google/apis/run_v1/classes.rb', line 2038 def substitution_option @substitution_option end |
#volumes ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Volume>
Global list of volumes to mount for ALL build steps Each volume is created as
an empty volume prior to starting the build process. Upon completion of the
build, volumes and their contents are discarded. Global volume names and paths
cannot conflict with the volumes defined a build step. Using a global volume
in a build with only one step is not valid as it is indicative of a build
request with an incorrect configuration.
Corresponds to the JSON property volumes
2048 2049 2050 |
# File 'lib/google/apis/run_v1/classes.rb', line 2048 def volumes @volumes end |
#worker_pool ⇒ String
This field deprecated; please use pool.name instead.
Corresponds to the JSON property workerPool
2053 2054 2055 |
# File 'lib/google/apis/run_v1/classes.rb', line 2053 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/google/apis/run_v1/classes.rb', line 2060 def update!(**args) @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions) @default_logs_bucket_behavior = args[:default_logs_bucket_behavior] if args.key?(:default_logs_bucket_behavior) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @dynamic_substitutions = args[:dynamic_substitutions] if args.key?(:dynamic_substitutions) @enable_structured_logging = args[:enable_structured_logging] if args.key?(:enable_structured_logging) @env = args[:env] if args.key?(:env) @log_streaming_option = args[:log_streaming_option] if args.key?(:log_streaming_option) @logging = args[:logging] if args.key?(:logging) @machine_type = args[:machine_type] if args.key?(:machine_type) @pool = args[:pool] if args.key?(:pool) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @requested_verify_option = args[:requested_verify_option] if args.key?(:requested_verify_option) @secret_env = args[:secret_env] if args.key?(:secret_env) @source_provenance_hash = args[:source_provenance_hash] if args.key?(:source_provenance_hash) @substitution_option = args[:substitution_option] if args.key?(:substitution_option) @volumes = args[:volumes] if args.key?(:volumes) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |