Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
An image built by the pipeline.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#digest ⇒ String
Docker Registry 2.0 digest.
-
#name ⇒ String
Name used to push the container image to Google Container Registry, as presented to
docker push. -
#oci_media_type ⇒ String
Output only.
-
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage
constructor
A new instance of GoogleDevtoolsCloudbuildV1BuiltImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage
Returns a new instance of GoogleDevtoolsCloudbuildV1BuiltImage.
2279 2280 2281 |
# File 'lib/google/apis/run_v1/classes.rb', line 2279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
2255 2256 2257 |
# File 'lib/google/apis/run_v1/classes.rb', line 2255 def artifact_registry_package @artifact_registry_package end |
#digest ⇒ String
Docker Registry 2.0 digest.
Corresponds to the JSON property digest
2260 2261 2262 |
# File 'lib/google/apis/run_v1/classes.rb', line 2260 def digest @digest end |
#name ⇒ String
Name used to push the container image to Google Container Registry, as
presented to docker push.
Corresponds to the JSON property name
2266 2267 2268 |
# File 'lib/google/apis/run_v1/classes.rb', line 2266 def name @name end |
#oci_media_type ⇒ String
Output only. The OCI media type of the artifact. Non-OCI images, such as
Docker images, will have an unspecified value.
Corresponds to the JSON property ociMediaType
2272 2273 2274 |
# File 'lib/google/apis/run_v1/classes.rb', line 2272 def oci_media_type @oci_media_type end |
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
2277 2278 2279 |
# File 'lib/google/apis/run_v1/classes.rb', line 2277 def push_timing @push_timing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2284 2285 2286 2287 2288 2289 2290 |
# File 'lib/google/apis/run_v1/classes.rb', line 2284 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type) @push_timing = args[:push_timing] if args.key?(:push_timing) end |