Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

An image built by the pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage

Returns a new instance of GoogleDevtoolsCloudbuildV1BuiltImage.



2255
2256
2257
# File 'lib/google/apis/run_v1/classes.rb', line 2255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/run_v1/classes.rb', line 2237

def artifact_registry_package
  @artifact_registry_package
end

#digestString

Docker Registry 2.0 digest. Corresponds to the JSON property digest

Returns:

  • (String)


2242
2243
2244
# File 'lib/google/apis/run_v1/classes.rb', line 2242

def digest
  @digest
end

#nameString

Name used to push the container image to Google Container Registry, as presented to docker push. Corresponds to the JSON property name

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/run_v1/classes.rb', line 2248

def name
  @name
end

#push_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



2253
2254
2255
# File 'lib/google/apis/run_v1/classes.rb', line 2253

def push_timing
  @push_timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2260
2261
2262
2263
2264
2265
# File 'lib/google/apis/run_v1/classes.rb', line 2260

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @digest = args[:digest] if args.key?(:digest)
  @name = args[:name] if args.key?(:name)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
end