Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1ConnectedRepository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Location of the source in a 2nd-gen Google Cloud Build repository resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ConnectedRepository

Returns a new instance of GoogleDevtoolsCloudbuildV1ConnectedRepository.



2289
2290
2291
# File 'lib/google/apis/run_v1/classes.rb', line 2289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Optional. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/run_v1/classes.rb', line 2275

def dir
  @dir
end

#repositoryString

Required. Name of the Google Cloud Build repository, formatted as projects/*/ locations/*/connections/*/repositories/*. Corresponds to the JSON property repository

Returns:

  • (String)


2281
2282
2283
# File 'lib/google/apis/run_v1/classes.rb', line 2281

def repository
  @repository
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2287
2288
2289
# File 'lib/google/apis/run_v1/classes.rb', line 2287

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2294
2295
2296
2297
2298
# File 'lib/google/apis/run_v1/classes.rb', line 2294

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end