Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.



2348
2349
2350
# File 'lib/google/apis/run_v1/classes.rb', line 2348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


2335
2336
2337
# File 'lib/google/apis/run_v1/classes.rb', line 2335

def empty
  @empty
end

#generic_artifactGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



2341
2342
2343
# File 'lib/google/apis/run_v1/classes.rb', line 2341

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



2346
2347
2348
# File 'lib/google/apis/run_v1/classes.rb', line 2346

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2353
2354
2355
2356
2357
# File 'lib/google/apis/run_v1/classes.rb', line 2353

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end