Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Dependency
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Dependency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A dependency that the Cloud Build worker will fetch before executing user steps.
Instance Attribute Summary collapse
-
#empty ⇒ Boolean
(also: #empty?)
If set to true disable all dependency fetching (ignoring the default source as well).
-
#git_source ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
constructor
A new instance of GoogleDevtoolsCloudbuildV1Dependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.
2318 2319 2320 |
# File 'lib/google/apis/run_v1/classes.rb', line 2318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#empty ⇒ Boolean Also known as: empty?
If set to true disable all dependency fetching (ignoring the default source as
well).
Corresponds to the JSON property empty
2310 2311 2312 |
# File 'lib/google/apis/run_v1/classes.rb', line 2310 def empty @empty end |
#git_source ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Corresponds to the JSON property gitSource
2316 2317 2318 |
# File 'lib/google/apis/run_v1/classes.rb', line 2316 def git_source @git_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2323 2324 2325 2326 |
# File 'lib/google/apis/run_v1/classes.rb', line 2323 def update!(**args) @empty = args[:empty] if args.key?(:empty) @git_source = args[:git_source] if args.key?(:git_source) end |