Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

This config defines the location of a source through Developer Connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Returns a new instance of GoogleDevtoolsCloudbuildV1DeveloperConnectConfig.



2381
2382
2383
# File 'lib/google/apis/run_v1/classes.rb', line 2381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/run_v1/classes.rb', line 2367

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


2373
2374
2375
# File 'lib/google/apis/run_v1/classes.rb', line 2373

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/run_v1/classes.rb', line 2379

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2386
2387
2388
2389
2390
# File 'lib/google/apis/run_v1/classes.rb', line 2386

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end