Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FileHashes

Returns a new instance of GoogleDevtoolsCloudbuildV1FileHashes.



2428
2429
2430
# File 'lib/google/apis/run_v1/classes.rb', line 2428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Hash>

Collection of file hashes. Corresponds to the JSON property fileHash



2426
2427
2428
# File 'lib/google/apis/run_v1/classes.rb', line 2426

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2433
2434
2435
# File 'lib/google/apis/run_v1/classes.rb', line 2433

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end