Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency

Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.



2583
2584
2585
# File 'lib/google/apis/run_v1/classes.rb', line 2583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2560
2561
2562
# File 'lib/google/apis/run_v1/classes.rb', line 2560

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/run_v1/classes.rb', line 2565

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2570
2571
2572
# File 'lib/google/apis/run_v1/classes.rb', line 2570

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2576
2577
2578
# File 'lib/google/apis/run_v1/classes.rb', line 2576

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2581
2582
2583
# File 'lib/google/apis/run_v1/classes.rb', line 2581

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2588
2589
2590
2591
2592
2593
2594
# File 'lib/google/apis/run_v1/classes.rb', line 2588

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end