Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency

Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.



2497
2498
2499
# File 'lib/google/apis/run_v1/classes.rb', line 2497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


2474
2475
2476
# File 'lib/google/apis/run_v1/classes.rb', line 2474

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/run_v1/classes.rb', line 2479

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


2484
2485
2486
# File 'lib/google/apis/run_v1/classes.rb', line 2484

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



2490
2491
2492
# File 'lib/google/apis/run_v1/classes.rb', line 2490

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/run_v1/classes.rb', line 2495

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2502
2503
2504
2505
2506
2507
2508
# File 'lib/google/apis/run_v1/classes.rb', line 2502

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end