Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GoModule
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1GoModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Go module to upload to Artifact Registry upon successful completion of all build steps. A module refers to all dependencies in a go.mod file.
Instance Attribute Summary collapse
-
#module_path ⇒ String
Optional.
-
#module_version ⇒ String
Optional.
-
#repository_location ⇒ String
Optional.
-
#repository_name ⇒ String
Optional.
-
#repository_project_id ⇒ String
Optional.
-
#source_path ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GoModule
constructor
A new instance of GoogleDevtoolsCloudbuildV1GoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GoModule
Returns a new instance of GoogleDevtoolsCloudbuildV1GoModule.
2580 2581 2582 |
# File 'lib/google/apis/run_v1/classes.rb', line 2580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#module_path ⇒ String
Optional. The Go module's "module path". e.g. example.com/foo/v2
Corresponds to the JSON property modulePath
2545 2546 2547 |
# File 'lib/google/apis/run_v1/classes.rb', line 2545 def module_path @module_path end |
#module_version ⇒ String
Optional. The Go module's semantic version in the form vX.Y.Z. e.g. v0.1.1 Pre-
release identifiers can also be added by appending a dash and dot separated
ASCII alphanumeric characters and hyphens. e.g. v0.2.3-alpha.x.12m.5
Corresponds to the JSON property moduleVersion
2552 2553 2554 |
# File 'lib/google/apis/run_v1/classes.rb', line 2552 def module_version @module_version end |
#repository_location ⇒ String
Optional. Location of the Artifact Registry repository. i.e. us-east1 Defaults
to the build’s location.
Corresponds to the JSON property repositoryLocation
2558 2559 2560 |
# File 'lib/google/apis/run_v1/classes.rb', line 2558 def repository_location @repository_location end |
#repository_name ⇒ String
Optional. Artifact Registry repository name. Specified Go modules will be
zipped and uploaded to Artifact Registry with this location as a prefix. e.g.
my-go-repo
Corresponds to the JSON property repositoryName
2565 2566 2567 |
# File 'lib/google/apis/run_v1/classes.rb', line 2565 def repository_name @repository_name end |
#repository_project_id ⇒ String
Optional. Project ID of the Artifact Registry repository. Defaults to the
build project.
Corresponds to the JSON property repositoryProjectId
2571 2572 2573 |
# File 'lib/google/apis/run_v1/classes.rb', line 2571 def repository_project_id @repository_project_id end |
#source_path ⇒ String
Optional. Source path of the go.mod file in the build's workspace. If not
specified, this will default to the current directory. e.g. ~/code/go/
mypackage
Corresponds to the JSON property sourcePath
2578 2579 2580 |
# File 'lib/google/apis/run_v1/classes.rb', line 2578 def source_path @source_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2585 2586 2587 2588 2589 2590 2591 2592 |
# File 'lib/google/apis/run_v1/classes.rb', line 2585 def update!(**args) @module_path = args[:module_path] if args.key?(:module_path) @module_version = args[:module_version] if args.key?(:module_version) @repository_location = args[:repository_location] if args.key?(:repository_location) @repository_name = args[:repository_name] if args.key?(:repository_name) @repository_project_id = args[:repository_project_id] if args.key?(:repository_project_id) @source_path = args[:source_path] if args.key?(:source_path) end |