Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Oci
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Oci
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
OCI image to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#file ⇒ String
Required.
-
#registry_path ⇒ String
Required.
-
#tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Oci
constructor
A new instance of GoogleDevtoolsCloudbuildV1Oci.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Oci
Returns a new instance of GoogleDevtoolsCloudbuildV1Oci.
2868 2869 2870 |
# File 'lib/google/apis/run_v1/classes.rb', line 2868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Required. Path on the local file system where to find the container to upload.
e.g. /workspace/my-image.tar
Corresponds to the JSON property file
2855 2856 2857 |
# File 'lib/google/apis/run_v1/classes.rb', line 2855 def file @file end |
#registry_path ⇒ String
Required. Registry path to upload the container to. e.g. us-east1-docker.pkg.
dev/my-project/my-repo/my-image
Corresponds to the JSON property registryPath
2861 2862 2863 |
# File 'lib/google/apis/run_v1/classes.rb', line 2861 def registry_path @registry_path end |
#tags ⇒ Array<String>
Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0
Corresponds to the JSON property tags
2866 2867 2868 |
# File 'lib/google/apis/run_v1/classes.rb', line 2866 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2873 2874 2875 2876 2877 |
# File 'lib/google/apis/run_v1/classes.rb', line 2873 def update!(**args) @file = args[:file] if args.key?(:file) @registry_path = args[:registry_path] if args.key?(:registry_path) @tags = args[:tags] if args.key?(:tags) end |