Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#build_step_results ⇒ Hash<String,Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps.
-
#generic_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
constructor
A new instance of GoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
Returns a new instance of GoogleDevtoolsCloudbuildV1Results.
3109 3110 3111 |
# File 'lib/google/apis/run_v1/classes.rb', line 3109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
3045 3046 3047 |
# File 'lib/google/apis/run_v1/classes.rb', line 3045 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
3050 3051 3052 |
# File 'lib/google/apis/run_v1/classes.rb', line 3050 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
3055 3056 3057 |
# File 'lib/google/apis/run_v1/classes.rb', line 3055 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
3064 3065 3066 |
# File 'lib/google/apis/run_v1/classes.rb', line 3064 def build_step_outputs @build_step_outputs end |
#build_step_results ⇒ Hash<String,Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps. step_id ->
Corresponds to the JSON property buildStepResults
3069 3070 3071 |
# File 'lib/google/apis/run_v1/classes.rb', line 3069 def build_step_results @build_step_results end |
#generic_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
3075 3076 3077 |
# File 'lib/google/apis/run_v1/classes.rb', line 3075 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
3081 3082 3083 |
# File 'lib/google/apis/run_v1/classes.rb', line 3081 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
3086 3087 3088 |
# File 'lib/google/apis/run_v1/classes.rb', line 3086 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
3091 3092 3093 |
# File 'lib/google/apis/run_v1/classes.rb', line 3091 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
3096 3097 3098 |
# File 'lib/google/apis/run_v1/classes.rb', line 3096 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
3102 3103 3104 |
# File 'lib/google/apis/run_v1/classes.rb', line 3102 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
3107 3108 3109 |
# File 'lib/google/apis/run_v1/classes.rb', line 3107 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 |
# File 'lib/google/apis/run_v1/classes.rb', line 3114 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @build_step_results = args[:build_step_results] if args.key?(:build_step_results) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |