Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results

Returns a new instance of GoogleDevtoolsCloudbuildV1Results.



3101
3102
3103
# File 'lib/google/apis/run_v1/classes.rb', line 3101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


3037
3038
3039
# File 'lib/google/apis/run_v1/classes.rb', line 3037

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



3042
3043
3044
# File 'lib/google/apis/run_v1/classes.rb', line 3042

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


3047
3048
3049
# File 'lib/google/apis/run_v1/classes.rb', line 3047

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


3056
3057
3058
# File 'lib/google/apis/run_v1/classes.rb', line 3056

def build_step_outputs
  @build_step_outputs
end

#build_step_resultsHash<String,Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuildStepResults>

Results for build steps. step_id -> Corresponds to the JSON property buildStepResults



3061
3062
3063
# File 'lib/google/apis/run_v1/classes.rb', line 3061

def build_step_results
  @build_step_results
end

#generic_artifactsArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>

Output only. Generic artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property genericArtifacts



3067
3068
3069
# File 'lib/google/apis/run_v1/classes.rb', line 3067

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



3073
3074
3075
# File 'lib/google/apis/run_v1/classes.rb', line 3073

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



3078
3079
3080
# File 'lib/google/apis/run_v1/classes.rb', line 3078

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



3083
3084
3085
# File 'lib/google/apis/run_v1/classes.rb', line 3083

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



3088
3089
3090
# File 'lib/google/apis/run_v1/classes.rb', line 3088

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


3094
3095
3096
# File 'lib/google/apis/run_v1/classes.rb', line 3094

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



3099
3100
3101
# File 'lib/google/apis/run_v1/classes.rb', line 3099

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
# File 'lib/google/apis/run_v1/classes.rb', line 3106

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @build_step_results = args[:build_step_results] if args.key?(:build_step_results)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end