Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Results
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#generic_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
constructor
A new instance of GoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
Returns a new instance of GoogleDevtoolsCloudbuildV1Results.
3071 3072 3073 |
# File 'lib/google/apis/run_v1/classes.rb', line 3071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
3012 3013 3014 |
# File 'lib/google/apis/run_v1/classes.rb', line 3012 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
3017 3018 3019 |
# File 'lib/google/apis/run_v1/classes.rb', line 3017 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
3022 3023 3024 |
# File 'lib/google/apis/run_v1/classes.rb', line 3022 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
3031 3032 3033 |
# File 'lib/google/apis/run_v1/classes.rb', line 3031 def build_step_outputs @build_step_outputs end |
#generic_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
3037 3038 3039 |
# File 'lib/google/apis/run_v1/classes.rb', line 3037 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
3043 3044 3045 |
# File 'lib/google/apis/run_v1/classes.rb', line 3043 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
3048 3049 3050 |
# File 'lib/google/apis/run_v1/classes.rb', line 3048 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
3053 3054 3055 |
# File 'lib/google/apis/run_v1/classes.rb', line 3053 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
3058 3059 3060 |
# File 'lib/google/apis/run_v1/classes.rb', line 3058 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
3064 3065 3066 |
# File 'lib/google/apis/run_v1/classes.rb', line 3064 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
3069 3070 3071 |
# File 'lib/google/apis/run_v1/classes.rb', line 3069 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 |
# File 'lib/google/apis/run_v1/classes.rb', line 3076 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |