Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1SecretManagerSecret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SecretManagerSecret

Returns a new instance of GoogleDevtoolsCloudbuildV1SecretManagerSecret.



3139
3140
3141
# File 'lib/google/apis/run_v1/classes.rb', line 3139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envString

Environment variable name to associate with the secret. Secret environment variables must be unique across all of a build's secrets, and must be used by at least one build step. Corresponds to the JSON property env

Returns:

  • (String)


3132
3133
3134
# File 'lib/google/apis/run_v1/classes.rb', line 3132

def env
  @env
end

#version_nameString

Resource name of the SecretVersion. In format: projects//secrets//versions/* Corresponds to the JSON property versionName

Returns:

  • (String)


3137
3138
3139
# File 'lib/google/apis/run_v1/classes.rb', line 3137

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3144
3145
3146
3147
# File 'lib/google/apis/run_v1/classes.rb', line 3144

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @version_name = args[:version_name] if args.key?(:version_name)
end