Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1SecretManagerSecret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SecretManagerSecret

Returns a new instance of GoogleDevtoolsCloudbuildV1SecretManagerSecret.



3012
3013
3014
# File 'lib/google/apis/run_v1/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envString

Environment variable name to associate with the secret. Secret environment variables must be unique across all of a build's secrets, and must be used by at least one build step. Corresponds to the JSON property env

Returns:

  • (String)


3005
3006
3007
# File 'lib/google/apis/run_v1/classes.rb', line 3005

def env
  @env
end

#version_nameString

Resource name of the SecretVersion. In format: projects//secrets//versions/* Corresponds to the JSON property versionName

Returns:

  • (String)


3010
3011
3012
# File 'lib/google/apis/run_v1/classes.rb', line 3010

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
3020
# File 'lib/google/apis/run_v1/classes.rb', line 3017

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @version_name = args[:version_name] if args.key?(:version_name)
end