Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Location of the source in a supported storage service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source

Returns a new instance of GoogleDevtoolsCloudbuildV1Source.



3242
3243
3244
# File 'lib/google/apis/run_v1/classes.rb', line 3242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoryGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property connectedRepository



3213
3214
3215
# File 'lib/google/apis/run_v1/classes.rb', line 3213

def connected_repository
  @connected_repository
end

#developer_connect_configGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

This config defines the location of a source through Developer Connect. Corresponds to the JSON property developerConnectConfig



3218
3219
3220
# File 'lib/google/apis/run_v1/classes.rb', line 3218

def developer_connect_config
  @developer_connect_config
end

#git_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property gitSource



3223
3224
3225
# File 'lib/google/apis/run_v1/classes.rb', line 3223

def git_source
  @git_source
end

#repo_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property repoSource



3228
3229
3230
# File 'lib/google/apis/run_v1/classes.rb', line 3228

def repo_source
  @repo_source
end

#storage_sourceGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property storageSource



3233
3234
3235
# File 'lib/google/apis/run_v1/classes.rb', line 3233

def storage_source
  @storage_source
end

#storage_source_manifestGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property storageSourceManifest



3240
3241
3242
# File 'lib/google/apis/run_v1/classes.rb', line 3240

def storage_source_manifest
  @storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3247
3248
3249
3250
3251
3252
3253
3254
# File 'lib/google/apis/run_v1/classes.rb', line 3247

def update!(**args)
  @connected_repository = args[:connected_repository] if args.key?(:connected_repository)
  @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config)
  @git_source = args[:git_source] if args.key?(:git_source)
  @repo_source = args[:repo_source] if args.key?(:repo_source)
  @storage_source = args[:storage_source] if args.key?(:storage_source)
  @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest)
end