Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGenericArtifact.



3488
3489
3490
# File 'lib/google/apis/run_v1/classes.rb', line 3488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_fingerprintGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property artifactFingerprint



3465
3466
3467
# File 'lib/google/apis/run_v1/classes.rb', line 3465

def artifact_fingerprint
  @artifact_fingerprint
end

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3470
3471
3472
# File 'lib/google/apis/run_v1/classes.rb', line 3470

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesHash<String,Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes>

Output only. The file hashes that make up the generic artifact. Corresponds to the JSON property fileHashes



3475
3476
3477
# File 'lib/google/apis/run_v1/classes.rb', line 3475

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3480
3481
3482
# File 'lib/google/apis/run_v1/classes.rb', line 3480

def push_timing
  @push_timing
end

#uriString

Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/ repositories/r1/packages/p1/versions/v1 Corresponds to the JSON property uri

Returns:

  • (String)


3486
3487
3488
# File 'lib/google/apis/run_v1/classes.rb', line 3486

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3493
3494
3495
3496
3497
3498
3499
# File 'lib/google/apis/run_v1/classes.rb', line 3493

def update!(**args)
  @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end