Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedGoModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A Go module artifact uploaded to Artifact Registry using the GoModule directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.



3520
3521
3522
# File 'lib/google/apis/run_v1/classes.rb', line 3520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


3502
3503
3504
# File 'lib/google/apis/run_v1/classes.rb', line 3502

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



3508
3509
3510
# File 'lib/google/apis/run_v1/classes.rb', line 3508

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



3513
3514
3515
# File 'lib/google/apis/run_v1/classes.rb', line 3513

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


3518
3519
3520
# File 'lib/google/apis/run_v1/classes.rb', line 3518

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3525
3526
3527
3528
3529
3530
# File 'lib/google/apis/run_v1/classes.rb', line 3525

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end