Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A Maven artifact uploaded using the MavenArtifact directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedMavenArtifact
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedMavenArtifact
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.
3496 3497 3498 |
# File 'lib/google/apis/run_v1/classes.rb', line 3496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3478 3479 3480 |
# File 'lib/google/apis/run_v1/classes.rb', line 3478 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3484 3485 3486 |
# File 'lib/google/apis/run_v1/classes.rb', line 3484 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3489 3490 3491 |
# File 'lib/google/apis/run_v1/classes.rb', line 3489 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
3494 3495 3496 |
# File 'lib/google/apis/run_v1/classes.rb', line 3494 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3501 3502 3503 3504 3505 3506 |
# File 'lib/google/apis/run_v1/classes.rb', line 3501 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |