Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
An npm package uploaded to Artifact Registry using the NpmPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded npm package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.
3361 3362 3363 |
# File 'lib/google/apis/run_v1/classes.rb', line 3361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3343 3344 3345 |
# File 'lib/google/apis/run_v1/classes.rb', line 3343 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3349 3350 3351 |
# File 'lib/google/apis/run_v1/classes.rb', line 3349 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3354 3355 3356 |
# File 'lib/google/apis/run_v1/classes.rb', line 3354 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded npm package.
Corresponds to the JSON property uri
3359 3360 3361 |
# File 'lib/google/apis/run_v1/classes.rb', line 3359 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3366 3367 3368 3369 3370 3371 |
# File 'lib/google/apis/run_v1/classes.rb', line 3366 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |