Class: Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1UploadedPythonPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Artifact uploaded using the PythonPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedPythonPackage
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedPythonPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedPythonPackage
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedPythonPackage.
3659 3660 3661 |
# File 'lib/google/apis/run_v1/classes.rb', line 3659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
3641 3642 3643 |
# File 'lib/google/apis/run_v1/classes.rb', line 3641 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
3647 3648 3649 |
# File 'lib/google/apis/run_v1/classes.rb', line 3647 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV1::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
3652 3653 3654 |
# File 'lib/google/apis/run_v1/classes.rb', line 3652 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
3657 3658 3659 |
# File 'lib/google/apis/run_v1/classes.rb', line 3657 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3664 3665 3666 3667 3668 3669 |
# File 'lib/google/apis/run_v1/classes.rb', line 3664 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |