Class: Google::Apis::RunV1::GrpcAction
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::GrpcAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
GRPCAction describes an action involving a GRPC port.
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
Port number of the gRPC service.
-
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrpcAction
constructor
A new instance of GrpcAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrpcAction
Returns a new instance of GrpcAction.
1377 1378 1379 |
# File 'lib/google/apis/run_v1/classes.rb', line 1377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
Port number of the gRPC service. Number must be in the range 1 to 65535.
Corresponds to the JSON property port
1369 1370 1371 |
# File 'lib/google/apis/run_v1/classes.rb', line 1369 def port @port end |
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest. If
this is not specified, the default behavior is defined by gRPC.
Corresponds to the JSON property service
1375 1376 1377 |
# File 'lib/google/apis/run_v1/classes.rb', line 1375 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1382 1383 1384 1385 |
# File 'lib/google/apis/run_v1/classes.rb', line 1382 def update!(**args) @port = args[:port] if args.key?(:port) @service = args[:service] if args.key?(:service) end |