Class: Google::Apis::RunV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Instance represents the configuration of a single Instance, which references a container image which is run to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



3969
3970
3971
# File 'lib/google/apis/run_v1/classes.rb', line 3969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/run_v1/classes.rb', line 3944

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


3951
3952
3953
# File 'lib/google/apis/run_v1/classes.rb', line 3951

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



3957
3958
3959
# File 'lib/google/apis/run_v1/classes.rb', line 3957

def 
  @metadata
end

#specGoogle::Apis::RunV1::InstanceSpec

InstanceSpec describes how the Instance will look. Corresponds to the JSON property spec



3962
3963
3964
# File 'lib/google/apis/run_v1/classes.rb', line 3962

def spec
  @spec
end

#statusGoogle::Apis::RunV1::InstanceStatus

InstanceStatus represents the current state of a Instance. Corresponds to the JSON property status



3967
3968
3969
# File 'lib/google/apis/run_v1/classes.rb', line 3967

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3974
3975
3976
3977
3978
3979
3980
# File 'lib/google/apis/run_v1/classes.rb', line 3974

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end