Class: Google::Apis::RunV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Instance represents the configuration of a single Instance, which references a container image which is run to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



3961
3962
3963
# File 'lib/google/apis/run_v1/classes.rb', line 3961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3936
3937
3938
# File 'lib/google/apis/run_v1/classes.rb', line 3936

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/run_v1/classes.rb', line 3943

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



3949
3950
3951
# File 'lib/google/apis/run_v1/classes.rb', line 3949

def 
  @metadata
end

#specGoogle::Apis::RunV1::InstanceSpec

InstanceSpec describes how the Instance will look. Corresponds to the JSON property spec



3954
3955
3956
# File 'lib/google/apis/run_v1/classes.rb', line 3954

def spec
  @spec
end

#statusGoogle::Apis::RunV1::InstanceStatus

InstanceStatus represents the current state of a Instance. Corresponds to the JSON property status



3959
3960
3961
# File 'lib/google/apis/run_v1/classes.rb', line 3959

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3966
3967
3968
3969
3970
3971
3972
# File 'lib/google/apis/run_v1/classes.rb', line 3966

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end