Class: Google::Apis::RunV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Instance represents the configuration of a single Instance, which references a container image which is run to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



3899
3900
3901
# File 'lib/google/apis/run_v1/classes.rb', line 3899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3874
3875
3876
# File 'lib/google/apis/run_v1/classes.rb', line 3874

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/run_v1/classes.rb', line 3881

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



3887
3888
3889
# File 'lib/google/apis/run_v1/classes.rb', line 3887

def 
  @metadata
end

#specGoogle::Apis::RunV1::InstanceSpec

InstanceSpec describes how the Instance will look. Corresponds to the JSON property spec



3892
3893
3894
# File 'lib/google/apis/run_v1/classes.rb', line 3892

def spec
  @spec
end

#statusGoogle::Apis::RunV1::InstanceStatus

InstanceStatus represents the current state of a Instance. Corresponds to the JSON property status



3897
3898
3899
# File 'lib/google/apis/run_v1/classes.rb', line 3897

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3904
3905
3906
3907
3908
3909
3910
# File 'lib/google/apis/run_v1/classes.rb', line 3904

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end