Class: Google::Apis::RunV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Instance represents the configuration of a single Instance, which references a container image which is run to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::InstanceSpec
InstanceSpec describes how the Instance will look.
-
#status ⇒ Google::Apis::RunV1::InstanceStatus
InstanceStatus represents the current state of a Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
3726 3727 3728 |
# File 'lib/google/apis/run_v1/classes.rb', line 3726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
3701 3702 3703 |
# File 'lib/google/apis/run_v1/classes.rb', line 3701 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
3708 3709 3710 |
# File 'lib/google/apis/run_v1/classes.rb', line 3708 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
3714 3715 3716 |
# File 'lib/google/apis/run_v1/classes.rb', line 3714 def @metadata end |
#spec ⇒ Google::Apis::RunV1::InstanceSpec
InstanceSpec describes how the Instance will look.
Corresponds to the JSON property spec
3719 3720 3721 |
# File 'lib/google/apis/run_v1/classes.rb', line 3719 def spec @spec end |
#status ⇒ Google::Apis::RunV1::InstanceStatus
InstanceStatus represents the current state of a Instance.
Corresponds to the JSON property status
3724 3725 3726 |
# File 'lib/google/apis/run_v1/classes.rb', line 3724 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/google/apis/run_v1/classes.rb', line 3731 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |