Class: Google::Apis::RunV1::InstanceSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::InstanceSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
InstanceSpec describes how the Instance will look.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::RunV1::Container>
Optional.
-
#node_selector ⇒ Hash<String,String>
Optional.
-
#service_account_name ⇒ String
Optional.
-
#timeout ⇒ String
Optional.
-
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceSpec
constructor
A new instance of InstanceSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceSpec
Returns a new instance of InstanceSpec.
3776 3777 3778 |
# File 'lib/google/apis/run_v1/classes.rb', line 3776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::RunV1::Container>
Optional. List of containers belonging to the Instance. We disallow a number
of fields on this Container.
Corresponds to the JSON property containers
3748 3749 3750 |
# File 'lib/google/apis/run_v1/classes.rb', line 3748 def containers @containers end |
#node_selector ⇒ Hash<String,String>
Optional. The Node Selector configuration. Map of selector key to a value
which matches a node.
Corresponds to the JSON property nodeSelector
3754 3755 3756 |
# File 'lib/google/apis/run_v1/classes.rb', line 3754 def node_selector @node_selector end |
#service_account_name ⇒ String
Optional. Email address of the IAM service account associated with the
Instance. The service account represents the identity of the running container,
and determines what permissions the Instance has. If not provided, the
Instance will use the project's default service account.
Corresponds to the JSON property serviceAccountName
3762 3763 3764 |
# File 'lib/google/apis/run_v1/classes.rb', line 3762 def service_account_name @service_account_name end |
#timeout ⇒ String
Optional. Duration the instance may be active before the system will shut it
down.
Corresponds to the JSON property timeout
3768 3769 3770 |
# File 'lib/google/apis/run_v1/classes.rb', line 3768 def timeout @timeout end |
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Optional. List of volumes that can be mounted by containers belonging to the
Instance.
Corresponds to the JSON property volumes
3774 3775 3776 |
# File 'lib/google/apis/run_v1/classes.rb', line 3774 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3781 3782 3783 3784 3785 3786 3787 |
# File 'lib/google/apis/run_v1/classes.rb', line 3781 def update!(**args) @containers = args[:containers] if args.key?(:containers) @node_selector = args[:node_selector] if args.key?(:node_selector) @service_account_name = args[:service_account_name] if args.key?(:service_account_name) @timeout = args[:timeout] if args.key?(:timeout) @volumes = args[:volumes] if args.key?(:volumes) end |