Class: Google::Apis::RunV1::InstanceStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::InstanceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
InstanceStatus represents the current state of a Instance.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Output only.
-
#log_uri ⇒ String
Optional.
-
#observed_generation ⇒ Fixnum
Output only.
-
#urls ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceStatus
constructor
A new instance of InstanceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceStatus
Returns a new instance of InstanceStatus.
4089 4090 4091 |
# File 'lib/google/apis/run_v1/classes.rb', line 4089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Output only. Conditions communicate information about ongoing/complete
reconciliation processes that bring the "spec" inline with the observed state
of the world. Instance-specific conditions include: * Ready: True when the
Instance is ready to be executed.
Corresponds to the JSON property conditions
4071 4072 4073 |
# File 'lib/google/apis/run_v1/classes.rb', line 4071 def conditions @conditions end |
#log_uri ⇒ String
Optional. URI where logs for this execution can be found in Cloud Console.
Corresponds to the JSON property logUri
4076 4077 4078 |
# File 'lib/google/apis/run_v1/classes.rb', line 4076 def log_uri @log_uri end |
#observed_generation ⇒ Fixnum
Output only. The 'generation' of the Instance that was last processed by the
controller.
Corresponds to the JSON property observedGeneration
4082 4083 4084 |
# File 'lib/google/apis/run_v1/classes.rb', line 4082 def observed_generation @observed_generation end |
#urls ⇒ Array<String>
Output only. All URLs serving traffic for this Instance.
Corresponds to the JSON property urls
4087 4088 4089 |
# File 'lib/google/apis/run_v1/classes.rb', line 4087 def urls @urls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4094 4095 4096 4097 4098 4099 |
# File 'lib/google/apis/run_v1/classes.rb', line 4094 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @log_uri = args[:log_uri] if args.key?(:log_uri) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @urls = args[:urls] if args.key?(:urls) end |