Class: Google::Apis::RunV1::InstanceStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::InstanceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
InstanceStatus represents the current state of a Instance.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Output only.
-
#log_uri ⇒ String
Optional.
-
#observed_generation ⇒ Fixnum
Output only.
-
#urls ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceStatus
constructor
A new instance of InstanceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceStatus
Returns a new instance of InstanceStatus.
3854 3855 3856 |
# File 'lib/google/apis/run_v1/classes.rb', line 3854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Output only. Conditions communicate information about ongoing/complete
reconciliation processes that bring the "spec" inline with the observed state
of the world. Instance-specific conditions include: * Ready: True when the
Instance is ready to be executed.
Corresponds to the JSON property conditions
3836 3837 3838 |
# File 'lib/google/apis/run_v1/classes.rb', line 3836 def conditions @conditions end |
#log_uri ⇒ String
Optional. URI where logs for this execution can be found in Cloud Console.
Corresponds to the JSON property logUri
3841 3842 3843 |
# File 'lib/google/apis/run_v1/classes.rb', line 3841 def log_uri @log_uri end |
#observed_generation ⇒ Fixnum
Output only. The 'generation' of the Instance that was last processed by the
controller.
Corresponds to the JSON property observedGeneration
3847 3848 3849 |
# File 'lib/google/apis/run_v1/classes.rb', line 3847 def observed_generation @observed_generation end |
#urls ⇒ Array<String>
Output only. All URLs serving traffic for this Instance.
Corresponds to the JSON property urls
3852 3853 3854 |
# File 'lib/google/apis/run_v1/classes.rb', line 3852 def urls @urls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3859 3860 3861 3862 3863 3864 |
# File 'lib/google/apis/run_v1/classes.rb', line 3859 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @log_uri = args[:log_uri] if args.key?(:log_uri) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @urls = args[:urls] if args.key?(:urls) end |