Class: Google::Apis::RunV1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Job represents the configuration of a single job, which references a container image which is run to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



4145
4146
4147
# File 'lib/google/apis/run_v1/classes.rb', line 4145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/run_v1/classes.rb', line 4120

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


4127
4128
4129
# File 'lib/google/apis/run_v1/classes.rb', line 4127

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



4133
4134
4135
# File 'lib/google/apis/run_v1/classes.rb', line 4133

def 
  @metadata
end

#specGoogle::Apis::RunV1::JobSpec

JobSpec describes how the job will look. Corresponds to the JSON property spec



4138
4139
4140
# File 'lib/google/apis/run_v1/classes.rb', line 4138

def spec
  @spec
end

#statusGoogle::Apis::RunV1::JobStatus

JobStatus represents the current state of a Job. Corresponds to the JSON property status



4143
4144
4145
# File 'lib/google/apis/run_v1/classes.rb', line 4143

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4150
4151
4152
4153
4154
4155
4156
# File 'lib/google/apis/run_v1/classes.rb', line 4150

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end