Class: Google::Apis::RunV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Job represents the configuration of a single job, which references a container image which is run to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::JobSpec
JobSpec describes how the job will look.
-
#status ⇒ Google::Apis::RunV1::JobStatus
JobStatus represents the current state of a Job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
4130 4131 4132 |
# File 'lib/google/apis/run_v1/classes.rb', line 4130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
4105 4106 4107 |
# File 'lib/google/apis/run_v1/classes.rb', line 4105 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
4112 4113 4114 |
# File 'lib/google/apis/run_v1/classes.rb', line 4112 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
4118 4119 4120 |
# File 'lib/google/apis/run_v1/classes.rb', line 4118 def @metadata end |
#spec ⇒ Google::Apis::RunV1::JobSpec
JobSpec describes how the job will look.
Corresponds to the JSON property spec
4123 4124 4125 |
# File 'lib/google/apis/run_v1/classes.rb', line 4123 def spec @spec end |
#status ⇒ Google::Apis::RunV1::JobStatus
JobStatus represents the current state of a Job.
Corresponds to the JSON property status
4128 4129 4130 |
# File 'lib/google/apis/run_v1/classes.rb', line 4128 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4135 4136 4137 4138 4139 4140 4141 |
# File 'lib/google/apis/run_v1/classes.rb', line 4135 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |