Class: Google::Apis::RunV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Job represents the configuration of a single job, which references a container image which is run to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::JobSpec
JobSpec describes how the job will look.
-
#status ⇒ Google::Apis::RunV1::JobStatus
JobStatus represents the current state of a Job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
3762 3763 3764 |
# File 'lib/google/apis/run_v1/classes.rb', line 3762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
3737 3738 3739 |
# File 'lib/google/apis/run_v1/classes.rb', line 3737 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
3744 3745 3746 |
# File 'lib/google/apis/run_v1/classes.rb', line 3744 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
3750 3751 3752 |
# File 'lib/google/apis/run_v1/classes.rb', line 3750 def @metadata end |
#spec ⇒ Google::Apis::RunV1::JobSpec
JobSpec describes how the job will look.
Corresponds to the JSON property spec
3755 3756 3757 |
# File 'lib/google/apis/run_v1/classes.rb', line 3755 def spec @spec end |
#status ⇒ Google::Apis::RunV1::JobStatus
JobStatus represents the current state of a Job.
Corresponds to the JSON property status
3760 3761 3762 |
# File 'lib/google/apis/run_v1/classes.rb', line 3760 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3767 3768 3769 3770 3771 3772 3773 |
# File 'lib/google/apis/run_v1/classes.rb', line 3767 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |