Class: Google::Apis::RunV1::JobSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::JobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
JobSpec describes how the job will look.
Instance Attribute Summary collapse
-
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution.
-
#start_execution_token ⇒ String
A unique string used as a suffix for creating a new execution.
-
#template ⇒ Google::Apis::RunV1::ExecutionTemplateSpec
ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobSpec
constructor
A new instance of JobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobSpec
Returns a new instance of JobSpec.
4200 4201 4202 |
# File 'lib/google/apis/run_v1/classes.rb', line 4200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution. The Job will
become ready when the execution is successfully completed. The sum of job name
and token length must be fewer than 63 characters.
Corresponds to the JSON property runExecutionToken
4185 4186 4187 |
# File 'lib/google/apis/run_v1/classes.rb', line 4185 def run_execution_token @run_execution_token end |
#start_execution_token ⇒ String
A unique string used as a suffix for creating a new execution. The Job will
become ready when the execution is successfully started. The sum of job name
and token length must be fewer than 63 characters.
Corresponds to the JSON property startExecutionToken
4192 4193 4194 |
# File 'lib/google/apis/run_v1/classes.rb', line 4192 def start_execution_token @start_execution_token end |
#template ⇒ Google::Apis::RunV1::ExecutionTemplateSpec
ExecutionTemplateSpec describes the metadata and spec an Execution should have
when created from a job.
Corresponds to the JSON property template
4198 4199 4200 |
# File 'lib/google/apis/run_v1/classes.rb', line 4198 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4205 4206 4207 4208 4209 |
# File 'lib/google/apis/run_v1/classes.rb', line 4205 def update!(**args) @run_execution_token = args[:run_execution_token] if args.key?(:run_execution_token) @start_execution_token = args[:start_execution_token] if args.key?(:start_execution_token) @template = args[:template] if args.key?(:template) end |