Class: Google::Apis::RunV1::JobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

JobSpec describes how the job will look.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobSpec

Returns a new instance of JobSpec.



4168
4169
4170
# File 'lib/google/apis/run_v1/classes.rb', line 4168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#run_execution_tokenString

A unique string used as a suffix for creating a new execution. The Job will become ready when the execution is successfully completed. The sum of job name and token length must be fewer than 63 characters. Corresponds to the JSON property runExecutionToken

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/run_v1/classes.rb', line 4153

def run_execution_token
  @run_execution_token
end

#start_execution_tokenString

A unique string used as a suffix for creating a new execution. The Job will become ready when the execution is successfully started. The sum of job name and token length must be fewer than 63 characters. Corresponds to the JSON property startExecutionToken

Returns:

  • (String)


4160
4161
4162
# File 'lib/google/apis/run_v1/classes.rb', line 4160

def start_execution_token
  @start_execution_token
end

#templateGoogle::Apis::RunV1::ExecutionTemplateSpec

ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job. Corresponds to the JSON property template



4166
4167
4168
# File 'lib/google/apis/run_v1/classes.rb', line 4166

def template
  @template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4173
4174
4175
4176
4177
# File 'lib/google/apis/run_v1/classes.rb', line 4173

def update!(**args)
  @run_execution_token = args[:run_execution_token] if args.key?(:run_execution_token)
  @start_execution_token = args[:start_execution_token] if args.key?(:start_execution_token)
  @template = args[:template] if args.key?(:template)
end