Class: Google::Apis::RunV1::JobSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::JobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
JobSpec describes how the job will look.
Instance Attribute Summary collapse
-
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution.
-
#start_execution_token ⇒ String
A unique string used as a suffix for creating a new execution.
-
#template ⇒ Google::Apis::RunV1::ExecutionTemplateSpec
ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobSpec
constructor
A new instance of JobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobSpec
Returns a new instance of JobSpec.
4113 4114 4115 |
# File 'lib/google/apis/run_v1/classes.rb', line 4113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution. The Job will
become ready when the execution is successfully completed. The sum of job name
and token length must be fewer than 63 characters.
Corresponds to the JSON property runExecutionToken
4098 4099 4100 |
# File 'lib/google/apis/run_v1/classes.rb', line 4098 def run_execution_token @run_execution_token end |
#start_execution_token ⇒ String
A unique string used as a suffix for creating a new execution. The Job will
become ready when the execution is successfully started. The sum of job name
and token length must be fewer than 63 characters.
Corresponds to the JSON property startExecutionToken
4105 4106 4107 |
# File 'lib/google/apis/run_v1/classes.rb', line 4105 def start_execution_token @start_execution_token end |
#template ⇒ Google::Apis::RunV1::ExecutionTemplateSpec
ExecutionTemplateSpec describes the metadata and spec an Execution should have
when created from a job.
Corresponds to the JSON property template
4111 4112 4113 |
# File 'lib/google/apis/run_v1/classes.rb', line 4111 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4118 4119 4120 4121 4122 |
# File 'lib/google/apis/run_v1/classes.rb', line 4118 def update!(**args) @run_execution_token = args[:run_execution_token] if args.key?(:run_execution_token) @start_execution_token = args[:start_execution_token] if args.key?(:start_execution_token) @template = args[:template] if args.key?(:template) end |