Class: Google::Apis::RunV1::JobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

JobSpec describes how the job will look.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobSpec

Returns a new instance of JobSpec.



3940
3941
3942
# File 'lib/google/apis/run_v1/classes.rb', line 3940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#run_execution_tokenString

A unique string used as a suffix for creating a new execution. The Job will become ready when the execution is successfully completed. The sum of job name and token length must be fewer than 63 characters. Corresponds to the JSON property runExecutionToken

Returns:

  • (String)


3925
3926
3927
# File 'lib/google/apis/run_v1/classes.rb', line 3925

def run_execution_token
  @run_execution_token
end

#start_execution_tokenString

A unique string used as a suffix for creating a new execution. The Job will become ready when the execution is successfully started. The sum of job name and token length must be fewer than 63 characters. Corresponds to the JSON property startExecutionToken

Returns:

  • (String)


3932
3933
3934
# File 'lib/google/apis/run_v1/classes.rb', line 3932

def start_execution_token
  @start_execution_token
end

#templateGoogle::Apis::RunV1::ExecutionTemplateSpec

ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job. Corresponds to the JSON property template



3938
3939
3940
# File 'lib/google/apis/run_v1/classes.rb', line 3938

def template
  @template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3945
3946
3947
3948
3949
# File 'lib/google/apis/run_v1/classes.rb', line 3945

def update!(**args)
  @run_execution_token = args[:run_execution_token] if args.key?(:run_execution_token)
  @start_execution_token = args[:start_execution_token] if args.key?(:start_execution_token)
  @template = args[:template] if args.key?(:template)
end