Class: Google::Apis::RunV1::KeyToPath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Maps a string key to a path within a volume.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyToPath

Returns a new instance of KeyToPath.



4023
4024
4025
# File 'lib/google/apis/run_v1/classes.rb', line 4023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

The Cloud Secret Manager secret version. Can be 'latest' for the latest value, or an integer or a secret alias for a specific version. The key to project. Corresponds to the JSON property key

Returns:

  • (String)


4001
4002
4003
# File 'lib/google/apis/run_v1/classes.rb', line 4001

def key
  @key
end

#modeFixnum

(Optional) Mode bits to use on this file, must be a value between 01 and 0777 ( octal). If 0 or not set, the Volume's default mode will be used. Notes * Internally, a umask of 0222 will be applied to any non-zero value. * This is an integer representation of the mode bits. So, the octal integer value should look exactly as the chmod numeric notation with a leading zero. Some examples: for chmod 777 (a=rwx), set to 0777 (octal) or 511 (base-10). For chmod 640 (u= rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 (u=rwx,g=rx,o=rx), set to 0755 (octal) or 493 (base-10). * This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. Corresponds to the JSON property mode

Returns:

  • (Fixnum)


4015
4016
4017
# File 'lib/google/apis/run_v1/classes.rb', line 4015

def mode
  @mode
end

#pathString

The relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'. Corresponds to the JSON property path

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/run_v1/classes.rb', line 4021

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4028
4029
4030
4031
4032
# File 'lib/google/apis/run_v1/classes.rb', line 4028

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @mode = args[:mode] if args.key?(:mode)
  @path = args[:path] if args.key?(:path)
end