Class: Google::Apis::RunV1::ListConfigurationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListConfigurationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListConfigurationsResponse is a list of Configuration resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Configuration>
List of Configurations.
-
#kind ⇒ String
The kind of this resource, in this case "ConfigurationList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConfigurationsResponse
constructor
A new instance of ListConfigurationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConfigurationsResponse
Returns a new instance of ListConfigurationsResponse.
4318 4319 4320 |
# File 'lib/google/apis/run_v1/classes.rb', line 4318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
4295 4296 4297 |
# File 'lib/google/apis/run_v1/classes.rb', line 4295 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Configuration>
List of Configurations.
Corresponds to the JSON property items
4300 4301 4302 |
# File 'lib/google/apis/run_v1/classes.rb', line 4300 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "ConfigurationList".
Corresponds to the JSON property kind
4305 4306 4307 |
# File 'lib/google/apis/run_v1/classes.rb', line 4305 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4311 4312 4313 |
# File 'lib/google/apis/run_v1/classes.rb', line 4311 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4316 4317 4318 |
# File 'lib/google/apis/run_v1/classes.rb', line 4316 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4323 4324 4325 4326 4327 4328 4329 |
# File 'lib/google/apis/run_v1/classes.rb', line 4323 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |