Class: Google::Apis::RunV1::ListConfigurationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListConfigurationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListConfigurationsResponse is a list of Configuration resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Configuration>
List of Configurations.
-
#kind ⇒ String
The kind of this resource, in this case "ConfigurationList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConfigurationsResponse
constructor
A new instance of ListConfigurationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConfigurationsResponse
Returns a new instance of ListConfigurationsResponse.
4325 4326 4327 |
# File 'lib/google/apis/run_v1/classes.rb', line 4325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
4302 4303 4304 |
# File 'lib/google/apis/run_v1/classes.rb', line 4302 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Configuration>
List of Configurations.
Corresponds to the JSON property items
4307 4308 4309 |
# File 'lib/google/apis/run_v1/classes.rb', line 4307 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "ConfigurationList".
Corresponds to the JSON property kind
4312 4313 4314 |
# File 'lib/google/apis/run_v1/classes.rb', line 4312 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4318 4319 4320 |
# File 'lib/google/apis/run_v1/classes.rb', line 4318 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4323 4324 4325 |
# File 'lib/google/apis/run_v1/classes.rb', line 4323 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4330 4331 4332 4333 4334 4335 4336 |
# File 'lib/google/apis/run_v1/classes.rb', line 4330 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |