Class: Google::Apis::RunV1::ListConfigurationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListConfigurationsResponse is a list of Configuration resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConfigurationsResponse

Returns a new instance of ListConfigurationsResponse.



3950
3951
3952
# File 'lib/google/apis/run_v1/classes.rb', line 3950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/run_v1/classes.rb', line 3927

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Configuration>

List of Configurations. Corresponds to the JSON property items



3932
3933
3934
# File 'lib/google/apis/run_v1/classes.rb', line 3932

def items
  @items
end

#kindString

The kind of this resource, in this case "ConfigurationList". Corresponds to the JSON property kind

Returns:

  • (String)


3937
3938
3939
# File 'lib/google/apis/run_v1/classes.rb', line 3937

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



3943
3944
3945
# File 'lib/google/apis/run_v1/classes.rb', line 3943

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3948
3949
3950
# File 'lib/google/apis/run_v1/classes.rb', line 3948

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3955
3956
3957
3958
3959
3960
3961
# File 'lib/google/apis/run_v1/classes.rb', line 3955

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end