Class: Google::Apis::RunV1::ListDomainMappingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListDomainMappingsResponse is a list of DomainMapping resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainMappingsResponse

Returns a new instance of ListDomainMappingsResponse.



4362
4363
4364
# File 'lib/google/apis/run_v1/classes.rb', line 4362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "domains.cloudrun.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4339
4340
4341
# File 'lib/google/apis/run_v1/classes.rb', line 4339

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::DomainMapping>

List of DomainMappings. Corresponds to the JSON property items



4344
4345
4346
# File 'lib/google/apis/run_v1/classes.rb', line 4344

def items
  @items
end

#kindString

The kind of this resource, in this case "DomainMappingList". Corresponds to the JSON property kind

Returns:

  • (String)


4349
4350
4351
# File 'lib/google/apis/run_v1/classes.rb', line 4349

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4355
4356
4357
# File 'lib/google/apis/run_v1/classes.rb', line 4355

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4360
4361
4362
# File 'lib/google/apis/run_v1/classes.rb', line 4360

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4367
4368
4369
4370
4371
4372
4373
# File 'lib/google/apis/run_v1/classes.rb', line 4367

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end