Class: Google::Apis::RunV1::ListDomainMappingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListDomainMappingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListDomainMappingsResponse is a list of DomainMapping resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "domains.cloudrun.com/v1".
-
#items ⇒ Array<Google::Apis::RunV1::DomainMapping>
List of DomainMappings.
-
#kind ⇒ String
The kind of this resource, in this case "DomainMappingList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDomainMappingsResponse
constructor
A new instance of ListDomainMappingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDomainMappingsResponse
Returns a new instance of ListDomainMappingsResponse.
4369 4370 4371 |
# File 'lib/google/apis/run_v1/classes.rb', line 4369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "domains.cloudrun.com/v1".
Corresponds to the JSON property apiVersion
4346 4347 4348 |
# File 'lib/google/apis/run_v1/classes.rb', line 4346 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::DomainMapping>
List of DomainMappings.
Corresponds to the JSON property items
4351 4352 4353 |
# File 'lib/google/apis/run_v1/classes.rb', line 4351 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "DomainMappingList".
Corresponds to the JSON property kind
4356 4357 4358 |
# File 'lib/google/apis/run_v1/classes.rb', line 4356 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4362 4363 4364 |
# File 'lib/google/apis/run_v1/classes.rb', line 4362 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4367 4368 4369 |
# File 'lib/google/apis/run_v1/classes.rb', line 4367 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/google/apis/run_v1/classes.rb', line 4374 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |