Class: Google::Apis::RunV1::ListDomainMappingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListDomainMappingsResponse is a list of DomainMapping resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainMappingsResponse

Returns a new instance of ListDomainMappingsResponse.



4134
4135
4136
# File 'lib/google/apis/run_v1/classes.rb', line 4134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "domains.cloudrun.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4111
4112
4113
# File 'lib/google/apis/run_v1/classes.rb', line 4111

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::DomainMapping>

List of DomainMappings. Corresponds to the JSON property items



4116
4117
4118
# File 'lib/google/apis/run_v1/classes.rb', line 4116

def items
  @items
end

#kindString

The kind of this resource, in this case "DomainMappingList". Corresponds to the JSON property kind

Returns:

  • (String)


4121
4122
4123
# File 'lib/google/apis/run_v1/classes.rb', line 4121

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4127
4128
4129
# File 'lib/google/apis/run_v1/classes.rb', line 4127

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4132
4133
4134
# File 'lib/google/apis/run_v1/classes.rb', line 4132

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4139
4140
4141
4142
4143
4144
4145
# File 'lib/google/apis/run_v1/classes.rb', line 4139

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end