Class: Google::Apis::RunV1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListInstancesResponse is a list of Instances resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



4395
4396
4397
# File 'lib/google/apis/run_v1/classes.rb', line 4395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/run_v1/classes.rb', line 4372

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Instance>

List of Instances. Corresponds to the JSON property items

Returns:



4377
4378
4379
# File 'lib/google/apis/run_v1/classes.rb', line 4377

def items
  @items
end

#kindString

The kind of this resource, in this case "InstancesList". Corresponds to the JSON property kind

Returns:

  • (String)


4382
4383
4384
# File 'lib/google/apis/run_v1/classes.rb', line 4382

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4388
4389
4390
# File 'lib/google/apis/run_v1/classes.rb', line 4388

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4393
4394
4395
# File 'lib/google/apis/run_v1/classes.rb', line 4393

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4400
4401
4402
4403
4404
4405
4406
# File 'lib/google/apis/run_v1/classes.rb', line 4400

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end