Class: Google::Apis::RunV1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListInstancesResponse is a list of Instances resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



4222
4223
4224
# File 'lib/google/apis/run_v1/classes.rb', line 4222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4199
4200
4201
# File 'lib/google/apis/run_v1/classes.rb', line 4199

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Instance>

List of Instances. Corresponds to the JSON property items

Returns:



4204
4205
4206
# File 'lib/google/apis/run_v1/classes.rb', line 4204

def items
  @items
end

#kindString

The kind of this resource, in this case "InstancesList". Corresponds to the JSON property kind

Returns:

  • (String)


4209
4210
4211
# File 'lib/google/apis/run_v1/classes.rb', line 4209

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4215
4216
4217
# File 'lib/google/apis/run_v1/classes.rb', line 4215

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4220
4221
4222
# File 'lib/google/apis/run_v1/classes.rb', line 4220

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4227
4228
4229
4230
4231
4232
4233
# File 'lib/google/apis/run_v1/classes.rb', line 4227

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end