Class: Google::Apis::RunV1::ListJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListJobsResponse is a list of Jobs resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListJobsResponse

Returns a new instance of ListJobsResponse.



4494
4495
4496
# File 'lib/google/apis/run_v1/classes.rb', line 4494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4471
4472
4473
# File 'lib/google/apis/run_v1/classes.rb', line 4471

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Job>

List of Jobs. Corresponds to the JSON property items

Returns:



4476
4477
4478
# File 'lib/google/apis/run_v1/classes.rb', line 4476

def items
  @items
end

#kindString

The kind of this resource, in this case "JobsList". Corresponds to the JSON property kind

Returns:

  • (String)


4481
4482
4483
# File 'lib/google/apis/run_v1/classes.rb', line 4481

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4487
4488
4489
# File 'lib/google/apis/run_v1/classes.rb', line 4487

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4492
4493
4494
# File 'lib/google/apis/run_v1/classes.rb', line 4492

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4499
4500
4501
4502
4503
4504
4505
# File 'lib/google/apis/run_v1/classes.rb', line 4499

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end