Class: Google::Apis::RunV1::ListJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
ListJobsResponse is a list of Jobs resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "run.googleapis.com/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Job>
List of Jobs.
-
#kind ⇒ String
The kind of this resource, in this case "JobsList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListJobsResponse
constructor
A new instance of ListJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListJobsResponse
Returns a new instance of ListJobsResponse.
4439 4440 4441 |
# File 'lib/google/apis/run_v1/classes.rb', line 4439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
4416 4417 4418 |
# File 'lib/google/apis/run_v1/classes.rb', line 4416 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Job>
List of Jobs.
Corresponds to the JSON property items
4421 4422 4423 |
# File 'lib/google/apis/run_v1/classes.rb', line 4421 def items @items end |
#kind ⇒ String
The kind of this resource, in this case "JobsList".
Corresponds to the JSON property kind
4426 4427 4428 |
# File 'lib/google/apis/run_v1/classes.rb', line 4426 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4432 4433 4434 |
# File 'lib/google/apis/run_v1/classes.rb', line 4432 def @metadata end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4437 4438 4439 |
# File 'lib/google/apis/run_v1/classes.rb', line 4437 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4444 4445 4446 4447 4448 4449 4450 |
# File 'lib/google/apis/run_v1/classes.rb', line 4444 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |