Class: Google::Apis::RunV1::ListMeta
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListMeta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta.
Instance Attribute Summary collapse
-
#continue ⇒ String
Continuation token is a value emitted when the count of items is larger than the user/system limit.
-
#resource_version ⇒ String
Opaque string that identifies the server's internal version of this object.
-
#self_link ⇒ String
URL representing this object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMeta
constructor
A new instance of ListMeta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMeta
Returns a new instance of ListMeta.
4572 4573 4574 |
# File 'lib/google/apis/run_v1/classes.rb', line 4572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#continue ⇒ String
Continuation token is a value emitted when the count of items is larger than
the user/system limit. To retrieve the next page of items, pass the value of
continue as the next request's page_token.
Corresponds to the JSON property continue
4558 4559 4560 |
# File 'lib/google/apis/run_v1/classes.rb', line 4558 def continue @continue end |
#resource_version ⇒ String
Opaque string that identifies the server's internal version of this object. It
can be used by clients to determine when objects have changed. If the message
is passed back to the server, it must be left unmodified.
Corresponds to the JSON property resourceVersion
4565 4566 4567 |
# File 'lib/google/apis/run_v1/classes.rb', line 4565 def resource_version @resource_version end |
#self_link ⇒ String
URL representing this object.
Corresponds to the JSON property selfLink
4570 4571 4572 |
# File 'lib/google/apis/run_v1/classes.rb', line 4570 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4577 4578 4579 4580 4581 |
# File 'lib/google/apis/run_v1/classes.rb', line 4577 def update!(**args) @continue = args[:continue] if args.key?(:continue) @resource_version = args[:resource_version] if args.key?(:resource_version) @self_link = args[:self_link] if args.key?(:self_link) end |