Class: Google::Apis::RunV1::ListMeta

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeta

Returns a new instance of ListMeta.



4502
4503
4504
# File 'lib/google/apis/run_v1/classes.rb', line 4502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#continueString

Continuation token is a value emitted when the count of items is larger than the user/system limit. To retrieve the next page of items, pass the value of continue as the next request's page_token. Corresponds to the JSON property continue

Returns:

  • (String)


4488
4489
4490
# File 'lib/google/apis/run_v1/classes.rb', line 4488

def continue
  @continue
end

#resource_versionString

Opaque string that identifies the server's internal version of this object. It can be used by clients to determine when objects have changed. If the message is passed back to the server, it must be left unmodified. Corresponds to the JSON property resourceVersion

Returns:

  • (String)


4495
4496
4497
# File 'lib/google/apis/run_v1/classes.rb', line 4495

def resource_version
  @resource_version
end

URL representing this object. Corresponds to the JSON property selfLink

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/run_v1/classes.rb', line 4500

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4507
4508
4509
4510
4511
# File 'lib/google/apis/run_v1/classes.rb', line 4507

def update!(**args)
  @continue = args[:continue] if args.key?(:continue)
  @resource_version = args[:resource_version] if args.key?(:resource_version)
  @self_link = args[:self_link] if args.key?(:self_link)
end