Class: Google::Apis::RunV1::ListMeta

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeta

Returns a new instance of ListMeta.



4329
4330
4331
# File 'lib/google/apis/run_v1/classes.rb', line 4329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#continueString

Continuation token is a value emitted when the count of items is larger than the user/system limit. To retrieve the next page of items, pass the value of continue as the next request's page_token. Corresponds to the JSON property continue

Returns:

  • (String)


4315
4316
4317
# File 'lib/google/apis/run_v1/classes.rb', line 4315

def continue
  @continue
end

#resource_versionString

Opaque string that identifies the server's internal version of this object. It can be used by clients to determine when objects have changed. If the message is passed back to the server, it must be left unmodified. Corresponds to the JSON property resourceVersion

Returns:

  • (String)


4322
4323
4324
# File 'lib/google/apis/run_v1/classes.rb', line 4322

def resource_version
  @resource_version
end

URL representing this object. Corresponds to the JSON property selfLink

Returns:

  • (String)


4327
4328
4329
# File 'lib/google/apis/run_v1/classes.rb', line 4327

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4334
4335
4336
4337
4338
# File 'lib/google/apis/run_v1/classes.rb', line 4334

def update!(**args)
  @continue = args[:continue] if args.key?(:continue)
  @resource_version = args[:resource_version] if args.key?(:resource_version)
  @self_link = args[:self_link] if args.key?(:self_link)
end