Class: Google::Apis::RunV1::ListRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListRevisionsResponse is a list of Revision resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRevisionsResponse

Returns a new instance of ListRevisionsResponse.



4606
4607
4608
# File 'lib/google/apis/run_v1/classes.rb', line 4606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4583
4584
4585
# File 'lib/google/apis/run_v1/classes.rb', line 4583

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Revision>

List of Revisions. Corresponds to the JSON property items

Returns:



4588
4589
4590
# File 'lib/google/apis/run_v1/classes.rb', line 4588

def items
  @items
end

#kindString

The kind of this resource, in this case "RevisionList". Corresponds to the JSON property kind

Returns:

  • (String)


4593
4594
4595
# File 'lib/google/apis/run_v1/classes.rb', line 4593

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4599
4600
4601
# File 'lib/google/apis/run_v1/classes.rb', line 4599

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4604
4605
4606
# File 'lib/google/apis/run_v1/classes.rb', line 4604

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4611
4612
4613
4614
4615
4616
4617
# File 'lib/google/apis/run_v1/classes.rb', line 4611

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end