Class: Google::Apis::RunV1::ListRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListRoutesResponse is a list of Route resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRoutesResponse

Returns a new instance of ListRoutesResponse.



4643
4644
4645
# File 'lib/google/apis/run_v1/classes.rb', line 4643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4620
4621
4622
# File 'lib/google/apis/run_v1/classes.rb', line 4620

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Route>

List of Routes. Corresponds to the JSON property items

Returns:



4625
4626
4627
# File 'lib/google/apis/run_v1/classes.rb', line 4625

def items
  @items
end

#kindString

The kind of this resource, in this case always "RouteList". Corresponds to the JSON property kind

Returns:

  • (String)


4630
4631
4632
# File 'lib/google/apis/run_v1/classes.rb', line 4630

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4636
4637
4638
# File 'lib/google/apis/run_v1/classes.rb', line 4636

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4641
4642
4643
# File 'lib/google/apis/run_v1/classes.rb', line 4641

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4648
4649
4650
4651
4652
4653
4654
# File 'lib/google/apis/run_v1/classes.rb', line 4648

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end