Class: Google::Apis::RunV1::ListRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListRoutesResponse is a list of Route resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRoutesResponse

Returns a new instance of ListRoutesResponse.



4650
4651
4652
# File 'lib/google/apis/run_v1/classes.rb', line 4650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4627
4628
4629
# File 'lib/google/apis/run_v1/classes.rb', line 4627

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Route>

List of Routes. Corresponds to the JSON property items

Returns:



4632
4633
4634
# File 'lib/google/apis/run_v1/classes.rb', line 4632

def items
  @items
end

#kindString

The kind of this resource, in this case always "RouteList". Corresponds to the JSON property kind

Returns:

  • (String)


4637
4638
4639
# File 'lib/google/apis/run_v1/classes.rb', line 4637

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4643
4644
4645
# File 'lib/google/apis/run_v1/classes.rb', line 4643

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4648
4649
4650
# File 'lib/google/apis/run_v1/classes.rb', line 4648

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4655
4656
4657
4658
4659
4660
4661
# File 'lib/google/apis/run_v1/classes.rb', line 4655

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end