Class: Google::Apis::RunV1::ListRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListRoutesResponse is a list of Route resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRoutesResponse

Returns a new instance of ListRoutesResponse.



4231
4232
4233
# File 'lib/google/apis/run_v1/classes.rb', line 4231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4208
4209
4210
# File 'lib/google/apis/run_v1/classes.rb', line 4208

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Route>

List of Routes. Corresponds to the JSON property items

Returns:



4213
4214
4215
# File 'lib/google/apis/run_v1/classes.rb', line 4213

def items
  @items
end

#kindString

The kind of this resource, in this case always "RouteList". Corresponds to the JSON property kind

Returns:

  • (String)


4218
4219
4220
# File 'lib/google/apis/run_v1/classes.rb', line 4218

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4224
4225
4226
# File 'lib/google/apis/run_v1/classes.rb', line 4224

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4229
4230
4231
# File 'lib/google/apis/run_v1/classes.rb', line 4229

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4236
4237
4238
4239
4240
4241
4242
# File 'lib/google/apis/run_v1/classes.rb', line 4236

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end