Class: Google::Apis::RunV1::ListServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A list of Service resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServicesResponse

Returns a new instance of ListServicesResponse.



4703
4704
4705
# File 'lib/google/apis/run_v1/classes.rb', line 4703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call; returns "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4679
4680
4681
# File 'lib/google/apis/run_v1/classes.rb', line 4679

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Service>

List of Services. Corresponds to the JSON property items

Returns:



4684
4685
4686
# File 'lib/google/apis/run_v1/classes.rb', line 4684

def items
  @items
end

#kindString

The kind of this resource; returns "ServiceList". Corresponds to the JSON property kind

Returns:

  • (String)


4689
4690
4691
# File 'lib/google/apis/run_v1/classes.rb', line 4689

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4695
4696
4697
# File 'lib/google/apis/run_v1/classes.rb', line 4695

def 
  @metadata
end

#unreachableArray<String>

For calls against the global endpoint, returns the list of Cloud locations that could not be reached. For regional calls, this field is not used. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4701
4702
4703
# File 'lib/google/apis/run_v1/classes.rb', line 4701

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4708
4709
4710
4711
4712
4713
4714
# File 'lib/google/apis/run_v1/classes.rb', line 4708

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end