Class: Google::Apis::RunV1::ListServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A list of Service resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call; returns "serving.knative.dev/v1".
-
#items ⇒ Array<Google::Apis::RunV1::Service>
List of Services.
-
#kind ⇒ String
The kind of this resource; returns "ServiceList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServicesResponse
constructor
A new instance of ListServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServicesResponse
Returns a new instance of ListServicesResponse.
4688 4689 4690 |
# File 'lib/google/apis/run_v1/classes.rb', line 4688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call; returns "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
4664 4665 4666 |
# File 'lib/google/apis/run_v1/classes.rb', line 4664 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::Service>
List of Services.
Corresponds to the JSON property items
4669 4670 4671 |
# File 'lib/google/apis/run_v1/classes.rb', line 4669 def items @items end |
#kind ⇒ String
The kind of this resource; returns "ServiceList".
Corresponds to the JSON property kind
4674 4675 4676 |
# File 'lib/google/apis/run_v1/classes.rb', line 4674 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4680 4681 4682 |
# File 'lib/google/apis/run_v1/classes.rb', line 4680 def @metadata end |
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations
that could not be reached. For regional calls, this field is not used.
Corresponds to the JSON property unreachable
4686 4687 4688 |
# File 'lib/google/apis/run_v1/classes.rb', line 4686 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/google/apis/run_v1/classes.rb', line 4693 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |