Class: Google::Apis::RunV1::ListServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A list of Service resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServicesResponse

Returns a new instance of ListServicesResponse.



4460
4461
4462
# File 'lib/google/apis/run_v1/classes.rb', line 4460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call; returns "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4436
4437
4438
# File 'lib/google/apis/run_v1/classes.rb', line 4436

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Service>

List of Services. Corresponds to the JSON property items

Returns:



4441
4442
4443
# File 'lib/google/apis/run_v1/classes.rb', line 4441

def items
  @items
end

#kindString

The kind of this resource; returns "ServiceList". Corresponds to the JSON property kind

Returns:

  • (String)


4446
4447
4448
# File 'lib/google/apis/run_v1/classes.rb', line 4446

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4452
4453
4454
# File 'lib/google/apis/run_v1/classes.rb', line 4452

def 
  @metadata
end

#unreachableArray<String>

For calls against the global endpoint, returns the list of Cloud locations that could not be reached. For regional calls, this field is not used. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4458
4459
4460
# File 'lib/google/apis/run_v1/classes.rb', line 4458

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4465
4466
4467
4468
4469
4470
4471
# File 'lib/google/apis/run_v1/classes.rb', line 4465

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end