Class: Google::Apis::RunV1::ListTasksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ListTasksResponse is a list of Tasks resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTasksResponse

Returns a new instance of ListTasksResponse.



4504
4505
4506
# File 'lib/google/apis/run_v1/classes.rb', line 4504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4481
4482
4483
# File 'lib/google/apis/run_v1/classes.rb', line 4481

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::Task>

List of Tasks. Corresponds to the JSON property items

Returns:



4486
4487
4488
# File 'lib/google/apis/run_v1/classes.rb', line 4486

def items
  @items
end

#kindString

The kind of this resource, in this case "TasksList". Corresponds to the JSON property kind

Returns:

  • (String)


4491
4492
4493
# File 'lib/google/apis/run_v1/classes.rb', line 4491

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4497
4498
4499
# File 'lib/google/apis/run_v1/classes.rb', line 4497

def 
  @metadata
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4502
4503
4504
# File 'lib/google/apis/run_v1/classes.rb', line 4502

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4509
4510
4511
4512
4513
4514
4515
# File 'lib/google/apis/run_v1/classes.rb', line 4509

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end