Class: Google::Apis::RunV1::ListWorkerPoolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListWorkerPoolsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A list of WorkerPool resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call; returns "run.googleapis.com/v1".
-
#items ⇒ Array<Google::Apis::RunV1::WorkerPool>
List of WorkerPools.
-
#kind ⇒ String
The kind of this resource; returns "WorkerPoolList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWorkerPoolsResponse
constructor
A new instance of ListWorkerPoolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWorkerPoolsResponse
Returns a new instance of ListWorkerPoolsResponse.
4809 4810 4811 |
# File 'lib/google/apis/run_v1/classes.rb', line 4809 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call; returns "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
4785 4786 4787 |
# File 'lib/google/apis/run_v1/classes.rb', line 4785 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::WorkerPool>
List of WorkerPools.
Corresponds to the JSON property items
4790 4791 4792 |
# File 'lib/google/apis/run_v1/classes.rb', line 4790 def items @items end |
#kind ⇒ String
The kind of this resource; returns "WorkerPoolList".
Corresponds to the JSON property kind
4795 4796 4797 |
# File 'lib/google/apis/run_v1/classes.rb', line 4795 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4801 4802 4803 |
# File 'lib/google/apis/run_v1/classes.rb', line 4801 def @metadata end |
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations
that could not be reached. For regional calls, this field is not used.
Corresponds to the JSON property unreachable
4807 4808 4809 |
# File 'lib/google/apis/run_v1/classes.rb', line 4807 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4814 4815 4816 4817 4818 4819 4820 |
# File 'lib/google/apis/run_v1/classes.rb', line 4814 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |