Class: Google::Apis::RunV1::ListWorkerPoolsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A list of WorkerPool resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkerPoolsResponse

Returns a new instance of ListWorkerPoolsResponse.



4784
4785
4786
# File 'lib/google/apis/run_v1/classes.rb', line 4784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call; returns "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4760
4761
4762
# File 'lib/google/apis/run_v1/classes.rb', line 4760

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::WorkerPool>

List of WorkerPools. Corresponds to the JSON property items



4765
4766
4767
# File 'lib/google/apis/run_v1/classes.rb', line 4765

def items
  @items
end

#kindString

The kind of this resource; returns "WorkerPoolList". Corresponds to the JSON property kind

Returns:

  • (String)


4770
4771
4772
# File 'lib/google/apis/run_v1/classes.rb', line 4770

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4776
4777
4778
# File 'lib/google/apis/run_v1/classes.rb', line 4776

def 
  @metadata
end

#unreachableArray<String>

For calls against the global endpoint, returns the list of Cloud locations that could not be reached. For regional calls, this field is not used. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4782
4783
4784
# File 'lib/google/apis/run_v1/classes.rb', line 4782

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4789
4790
4791
4792
4793
4794
4795
# File 'lib/google/apis/run_v1/classes.rb', line 4789

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end