Class: Google::Apis::RunV1::ListWorkerPoolsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A list of WorkerPool resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkerPoolsResponse

Returns a new instance of ListWorkerPoolsResponse.



4722
4723
4724
# File 'lib/google/apis/run_v1/classes.rb', line 4722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call; returns "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/run_v1/classes.rb', line 4698

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::WorkerPool>

List of WorkerPools. Corresponds to the JSON property items



4703
4704
4705
# File 'lib/google/apis/run_v1/classes.rb', line 4703

def items
  @items
end

#kindString

The kind of this resource; returns "WorkerPoolList". Corresponds to the JSON property kind

Returns:

  • (String)


4708
4709
4710
# File 'lib/google/apis/run_v1/classes.rb', line 4708

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4714
4715
4716
# File 'lib/google/apis/run_v1/classes.rb', line 4714

def 
  @metadata
end

#unreachableArray<String>

For calls against the global endpoint, returns the list of Cloud locations that could not be reached. For regional calls, this field is not used. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4720
4721
4722
# File 'lib/google/apis/run_v1/classes.rb', line 4720

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4727
4728
4729
4730
4731
4732
4733
# File 'lib/google/apis/run_v1/classes.rb', line 4727

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end