Class: Google::Apis::RunV1::ListWorkerPoolsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

A list of WorkerPool resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkerPoolsResponse

Returns a new instance of ListWorkerPoolsResponse.



4549
4550
4551
# File 'lib/google/apis/run_v1/classes.rb', line 4549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call; returns "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


4525
4526
4527
# File 'lib/google/apis/run_v1/classes.rb', line 4525

def api_version
  @api_version
end

#itemsArray<Google::Apis::RunV1::WorkerPool>

List of WorkerPools. Corresponds to the JSON property items



4530
4531
4532
# File 'lib/google/apis/run_v1/classes.rb', line 4530

def items
  @items
end

#kindString

The kind of this resource; returns "WorkerPoolList". Corresponds to the JSON property kind

Returns:

  • (String)


4535
4536
4537
# File 'lib/google/apis/run_v1/classes.rb', line 4535

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



4541
4542
4543
# File 'lib/google/apis/run_v1/classes.rb', line 4541

def 
  @metadata
end

#unreachableArray<String>

For calls against the global endpoint, returns the list of Cloud locations that could not be reached. For regional calls, this field is not used. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4547
4548
4549
# File 'lib/google/apis/run_v1/classes.rb', line 4547

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4554
4555
4556
4557
4558
4559
4560
# File 'lib/google/apis/run_v1/classes.rb', line 4554

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end