Class: Google::Apis::RunV1::ListWorkerPoolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ListWorkerPoolsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
A list of WorkerPool resources.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call; returns "run.googleapis.com/v1".
-
#items ⇒ Array<Google::Apis::RunV1::WorkerPool>
List of WorkerPools.
-
#kind ⇒ String
The kind of this resource; returns "WorkerPoolList".
-
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List.
-
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWorkerPoolsResponse
constructor
A new instance of ListWorkerPoolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWorkerPoolsResponse
Returns a new instance of ListWorkerPoolsResponse.
4365 4366 4367 |
# File 'lib/google/apis/run_v1/classes.rb', line 4365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call; returns "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
4341 4342 4343 |
# File 'lib/google/apis/run_v1/classes.rb', line 4341 def api_version @api_version end |
#items ⇒ Array<Google::Apis::RunV1::WorkerPool>
List of WorkerPools.
Corresponds to the JSON property items
4346 4347 4348 |
# File 'lib/google/apis/run_v1/classes.rb', line 4346 def items @items end |
#kind ⇒ String
The kind of this resource; returns "WorkerPoolList".
Corresponds to the JSON property kind
4351 4352 4353 |
# File 'lib/google/apis/run_v1/classes.rb', line 4351 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ListMeta
Metadata for synthetic resources like List. In Cloud Run, all List Resources
Responses will have a ListMeta instead of ObjectMeta.
Corresponds to the JSON property metadata
4357 4358 4359 |
# File 'lib/google/apis/run_v1/classes.rb', line 4357 def @metadata end |
#unreachable ⇒ Array<String>
For calls against the global endpoint, returns the list of Cloud locations
that could not be reached. For regional calls, this field is not used.
Corresponds to the JSON property unreachable
4363 4364 4365 |
# File 'lib/google/apis/run_v1/classes.rb', line 4363 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4370 4371 4372 4373 4374 4375 4376 |
# File 'lib/google/apis/run_v1/classes.rb', line 4370 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @unreachable = args[:unreachable] if args.key?(:unreachable) end |