Class: Google::Apis::RunV1::NfsVolumeSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Represents a persistent volume that will be mounted using NFS. This volume will be shared between all instances of the resource and data will not be deleted when the instance is shut down.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NfsVolumeSource

Returns a new instance of NfsVolumeSource.



4652
4653
4654
# File 'lib/google/apis/run_v1/classes.rb', line 4652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

Path that is exported by the NFS server. Corresponds to the JSON property path

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/run_v1/classes.rb', line 4639

def path
  @path
end

#read_onlyBoolean Also known as: read_only?

If true, mount the NFS volume as read only. Defaults to false. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


4644
4645
4646
# File 'lib/google/apis/run_v1/classes.rb', line 4644

def read_only
  @read_only
end

#serverString

Hostname or IP address of the NFS server. Corresponds to the JSON property server

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/run_v1/classes.rb', line 4650

def server
  @server
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4657
4658
4659
4660
4661
# File 'lib/google/apis/run_v1/classes.rb', line 4657

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @read_only = args[:read_only] if args.key?(:read_only)
  @server = args[:server] if args.key?(:server)
end