Class: Google::Apis::RunV1::ObjectMeta
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ObjectMeta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
-
#cluster_name ⇒ String
Not supported by Cloud Run Corresponds to the JSON property
clusterName. -
#creation_timestamp ⇒ String
UTC timestamp representing the server time when this object was created.
-
#deletion_grace_period_seconds ⇒ Fixnum
Not supported by Cloud Run Corresponds to the JSON property
deletionGracePeriodSeconds. -
#deletion_timestamp ⇒ String
The read-only soft deletion timestamp for this resource.
-
#finalizers ⇒ Array<String>
Not supported by Cloud Run Corresponds to the JSON property
finalizers. -
#generate_name ⇒ String
Optional.
-
#generation ⇒ Fixnum
A system-provided sequence number representing a specific generation of the desired state.
-
#labels ⇒ Hash<String,String>
Map of string keys and values that can be used to organize and categorize ( scope and select) objects.
-
#name ⇒ String
Optional.
-
#namespace ⇒ String
Required.
-
#owner_references ⇒ Array<Google::Apis::RunV1::OwnerReference>
Not supported by Cloud Run Corresponds to the JSON property
ownerReferences. -
#resource_version ⇒ String
Opaque, system-generated value that represents the internal version of this object that can be used by clients to determine when objects have changed.
-
#self_link ⇒ String
URL representing this object.
-
#uid ⇒ String
Unique, system-generated identifier for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectMeta
constructor
A new instance of ObjectMeta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectMeta
Returns a new instance of ObjectMeta.
4795 4796 4797 |
# File 'lib/google/apis/run_v1/classes.rb', line 4795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Unstructured key value map stored with a resource that may be set by external
tools to store and retrieve arbitrary metadata. They are not queryable and
should be preserved when modifying objects. In Cloud Run, annotations with '
run.googleapis.com/' and 'autoscaling.knative.dev' are restricted, and the
accepted annotations will be different depending on the resource type. *
autoscaling.knative.dev/maxScale: Revision. * autoscaling.knative.dev/
minScale: Revision. * run.googleapis.com/base-images: Service, Revision. *
run.googleapis.com/binary-authorization-breakglass: Service, Job, * run.
googleapis.com/binary-authorization: Service, Job, Execution. * run.
googleapis.com/build-base-image: Service. * run.googleapis.com/build-enable-
automatic-updates: Service. * run.googleapis.com/build-environment-variables
: Service. * run.googleapis.com/build-function-target: Service, Revision. *
run.googleapis.com/build-id: Service, Revision. * run.googleapis.com/build-
image-uri: Service. * run.googleapis.com/build-name: Service. * run.
googleapis.com/build-service-account: Service. * run.googleapis.com/build-
source-location: Service, Revision. * run.googleapis.com/build-worker-pool:
Service. * run.googleapis.com/client-name: All resources. * run.googleapis.
com/cloudsql-instances: Revision, Execution. * run.googleapis.com/container-
dependencies: Revision . * run.googleapis.com/cpu-throttling: Revision. *
run.googleapis.com/custom-audiences: Service. * run.googleapis.com/default-
url-disabled: Service. * run.googleapis.com/description: Service. * run.
googleapis.com/encryption-key-shutdown-hours: Revision * run.googleapis.com/
encryption-key: Revision, Execution. * run.googleapis.com/execution-
environment: Revision, Execution. * run.googleapis.com/gc-traffic-tags:
Service. * run.googleapis.com/gpu-zonal-redundancy-disabled: Revision. *
run.googleapis.com/health-check-disabled: Revision. * run.googleapis.com/
ingress: Service, Instance. * run.googleapis.com/invoker-iam-disabled:
Service, Instance. * run.googleapis.com/launch-stage: Service, Job. * run.
googleapis.com/minScale: Service. * run.googleapis.com/maxScale: Service. *
run.googleapis.com/manualInstanceCount: Service. * run.googleapis.com/
network-interfaces: Revision, Execution. * run.googleapis.com/post-key-
revocation-action-type: Revision. run.googleapis.com/scalingMode: Service. *
run.googleapis.com/secrets: Revision, Execution. * run.googleapis.com/
secure-session-agent: Revision. * run.googleapis.com/sessionAffinity:
Revision. * run.googleapis.com/startup-cpu-boost: Revision. * run.
googleapis.com/vpc-access-connector: Revision, Execution. * run.googleapis.
com/vpc-access-egress: Revision, Execution.
Corresponds to the JSON property annotations
4708 4709 4710 |
# File 'lib/google/apis/run_v1/classes.rb', line 4708 def annotations @annotations end |
#cluster_name ⇒ String
Not supported by Cloud Run
Corresponds to the JSON property clusterName
4713 4714 4715 |
# File 'lib/google/apis/run_v1/classes.rb', line 4713 def cluster_name @cluster_name end |
#creation_timestamp ⇒ String
UTC timestamp representing the server time when this object was created.
Corresponds to the JSON property creationTimestamp
4718 4719 4720 |
# File 'lib/google/apis/run_v1/classes.rb', line 4718 def @creation_timestamp end |
#deletion_grace_period_seconds ⇒ Fixnum
Not supported by Cloud Run
Corresponds to the JSON property deletionGracePeriodSeconds
4723 4724 4725 |
# File 'lib/google/apis/run_v1/classes.rb', line 4723 def deletion_grace_period_seconds @deletion_grace_period_seconds end |
#deletion_timestamp ⇒ String
The read-only soft deletion timestamp for this resource. In Cloud Run, users
are not able to set this field. Instead, they must call the corresponding
Delete API.
Corresponds to the JSON property deletionTimestamp
4730 4731 4732 |
# File 'lib/google/apis/run_v1/classes.rb', line 4730 def @deletion_timestamp end |
#finalizers ⇒ Array<String>
Not supported by Cloud Run
Corresponds to the JSON property finalizers
4735 4736 4737 |
# File 'lib/google/apis/run_v1/classes.rb', line 4735 def finalizers @finalizers end |
#generate_name ⇒ String
Optional. A prefix for the resource name if not provided in the create request.
Must be less than 31 characters to allow for a random suffix.
Corresponds to the JSON property generateName
4741 4742 4743 |
# File 'lib/google/apis/run_v1/classes.rb', line 4741 def generate_name @generate_name end |
#generation ⇒ Fixnum
A system-provided sequence number representing a specific generation of the
desired state.
Corresponds to the JSON property generation
4747 4748 4749 |
# File 'lib/google/apis/run_v1/classes.rb', line 4747 def generation @generation end |
#labels ⇒ Hash<String,String>
Map of string keys and values that can be used to organize and categorize (
scope and select) objects. May match selectors of replication controllers and
routes.
Corresponds to the JSON property labels
4754 4755 4756 |
# File 'lib/google/apis/run_v1/classes.rb', line 4754 def labels @labels end |
#name ⇒ String
Optional. The name of the resource. A name for creating top-level resources (
Service, Job, WorkerPool). Must be unique within a Cloud Run project/region,
and cannot be changed once created. If omitted, a default name will be
generated.
Corresponds to the JSON property name
4762 4763 4764 |
# File 'lib/google/apis/run_v1/classes.rb', line 4762 def name @name end |
#namespace ⇒ String
Required. Defines the space within each name must be unique within a Cloud Run
region. In Cloud Run, it must be project ID or number.
Corresponds to the JSON property namespace
4768 4769 4770 |
# File 'lib/google/apis/run_v1/classes.rb', line 4768 def namespace @namespace end |
#owner_references ⇒ Array<Google::Apis::RunV1::OwnerReference>
Not supported by Cloud Run
Corresponds to the JSON property ownerReferences
4773 4774 4775 |
# File 'lib/google/apis/run_v1/classes.rb', line 4773 def owner_references @owner_references end |
#resource_version ⇒ String
Opaque, system-generated value that represents the internal version of this
object that can be used by clients to determine when objects have changed. May
be used for optimistic concurrency, change detection, and the watch operation
on a resource or set of resources. Clients must treat these values as opaque
and passed unmodified back to the server or omit the value to disable conflict-
detection.
Corresponds to the JSON property resourceVersion
4783 4784 4785 |
# File 'lib/google/apis/run_v1/classes.rb', line 4783 def resource_version @resource_version end |
#self_link ⇒ String
URL representing this object.
Corresponds to the JSON property selfLink
4788 4789 4790 |
# File 'lib/google/apis/run_v1/classes.rb', line 4788 def self_link @self_link end |
#uid ⇒ String
Unique, system-generated identifier for this resource.
Corresponds to the JSON property uid
4793 4794 4795 |
# File 'lib/google/apis/run_v1/classes.rb', line 4793 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 4813 4814 4815 4816 |
# File 'lib/google/apis/run_v1/classes.rb', line 4800 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_grace_period_seconds = args[:deletion_grace_period_seconds] if args.key?(:deletion_grace_period_seconds) @deletion_timestamp = args[:deletion_timestamp] if args.key?(:deletion_timestamp) @finalizers = args[:finalizers] if args.key?(:finalizers) @generate_name = args[:generate_name] if args.key?(:generate_name) @generation = args[:generation] if args.key?(:generation) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace = args[:namespace] if args.key?(:namespace) @owner_references = args[:owner_references] if args.key?(:owner_references) @resource_version = args[:resource_version] if args.key?(:resource_version) @self_link = args[:self_link] if args.key?(:self_link) @uid = args[:uid] if args.key?(:uid) end |