Class: Google::Apis::RunV1::Overrides
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Overrides
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
RunJob Overrides that contains Execution fields to be overridden on the go.
Instance Attribute Summary collapse
-
#container_overrides ⇒ Array<Google::Apis::RunV1::ContainerOverride>
Per container override specification.
-
#delay_execution ⇒ Boolean
(also: #delay_execution?)
Optional.
-
#task_count ⇒ Fixnum
The desired number of tasks the execution should run.
-
#timeout_seconds ⇒ Fixnum
Duration in seconds the task may be active before the system will actively try to mark it failed and kill associated containers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Overrides
constructor
A new instance of Overrides.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Overrides
Returns a new instance of Overrides.
5109 5110 5111 |
# File 'lib/google/apis/run_v1/classes.rb', line 5109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_overrides ⇒ Array<Google::Apis::RunV1::ContainerOverride>
Per container override specification.
Corresponds to the JSON property containerOverrides
5087 5088 5089 |
# File 'lib/google/apis/run_v1/classes.rb', line 5087 def container_overrides @container_overrides end |
#delay_execution ⇒ Boolean Also known as: delay_execution?
Optional. If true, the system will start the execution within the next 12
hours depending on available capacity.
Corresponds to the JSON property delayExecution
5093 5094 5095 |
# File 'lib/google/apis/run_v1/classes.rb', line 5093 def delay_execution @delay_execution end |
#task_count ⇒ Fixnum
The desired number of tasks the execution should run. Will replace existing
task_count value.
Corresponds to the JSON property taskCount
5100 5101 5102 |
# File 'lib/google/apis/run_v1/classes.rb', line 5100 def task_count @task_count end |
#timeout_seconds ⇒ Fixnum
Duration in seconds the task may be active before the system will actively try
to mark it failed and kill associated containers. Will replace existing
timeout_seconds value.
Corresponds to the JSON property timeoutSeconds
5107 5108 5109 |
# File 'lib/google/apis/run_v1/classes.rb', line 5107 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5114 5115 5116 5117 5118 5119 |
# File 'lib/google/apis/run_v1/classes.rb', line 5114 def update!(**args) @container_overrides = args[:container_overrides] if args.key?(:container_overrides) @delay_execution = args[:delay_execution] if args.key?(:delay_execution) @task_count = args[:task_count] if args.key?(:task_count) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |