Class: Google::Apis::RunV1::OwnerReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

This is not supported or used by Cloud Run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OwnerReference

Returns a new instance of OwnerReference.



5124
5125
5126
# File 'lib/google/apis/run_v1/classes.rb', line 5124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

This is not supported or used by Cloud Run. Corresponds to the JSON property apiVersion

Returns:

  • (String)


5095
5096
5097
# File 'lib/google/apis/run_v1/classes.rb', line 5095

def api_version
  @api_version
end

#block_owner_deletionBoolean Also known as: block_owner_deletion?

This is not supported or used by Cloud Run. Corresponds to the JSON property blockOwnerDeletion

Returns:

  • (Boolean)


5100
5101
5102
# File 'lib/google/apis/run_v1/classes.rb', line 5100

def block_owner_deletion
  @block_owner_deletion
end

#controllerBoolean Also known as: controller?

This is not supported or used by Cloud Run. Corresponds to the JSON property controller

Returns:

  • (Boolean)


5106
5107
5108
# File 'lib/google/apis/run_v1/classes.rb', line 5106

def controller
  @controller
end

#kindString

This is not supported or used by Cloud Run. Corresponds to the JSON property kind

Returns:

  • (String)


5112
5113
5114
# File 'lib/google/apis/run_v1/classes.rb', line 5112

def kind
  @kind
end

#nameString

This is not supported or used by Cloud Run. Corresponds to the JSON property name

Returns:

  • (String)


5117
5118
5119
# File 'lib/google/apis/run_v1/classes.rb', line 5117

def name
  @name
end

#uidString

This is not supported or used by Cloud Run. Corresponds to the JSON property uid

Returns:

  • (String)


5122
5123
5124
# File 'lib/google/apis/run_v1/classes.rb', line 5122

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5129
5130
5131
5132
5133
5134
5135
5136
# File 'lib/google/apis/run_v1/classes.rb', line 5129

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @block_owner_deletion = args[:block_owner_deletion] if args.key?(:block_owner_deletion)
  @controller = args[:controller] if args.key?(:controller)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
end