Class: Google::Apis::RunV1::OwnerReference
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::OwnerReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
This is not supported or used by Cloud Run.
Instance Attribute Summary collapse
-
#api_version ⇒ String
This is not supported or used by Cloud Run.
-
#block_owner_deletion ⇒ Boolean
(also: #block_owner_deletion?)
This is not supported or used by Cloud Run.
-
#controller ⇒ Boolean
(also: #controller?)
This is not supported or used by Cloud Run.
-
#kind ⇒ String
This is not supported or used by Cloud Run.
-
#name ⇒ String
This is not supported or used by Cloud Run.
-
#uid ⇒ String
This is not supported or used by Cloud Run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OwnerReference
constructor
A new instance of OwnerReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OwnerReference
Returns a new instance of OwnerReference.
5062 5063 5064 |
# File 'lib/google/apis/run_v1/classes.rb', line 5062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property apiVersion
5033 5034 5035 |
# File 'lib/google/apis/run_v1/classes.rb', line 5033 def api_version @api_version end |
#block_owner_deletion ⇒ Boolean Also known as: block_owner_deletion?
This is not supported or used by Cloud Run.
Corresponds to the JSON property blockOwnerDeletion
5038 5039 5040 |
# File 'lib/google/apis/run_v1/classes.rb', line 5038 def block_owner_deletion @block_owner_deletion end |
#controller ⇒ Boolean Also known as: controller?
This is not supported or used by Cloud Run.
Corresponds to the JSON property controller
5044 5045 5046 |
# File 'lib/google/apis/run_v1/classes.rb', line 5044 def controller @controller end |
#kind ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property kind
5050 5051 5052 |
# File 'lib/google/apis/run_v1/classes.rb', line 5050 def kind @kind end |
#name ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property name
5055 5056 5057 |
# File 'lib/google/apis/run_v1/classes.rb', line 5055 def name @name end |
#uid ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property uid
5060 5061 5062 |
# File 'lib/google/apis/run_v1/classes.rb', line 5060 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/google/apis/run_v1/classes.rb', line 5067 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @block_owner_deletion = args[:block_owner_deletion] if args.key?(:block_owner_deletion) @controller = args[:controller] if args.key?(:controller) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) end |