Class: Google::Apis::RunV1::OwnerReference
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::OwnerReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
This is not supported or used by Cloud Run.
Instance Attribute Summary collapse
-
#api_version ⇒ String
This is not supported or used by Cloud Run.
-
#block_owner_deletion ⇒ Boolean
(also: #block_owner_deletion?)
This is not supported or used by Cloud Run.
-
#controller ⇒ Boolean
(also: #controller?)
This is not supported or used by Cloud Run.
-
#kind ⇒ String
This is not supported or used by Cloud Run.
-
#name ⇒ String
This is not supported or used by Cloud Run.
-
#uid ⇒ String
This is not supported or used by Cloud Run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OwnerReference
constructor
A new instance of OwnerReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OwnerReference
Returns a new instance of OwnerReference.
4889 4890 4891 |
# File 'lib/google/apis/run_v1/classes.rb', line 4889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property apiVersion
4860 4861 4862 |
# File 'lib/google/apis/run_v1/classes.rb', line 4860 def api_version @api_version end |
#block_owner_deletion ⇒ Boolean Also known as: block_owner_deletion?
This is not supported or used by Cloud Run.
Corresponds to the JSON property blockOwnerDeletion
4865 4866 4867 |
# File 'lib/google/apis/run_v1/classes.rb', line 4865 def block_owner_deletion @block_owner_deletion end |
#controller ⇒ Boolean Also known as: controller?
This is not supported or used by Cloud Run.
Corresponds to the JSON property controller
4871 4872 4873 |
# File 'lib/google/apis/run_v1/classes.rb', line 4871 def controller @controller end |
#kind ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property kind
4877 4878 4879 |
# File 'lib/google/apis/run_v1/classes.rb', line 4877 def kind @kind end |
#name ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property name
4882 4883 4884 |
# File 'lib/google/apis/run_v1/classes.rb', line 4882 def name @name end |
#uid ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property uid
4887 4888 4889 |
# File 'lib/google/apis/run_v1/classes.rb', line 4887 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4894 4895 4896 4897 4898 4899 4900 4901 |
# File 'lib/google/apis/run_v1/classes.rb', line 4894 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @block_owner_deletion = args[:block_owner_deletion] if args.key?(:block_owner_deletion) @controller = args[:controller] if args.key?(:controller) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) end |