Class: Google::Apis::RunV1::OwnerReference
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::OwnerReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
This is not supported or used by Cloud Run.
Instance Attribute Summary collapse
-
#api_version ⇒ String
This is not supported or used by Cloud Run.
-
#block_owner_deletion ⇒ Boolean
(also: #block_owner_deletion?)
This is not supported or used by Cloud Run.
-
#controller ⇒ Boolean
(also: #controller?)
This is not supported or used by Cloud Run.
-
#kind ⇒ String
This is not supported or used by Cloud Run.
-
#name ⇒ String
This is not supported or used by Cloud Run.
-
#uid ⇒ String
This is not supported or used by Cloud Run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OwnerReference
constructor
A new instance of OwnerReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OwnerReference
Returns a new instance of OwnerReference.
4702 4703 4704 |
# File 'lib/google/apis/run_v1/classes.rb', line 4702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property apiVersion
4673 4674 4675 |
# File 'lib/google/apis/run_v1/classes.rb', line 4673 def api_version @api_version end |
#block_owner_deletion ⇒ Boolean Also known as: block_owner_deletion?
This is not supported or used by Cloud Run.
Corresponds to the JSON property blockOwnerDeletion
4678 4679 4680 |
# File 'lib/google/apis/run_v1/classes.rb', line 4678 def block_owner_deletion @block_owner_deletion end |
#controller ⇒ Boolean Also known as: controller?
This is not supported or used by Cloud Run.
Corresponds to the JSON property controller
4684 4685 4686 |
# File 'lib/google/apis/run_v1/classes.rb', line 4684 def controller @controller end |
#kind ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property kind
4690 4691 4692 |
# File 'lib/google/apis/run_v1/classes.rb', line 4690 def kind @kind end |
#name ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property name
4695 4696 4697 |
# File 'lib/google/apis/run_v1/classes.rb', line 4695 def name @name end |
#uid ⇒ String
This is not supported or used by Cloud Run.
Corresponds to the JSON property uid
4700 4701 4702 |
# File 'lib/google/apis/run_v1/classes.rb', line 4700 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4707 4708 4709 4710 4711 4712 4713 4714 |
# File 'lib/google/apis/run_v1/classes.rb', line 4707 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @block_owner_deletion = args[:block_owner_deletion] if args.key?(:block_owner_deletion) @controller = args[:controller] if args.key?(:controller) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) end |