Class: Google::Apis::RunV1::Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Probe

Returns a new instance of Probe.



5301
5302
5303
# File 'lib/google/apis/run_v1/classes.rb', line 5301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::RunV1::ExecAction

Not supported by Cloud Run. ExecAction describes a "run in container" action. Corresponds to the JSON property exec



5251
5252
5253
# File 'lib/google/apis/run_v1/classes.rb', line 5251

def exec
  @exec
end

#failure_thresholdFixnum

Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


5257
5258
5259
# File 'lib/google/apis/run_v1/classes.rb', line 5257

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::RunV1::GrpcAction

GRPCAction describes an action involving a GRPC port. Corresponds to the JSON property grpc



5262
5263
5264
# File 'lib/google/apis/run_v1/classes.rb', line 5262

def grpc
  @grpc
end

#http_getGoogle::Apis::RunV1::HttpGetAction

HTTPGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



5267
5268
5269
# File 'lib/google/apis/run_v1/classes.rb', line 5267

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds after the container has started before the probe is initiated. Defaults to 0 seconds. Minimum value is 0. Maximum value for liveness probe is 3600. Maximum value for startup probe is 240. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


5274
5275
5276
# File 'lib/google/apis/run_v1/classes.rb', line 5274

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Maximum value for liveness probe is 3600. Maximum value for startup probe is 240. Must be greater or equal than timeout_seconds. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


5281
5282
5283
# File 'lib/google/apis/run_v1/classes.rb', line 5281

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Minimum consecutive successes for the probe to be considered successful after having failed. Must be 1 if set. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


5287
5288
5289
# File 'lib/google/apis/run_v1/classes.rb', line 5287

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::RunV1::TcpSocketAction

TCPSocketAction describes an action based on opening a socket Corresponds to the JSON property tcpSocket



5292
5293
5294
# File 'lib/google/apis/run_v1/classes.rb', line 5292

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Maximum value is 3600. Must be smaller than period_seconds; if period_seconds is not set, must be less or equal than 10. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


5299
5300
5301
# File 'lib/google/apis/run_v1/classes.rb', line 5299

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5306
5307
5308
5309
5310
5311
5312
5313
5314
5315
5316
# File 'lib/google/apis/run_v1/classes.rb', line 5306

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end