Class: Google::Apis::RunV1::Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Revision is an immutable snapshot of code and configuration. A revision references one or more container images. Revisions are created by updates to a Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Revision

Returns a new instance of Revision.



5403
5404
5405
# File 'lib/google/apis/run_v1/classes.rb', line 5403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


5379
5380
5381
# File 'lib/google/apis/run_v1/classes.rb', line 5379

def api_version
  @api_version
end

#kindString

The kind of this resource, in this case "Revision". Corresponds to the JSON property kind

Returns:

  • (String)


5384
5385
5386
# File 'lib/google/apis/run_v1/classes.rb', line 5384

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5390
5391
5392
# File 'lib/google/apis/run_v1/classes.rb', line 5390

def 
  @metadata
end

#specGoogle::Apis::RunV1::RevisionSpec

RevisionSpec holds the desired state of the Revision (from the client). Corresponds to the JSON property spec



5395
5396
5397
# File 'lib/google/apis/run_v1/classes.rb', line 5395

def spec
  @spec
end

#statusGoogle::Apis::RunV1::RevisionStatus

RevisionStatus communicates the observed state of the Revision (from the controller). Corresponds to the JSON property status



5401
5402
5403
# File 'lib/google/apis/run_v1/classes.rb', line 5401

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5408
5409
5410
5411
5412
5413
5414
# File 'lib/google/apis/run_v1/classes.rb', line 5408

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end