Class: Google::Apis::RunV1::Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Revision is an immutable snapshot of code and configuration. A revision references one or more container images. Revisions are created by updates to a Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Revision

Returns a new instance of Revision.



5348
5349
5350
# File 'lib/google/apis/run_v1/classes.rb', line 5348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


5324
5325
5326
# File 'lib/google/apis/run_v1/classes.rb', line 5324

def api_version
  @api_version
end

#kindString

The kind of this resource, in this case "Revision". Corresponds to the JSON property kind

Returns:

  • (String)


5329
5330
5331
# File 'lib/google/apis/run_v1/classes.rb', line 5329

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5335
5336
5337
# File 'lib/google/apis/run_v1/classes.rb', line 5335

def 
  @metadata
end

#specGoogle::Apis::RunV1::RevisionSpec

RevisionSpec holds the desired state of the Revision (from the client). Corresponds to the JSON property spec



5340
5341
5342
# File 'lib/google/apis/run_v1/classes.rb', line 5340

def spec
  @spec
end

#statusGoogle::Apis::RunV1::RevisionStatus

RevisionStatus communicates the observed state of the Revision (from the controller). Corresponds to the JSON property status



5346
5347
5348
# File 'lib/google/apis/run_v1/classes.rb', line 5346

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5353
5354
5355
5356
5357
5358
5359
# File 'lib/google/apis/run_v1/classes.rb', line 5353

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end