Class: Google::Apis::RunV1::Revision
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Revision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Revision is an immutable snapshot of code and configuration. A revision references a container image. Revisions are created by updates to a Configuration. See also: https://github.com/knative/specs/blob/main/specs/ serving/overview.md#revision
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
-
#kind ⇒ String
The kind of this resource, in this case "Revision".
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::RevisionSpec
RevisionSpec holds the desired state of the Revision (from the client).
-
#status ⇒ Google::Apis::RunV1::RevisionStatus
RevisionStatus communicates the observed state of the Revision (from the controller).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Revision
constructor
A new instance of Revision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Revision
Returns a new instance of Revision.
4989 4990 4991 |
# File 'lib/google/apis/run_v1/classes.rb', line 4989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call such as "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
4965 4966 4967 |
# File 'lib/google/apis/run_v1/classes.rb', line 4965 def api_version @api_version end |
#kind ⇒ String
The kind of this resource, in this case "Revision".
Corresponds to the JSON property kind
4970 4971 4972 |
# File 'lib/google/apis/run_v1/classes.rb', line 4970 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
4976 4977 4978 |
# File 'lib/google/apis/run_v1/classes.rb', line 4976 def @metadata end |
#spec ⇒ Google::Apis::RunV1::RevisionSpec
RevisionSpec holds the desired state of the Revision (from the client).
Corresponds to the JSON property spec
4981 4982 4983 |
# File 'lib/google/apis/run_v1/classes.rb', line 4981 def spec @spec end |
#status ⇒ Google::Apis::RunV1::RevisionStatus
RevisionStatus communicates the observed state of the Revision (from the
controller).
Corresponds to the JSON property status
4987 4988 4989 |
# File 'lib/google/apis/run_v1/classes.rb', line 4987 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4994 4995 4996 4997 4998 4999 5000 |
# File 'lib/google/apis/run_v1/classes.rb', line 4994 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |