Class: Google::Apis::RunV1::RevisionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::RevisionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
RevisionSpec holds the desired state of the Revision (from the client).
Instance Attribute Summary collapse
-
#container_concurrency ⇒ Fixnum
ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision.
-
#containers ⇒ Array<Google::Apis::RunV1::Container>
Required.
-
#enable_service_links ⇒ Boolean
(also: #enable_service_links?)
Not supported by Cloud Run.
-
#image_pull_secrets ⇒ Array<Google::Apis::RunV1::LocalObjectReference>
Not supported by Cloud Run.
-
#node_selector ⇒ Hash<String,String>
Optional.
-
#runtime_class_name ⇒ String
Optional.
-
#service_account_name ⇒ String
Email address of the IAM service account associated with the revision of the service.
-
#timeout_seconds ⇒ Fixnum
Optional.
-
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Corresponds to the JSON property
volumes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevisionSpec
constructor
A new instance of RevisionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevisionSpec
Returns a new instance of RevisionSpec.
5493 5494 5495 |
# File 'lib/google/apis/run_v1/classes.rb', line 5493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_concurrency ⇒ Fixnum
ContainerConcurrency specifies the maximum allowed in-flight (concurrent)
requests per container instance of the Revision. If not specified or 0,
defaults to 80 when requested CPU >= 1 and defaults to 1 when requested CPU <
1.
Corresponds to the JSON property containerConcurrency
5443 5444 5445 |
# File 'lib/google/apis/run_v1/classes.rb', line 5443 def container_concurrency @container_concurrency end |
#containers ⇒ Array<Google::Apis::RunV1::Container>
Required. Containers holds the list which define the units of execution for
this Revision.
Corresponds to the JSON property containers
5449 5450 5451 |
# File 'lib/google/apis/run_v1/classes.rb', line 5449 def containers @containers end |
#enable_service_links ⇒ Boolean Also known as: enable_service_links?
Not supported by Cloud Run.
Corresponds to the JSON property enableServiceLinks
5454 5455 5456 |
# File 'lib/google/apis/run_v1/classes.rb', line 5454 def enable_service_links @enable_service_links end |
#image_pull_secrets ⇒ Array<Google::Apis::RunV1::LocalObjectReference>
Not supported by Cloud Run.
Corresponds to the JSON property imagePullSecrets
5460 5461 5462 |
# File 'lib/google/apis/run_v1/classes.rb', line 5460 def image_pull_secrets @image_pull_secrets end |
#node_selector ⇒ Hash<String,String>
Optional. The Node Selector configuration. Map of selector key to a value
which matches a node.
Corresponds to the JSON property nodeSelector
5466 5467 5468 |
# File 'lib/google/apis/run_v1/classes.rb', line 5466 def node_selector @node_selector end |
#runtime_class_name ⇒ String
Optional. Runtime. Leave unset for default.
Corresponds to the JSON property runtimeClassName
5471 5472 5473 |
# File 'lib/google/apis/run_v1/classes.rb', line 5471 def runtime_class_name @runtime_class_name end |
#service_account_name ⇒ String
Email address of the IAM service account associated with the revision of the
service. The service account represents the identity of the running revision,
and determines what permissions the revision has. If not provided, the
revision will use the project's default service account.
Corresponds to the JSON property serviceAccountName
5479 5480 5481 |
# File 'lib/google/apis/run_v1/classes.rb', line 5479 def service_account_name @service_account_name end |
#timeout_seconds ⇒ Fixnum
Optional. TimeoutSeconds holds the max duration the instance is allowed for
responding to a request. Cloud Run: defaults to 300 seconds (5 minutes).
Maximum allowed value is 3600 seconds (1 hour).
Corresponds to the JSON property timeoutSeconds
5486 5487 5488 |
# File 'lib/google/apis/run_v1/classes.rb', line 5486 def timeout_seconds @timeout_seconds end |
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Corresponds to the JSON property volumes
5491 5492 5493 |
# File 'lib/google/apis/run_v1/classes.rb', line 5491 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 |
# File 'lib/google/apis/run_v1/classes.rb', line 5498 def update!(**args) @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency) @containers = args[:containers] if args.key?(:containers) @enable_service_links = args[:enable_service_links] if args.key?(:enable_service_links) @image_pull_secrets = args[:image_pull_secrets] if args.key?(:image_pull_secrets) @node_selector = args[:node_selector] if args.key?(:node_selector) @runtime_class_name = args[:runtime_class_name] if args.key?(:runtime_class_name) @service_account_name = args[:service_account_name] if args.key?(:service_account_name) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) @volumes = args[:volumes] if args.key?(:volumes) end |