Class: Google::Apis::RunV1::RevisionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionSpec holds the desired state of the Revision (from the client).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionSpec

Returns a new instance of RevisionSpec.



5484
5485
5486
# File 'lib/google/apis/run_v1/classes.rb', line 5484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_concurrencyFixnum

ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision. If not specified or 0, defaults to 80 when requested CPU >= 1 and defaults to 1 when requested CPU < 1. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


5434
5435
5436
# File 'lib/google/apis/run_v1/classes.rb', line 5434

def container_concurrency
  @container_concurrency
end

#containersArray<Google::Apis::RunV1::Container>

Required. Containers holds the list which define the units of execution for this Revision. Corresponds to the JSON property containers

Returns:



5440
5441
5442
# File 'lib/google/apis/run_v1/classes.rb', line 5440

def containers
  @containers
end

Not supported by Cloud Run. Corresponds to the JSON property enableServiceLinks

Returns:

  • (Boolean)


5445
5446
5447
# File 'lib/google/apis/run_v1/classes.rb', line 5445

def enable_service_links
  @enable_service_links
end

#image_pull_secretsArray<Google::Apis::RunV1::LocalObjectReference>

Not supported by Cloud Run. Corresponds to the JSON property imagePullSecrets



5451
5452
5453
# File 'lib/google/apis/run_v1/classes.rb', line 5451

def image_pull_secrets
  @image_pull_secrets
end

#node_selectorHash<String,String>

Optional. The Node Selector configuration. Map of selector key to a value which matches a node. Corresponds to the JSON property nodeSelector

Returns:

  • (Hash<String,String>)


5457
5458
5459
# File 'lib/google/apis/run_v1/classes.rb', line 5457

def node_selector
  @node_selector
end

#runtime_class_nameString

Optional. Runtime. Leave unset for default. Corresponds to the JSON property runtimeClassName

Returns:

  • (String)


5462
5463
5464
# File 'lib/google/apis/run_v1/classes.rb', line 5462

def runtime_class_name
  @runtime_class_name
end

#service_account_nameString

Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project's default service account. Corresponds to the JSON property serviceAccountName

Returns:

  • (String)


5470
5471
5472
# File 'lib/google/apis/run_v1/classes.rb', line 5470

def 
  @service_account_name
end

#timeout_secondsFixnum

Optional. TimeoutSeconds holds the max duration the instance is allowed for responding to a request. Cloud Run: defaults to 300 seconds (5 minutes). Maximum allowed value is 3600 seconds (1 hour). Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


5477
5478
5479
# File 'lib/google/apis/run_v1/classes.rb', line 5477

def timeout_seconds
  @timeout_seconds
end

#volumesArray<Google::Apis::RunV1::Volume>

Corresponds to the JSON property volumes

Returns:



5482
5483
5484
# File 'lib/google/apis/run_v1/classes.rb', line 5482

def volumes
  @volumes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/google/apis/run_v1/classes.rb', line 5489

def update!(**args)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @containers = args[:containers] if args.key?(:containers)
  @enable_service_links = args[:enable_service_links] if args.key?(:enable_service_links)
  @image_pull_secrets = args[:image_pull_secrets] if args.key?(:image_pull_secrets)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @runtime_class_name = args[:runtime_class_name] if args.key?(:runtime_class_name)
  @service_account_name = args[:service_account_name] if args.key?(:service_account_name)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
  @volumes = args[:volumes] if args.key?(:volumes)
end