Class: Google::Apis::RunV1::RevisionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::RevisionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
RevisionSpec holds the desired state of the Revision (from the client).
Instance Attribute Summary collapse
-
#container_concurrency ⇒ Fixnum
ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision.
-
#containers ⇒ Array<Google::Apis::RunV1::Container>
Required.
-
#enable_service_links ⇒ Boolean
(also: #enable_service_links?)
Not supported by Cloud Run.
-
#image_pull_secrets ⇒ Array<Google::Apis::RunV1::LocalObjectReference>
Not supported by Cloud Run.
-
#node_selector ⇒ Hash<String,String>
Optional.
-
#runtime_class_name ⇒ String
Optional.
-
#service_account_name ⇒ String
Email address of the IAM service account associated with the revision of the service.
-
#timeout_seconds ⇒ Fixnum
Optional.
-
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Corresponds to the JSON property
volumes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevisionSpec
constructor
A new instance of RevisionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevisionSpec
Returns a new instance of RevisionSpec.
5249 5250 5251 |
# File 'lib/google/apis/run_v1/classes.rb', line 5249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_concurrency ⇒ Fixnum
ContainerConcurrency specifies the maximum allowed in-flight (concurrent)
requests per container instance of the Revision. If not specified or 0,
defaults to 80 when requested CPU >= 1 and defaults to 1 when requested CPU <
1.
Corresponds to the JSON property containerConcurrency
5199 5200 5201 |
# File 'lib/google/apis/run_v1/classes.rb', line 5199 def container_concurrency @container_concurrency end |
#containers ⇒ Array<Google::Apis::RunV1::Container>
Required. Containers holds the list which define the units of execution for
this Revision.
Corresponds to the JSON property containers
5205 5206 5207 |
# File 'lib/google/apis/run_v1/classes.rb', line 5205 def containers @containers end |
#enable_service_links ⇒ Boolean Also known as: enable_service_links?
Not supported by Cloud Run.
Corresponds to the JSON property enableServiceLinks
5210 5211 5212 |
# File 'lib/google/apis/run_v1/classes.rb', line 5210 def enable_service_links @enable_service_links end |
#image_pull_secrets ⇒ Array<Google::Apis::RunV1::LocalObjectReference>
Not supported by Cloud Run.
Corresponds to the JSON property imagePullSecrets
5216 5217 5218 |
# File 'lib/google/apis/run_v1/classes.rb', line 5216 def image_pull_secrets @image_pull_secrets end |
#node_selector ⇒ Hash<String,String>
Optional. The Node Selector configuration. Map of selector key to a value
which matches a node.
Corresponds to the JSON property nodeSelector
5222 5223 5224 |
# File 'lib/google/apis/run_v1/classes.rb', line 5222 def node_selector @node_selector end |
#runtime_class_name ⇒ String
Optional. Runtime. Leave unset for default.
Corresponds to the JSON property runtimeClassName
5227 5228 5229 |
# File 'lib/google/apis/run_v1/classes.rb', line 5227 def runtime_class_name @runtime_class_name end |
#service_account_name ⇒ String
Email address of the IAM service account associated with the revision of the
service. The service account represents the identity of the running revision,
and determines what permissions the revision has. If not provided, the
revision will use the project's default service account.
Corresponds to the JSON property serviceAccountName
5235 5236 5237 |
# File 'lib/google/apis/run_v1/classes.rb', line 5235 def service_account_name @service_account_name end |
#timeout_seconds ⇒ Fixnum
Optional. TimeoutSeconds holds the max duration the instance is allowed for
responding to a request. Cloud Run: defaults to 300 seconds (5 minutes).
Maximum allowed value is 3600 seconds (1 hour).
Corresponds to the JSON property timeoutSeconds
5242 5243 5244 |
# File 'lib/google/apis/run_v1/classes.rb', line 5242 def timeout_seconds @timeout_seconds end |
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Corresponds to the JSON property volumes
5247 5248 5249 |
# File 'lib/google/apis/run_v1/classes.rb', line 5247 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 |
# File 'lib/google/apis/run_v1/classes.rb', line 5254 def update!(**args) @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency) @containers = args[:containers] if args.key?(:containers) @enable_service_links = args[:enable_service_links] if args.key?(:enable_service_links) @image_pull_secrets = args[:image_pull_secrets] if args.key?(:image_pull_secrets) @node_selector = args[:node_selector] if args.key?(:node_selector) @runtime_class_name = args[:runtime_class_name] if args.key?(:runtime_class_name) @service_account_name = args[:service_account_name] if args.key?(:service_account_name) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) @volumes = args[:volumes] if args.key?(:volumes) end |