Class: Google::Apis::RunV1::RevisionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionSpec holds the desired state of the Revision (from the client).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionSpec

Returns a new instance of RevisionSpec.



5064
5065
5066
# File 'lib/google/apis/run_v1/classes.rb', line 5064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_concurrencyFixnum

ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision. If not specified or 0, defaults to 80 when requested CPU >= 1 and defaults to 1 when requested CPU < 1. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


5013
5014
5015
# File 'lib/google/apis/run_v1/classes.rb', line 5013

def container_concurrency
  @container_concurrency
end

#containersArray<Google::Apis::RunV1::Container>

Required. Containers holds the list which define the units of execution for this Revision. In the context of a Revision, we disallow a number of fields on this Container, including: name and lifecycle. Corresponds to the JSON property containers

Returns:



5020
5021
5022
# File 'lib/google/apis/run_v1/classes.rb', line 5020

def containers
  @containers
end

Not supported by Cloud Run. Corresponds to the JSON property enableServiceLinks

Returns:

  • (Boolean)


5025
5026
5027
# File 'lib/google/apis/run_v1/classes.rb', line 5025

def enable_service_links
  @enable_service_links
end

#image_pull_secretsArray<Google::Apis::RunV1::LocalObjectReference>

Not supported by Cloud Run. Corresponds to the JSON property imagePullSecrets



5031
5032
5033
# File 'lib/google/apis/run_v1/classes.rb', line 5031

def image_pull_secrets
  @image_pull_secrets
end

#node_selectorHash<String,String>

Optional. The Node Selector configuration. Map of selector key to a value which matches a node. Corresponds to the JSON property nodeSelector

Returns:

  • (Hash<String,String>)


5037
5038
5039
# File 'lib/google/apis/run_v1/classes.rb', line 5037

def node_selector
  @node_selector
end

#runtime_class_nameString

Optional. Runtime. Leave unset for default. Corresponds to the JSON property runtimeClassName

Returns:

  • (String)


5042
5043
5044
# File 'lib/google/apis/run_v1/classes.rb', line 5042

def runtime_class_name
  @runtime_class_name
end

#service_account_nameString

Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project's default service account. Corresponds to the JSON property serviceAccountName

Returns:

  • (String)


5050
5051
5052
# File 'lib/google/apis/run_v1/classes.rb', line 5050

def 
  @service_account_name
end

#timeout_secondsFixnum

Optional. TimeoutSeconds holds the max duration the instance is allowed for responding to a request. Cloud Run: defaults to 300 seconds (5 minutes). Maximum allowed value is 3600 seconds (1 hour). Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


5057
5058
5059
# File 'lib/google/apis/run_v1/classes.rb', line 5057

def timeout_seconds
  @timeout_seconds
end

#volumesArray<Google::Apis::RunV1::Volume>

Corresponds to the JSON property volumes

Returns:



5062
5063
5064
# File 'lib/google/apis/run_v1/classes.rb', line 5062

def volumes
  @volumes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
# File 'lib/google/apis/run_v1/classes.rb', line 5069

def update!(**args)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @containers = args[:containers] if args.key?(:containers)
  @enable_service_links = args[:enable_service_links] if args.key?(:enable_service_links)
  @image_pull_secrets = args[:image_pull_secrets] if args.key?(:image_pull_secrets)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @runtime_class_name = args[:runtime_class_name] if args.key?(:runtime_class_name)
  @service_account_name = args[:service_account_name] if args.key?(:service_account_name)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
  @volumes = args[:volumes] if args.key?(:volumes)
end