Class: Google::Apis::RunV1::RevisionStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::RevisionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
RevisionStatus communicates the observed state of the Revision (from the controller).
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
-
#desired_replicas ⇒ Fixnum
Output only.
-
#image_digest ⇒ String
ImageDigest holds the resolved digest for the image specified within .Spec.
-
#log_url ⇒ String
Optional.
-
#observed_generation ⇒ Fixnum
ObservedGeneration is the 'Generation' of the Revision that was last processed by the controller.
-
#service_name ⇒ String
Not currently used by Cloud Run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevisionStatus
constructor
A new instance of RevisionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevisionStatus
Returns a new instance of RevisionStatus.
5545 5546 5547 |
# File 'lib/google/apis/run_v1/classes.rb', line 5545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the "spec" inline with the observed state of the world.
As a Revision is being prepared, it will incrementally update conditions.
Revision-specific conditions include: * ResourcesAvailable: True when
underlying resources have been provisioned. * ContainerHealthy: True when
the Revision readiness check completes. * Active: True when the Revision
may receive traffic.
Corresponds to the JSON property conditions
5509 5510 5511 |
# File 'lib/google/apis/run_v1/classes.rb', line 5509 def conditions @conditions end |
#desired_replicas ⇒ Fixnum
Output only. The configured number of instances running this revision. For
Cloud Run, this only includes instances provisioned using the minScale
annotation. It does not include instances created by autoscaling.
Corresponds to the JSON property desiredReplicas
5516 5517 5518 |
# File 'lib/google/apis/run_v1/classes.rb', line 5516 def desired_replicas @desired_replicas end |
#image_digest ⇒ String
ImageDigest holds the resolved digest for the image specified within .Spec.
Container.Image. The digest is resolved during the creation of Revision. This
field holds the digest value regardless of whether a tag or digest was
originally specified in the Container object.
Corresponds to the JSON property imageDigest
5524 5525 5526 |
# File 'lib/google/apis/run_v1/classes.rb', line 5524 def image_digest @image_digest end |
#log_url ⇒ String
Optional. Specifies the generated logging url for this particular revision
based on the revision url template specified in the controller's config.
Corresponds to the JSON property logUrl
5530 5531 5532 |
# File 'lib/google/apis/run_v1/classes.rb', line 5530 def log_url @log_url end |
#observed_generation ⇒ Fixnum
ObservedGeneration is the 'Generation' of the Revision that was last processed
by the controller. Clients polling for completed reconciliation should poll
until observedGeneration = metadata.generation, and the Ready condition's
status is True or False.
Corresponds to the JSON property observedGeneration
5538 5539 5540 |
# File 'lib/google/apis/run_v1/classes.rb', line 5538 def observed_generation @observed_generation end |
#service_name ⇒ String
Not currently used by Cloud Run.
Corresponds to the JSON property serviceName
5543 5544 5545 |
# File 'lib/google/apis/run_v1/classes.rb', line 5543 def service_name @service_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/google/apis/run_v1/classes.rb', line 5550 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @desired_replicas = args[:desired_replicas] if args.key?(:desired_replicas) @image_digest = args[:image_digest] if args.key?(:image_digest) @log_url = args[:log_url] if args.key?(:log_url) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @service_name = args[:service_name] if args.key?(:service_name) end |