Class: Google::Apis::RunV1::RevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionStatus communicates the observed state of the Revision (from the controller).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionStatus

Returns a new instance of RevisionStatus.



5490
5491
5492
# File 'lib/google/apis/run_v1/classes.rb', line 5490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. As a Revision is being prepared, it will incrementally update conditions. Revision-specific conditions include: * ResourcesAvailable: True when underlying resources have been provisioned. * ContainerHealthy: True when the Revision readiness check completes. * Active: True when the Revision may receive traffic. Corresponds to the JSON property conditions



5454
5455
5456
# File 'lib/google/apis/run_v1/classes.rb', line 5454

def conditions
  @conditions
end

#desired_replicasFixnum

Output only. The configured number of instances running this revision. For Cloud Run, this only includes instances provisioned using the minScale annotation. It does not include instances created by autoscaling. Corresponds to the JSON property desiredReplicas

Returns:

  • (Fixnum)


5461
5462
5463
# File 'lib/google/apis/run_v1/classes.rb', line 5461

def desired_replicas
  @desired_replicas
end

#image_digestString

ImageDigest holds the resolved digest for the image specified within .Spec. Container.Image. The digest is resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object. Corresponds to the JSON property imageDigest

Returns:

  • (String)


5469
5470
5471
# File 'lib/google/apis/run_v1/classes.rb', line 5469

def image_digest
  @image_digest
end

#log_urlString

Optional. Specifies the generated logging url for this particular revision based on the revision url template specified in the controller's config. Corresponds to the JSON property logUrl

Returns:

  • (String)


5475
5476
5477
# File 'lib/google/apis/run_v1/classes.rb', line 5475

def log_url
  @log_url
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the Revision that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation, and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


5483
5484
5485
# File 'lib/google/apis/run_v1/classes.rb', line 5483

def observed_generation
  @observed_generation
end

#service_nameString

Not currently used by Cloud Run. Corresponds to the JSON property serviceName

Returns:

  • (String)


5488
5489
5490
# File 'lib/google/apis/run_v1/classes.rb', line 5488

def service_name
  @service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5495
5496
5497
5498
5499
5500
5501
5502
# File 'lib/google/apis/run_v1/classes.rb', line 5495

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @desired_replicas = args[:desired_replicas] if args.key?(:desired_replicas)
  @image_digest = args[:image_digest] if args.key?(:image_digest)
  @log_url = args[:log_url] if args.key?(:log_url)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @service_name = args[:service_name] if args.key?(:service_name)
end