Class: Google::Apis::RunV1::RevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionStatus communicates the observed state of the Revision (from the controller).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionStatus

Returns a new instance of RevisionStatus.



5132
5133
5134
# File 'lib/google/apis/run_v1/classes.rb', line 5132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. As a Revision is being prepared, it will incrementally update conditions. Revision-specific conditions include: * ResourcesAvailable: True when underlying resources have been provisioned. * ContainerHealthy: True when the Revision readiness check completes. * Active: True when the Revision may receive traffic. Corresponds to the JSON property conditions



5096
5097
5098
# File 'lib/google/apis/run_v1/classes.rb', line 5096

def conditions
  @conditions
end

#desired_replicasFixnum

Output only. The configured number of instances running this revision. For Cloud Run, this only includes instances provisioned using the minScale annotation. It does not include instances created by autoscaling. Corresponds to the JSON property desiredReplicas

Returns:

  • (Fixnum)


5103
5104
5105
# File 'lib/google/apis/run_v1/classes.rb', line 5103

def desired_replicas
  @desired_replicas
end

#image_digestString

ImageDigest holds the resolved digest for the image specified within .Spec. Container.Image. The digest is resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object. Corresponds to the JSON property imageDigest

Returns:

  • (String)


5111
5112
5113
# File 'lib/google/apis/run_v1/classes.rb', line 5111

def image_digest
  @image_digest
end

#log_urlString

Optional. Specifies the generated logging url for this particular revision based on the revision url template specified in the controller's config. Corresponds to the JSON property logUrl

Returns:

  • (String)


5117
5118
5119
# File 'lib/google/apis/run_v1/classes.rb', line 5117

def log_url
  @log_url
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the Revision that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation, and the Ready condition's status is True or False. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


5125
5126
5127
# File 'lib/google/apis/run_v1/classes.rb', line 5125

def observed_generation
  @observed_generation
end

#service_nameString

Not currently used by Cloud Run. Corresponds to the JSON property serviceName

Returns:

  • (String)


5130
5131
5132
# File 'lib/google/apis/run_v1/classes.rb', line 5130

def service_name
  @service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5137
5138
5139
5140
5141
5142
5143
5144
# File 'lib/google/apis/run_v1/classes.rb', line 5137

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @desired_replicas = args[:desired_replicas] if args.key?(:desired_replicas)
  @image_digest = args[:image_digest] if args.key?(:image_digest)
  @log_url = args[:log_url] if args.key?(:log_url)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @service_name = args[:service_name] if args.key?(:service_name)
end