Class: Google::Apis::RunV1::RevisionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionTemplateSpec describes the data a revision should have when created from a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionTemplate

Returns a new instance of RevisionTemplate.



5576
5577
5578
# File 'lib/google/apis/run_v1/classes.rb', line 5576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5569
5570
5571
# File 'lib/google/apis/run_v1/classes.rb', line 5569

def 
  @metadata
end

#specGoogle::Apis::RunV1::RevisionSpec

RevisionSpec holds the desired state of the Revision (from the client). Corresponds to the JSON property spec



5574
5575
5576
# File 'lib/google/apis/run_v1/classes.rb', line 5574

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5581
5582
5583
5584
# File 'lib/google/apis/run_v1/classes.rb', line 5581

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
end