Class: Google::Apis::RunV1::RevisionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RevisionTemplateSpec describes the data a revision should have when created from a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionTemplate

Returns a new instance of RevisionTemplate.



5348
5349
5350
# File 'lib/google/apis/run_v1/classes.rb', line 5348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5341
5342
5343
# File 'lib/google/apis/run_v1/classes.rb', line 5341

def 
  @metadata
end

#specGoogle::Apis::RunV1::RevisionSpec

RevisionSpec holds the desired state of the Revision (from the client). Corresponds to the JSON property spec



5346
5347
5348
# File 'lib/google/apis/run_v1/classes.rb', line 5346

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5353
5354
5355
5356
# File 'lib/google/apis/run_v1/classes.rb', line 5353

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
end