Class: Google::Apis::RunV1::Route

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Route is responsible for configuring ingress over a collection of Revisions. Some of the Revisions a Route distributes traffic over may be specified by referencing the Configuration responsible for creating them; in these cases the Route is additionally responsible for monitoring the Configuration for " latest ready" revision changes, and smoothly rolling out latest revisions. Cloud Run currently supports referencing a single Configuration to automatically deploy the "latest ready" Revision from that Configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



5644
5645
5646
# File 'lib/google/apis/run_v1/classes.rb', line 5644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call such as "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


5621
5622
5623
# File 'lib/google/apis/run_v1/classes.rb', line 5621

def api_version
  @api_version
end

#kindString

The kind of this resource, in this case always "Route". Corresponds to the JSON property kind

Returns:

  • (String)


5626
5627
5628
# File 'lib/google/apis/run_v1/classes.rb', line 5626

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5632
5633
5634
# File 'lib/google/apis/run_v1/classes.rb', line 5632

def 
  @metadata
end

#specGoogle::Apis::RunV1::RouteSpec

RouteSpec holds the desired state of the Route (from the client). Corresponds to the JSON property spec



5637
5638
5639
# File 'lib/google/apis/run_v1/classes.rb', line 5637

def spec
  @spec
end

#statusGoogle::Apis::RunV1::RouteStatus

RouteStatus communicates the observed state of the Route (from the controller). Corresponds to the JSON property status



5642
5643
5644
# File 'lib/google/apis/run_v1/classes.rb', line 5642

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5649
5650
5651
5652
5653
5654
5655
# File 'lib/google/apis/run_v1/classes.rb', line 5649

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end