Class: Google::Apis::RunV1::RouteStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::RouteStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
RouteStatus communicates the observed state of the Route (from the controller).
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicates information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
-
#observed_generation ⇒ Fixnum
ObservedGeneration is the 'Generation' of the Route that was last processed by the controller.
-
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Traffic holds the configured traffic distribution.
-
#url ⇒ String
URL holds the url that will distribute traffic over the provided traffic targets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteStatus
constructor
A new instance of RouteStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteStatus
Returns a new instance of RouteStatus.
5719 5720 5721 |
# File 'lib/google/apis/run_v1/classes.rb', line 5719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
Corresponds to the JSON property address
5686 5687 5688 |
# File 'lib/google/apis/run_v1/classes.rb', line 5686 def address @address end |
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicates information about ongoing/complete reconciliation
processes that bring the "spec" inline with the observed state of the world.
Corresponds to the JSON property conditions
5692 5693 5694 |
# File 'lib/google/apis/run_v1/classes.rb', line 5692 def conditions @conditions end |
#observed_generation ⇒ Fixnum
ObservedGeneration is the 'Generation' of the Route that was last processed by
the controller. Clients polling for completed reconciliation should poll until
observedGeneration = metadata.generation and the Ready condition's status is
True or False. Note that providing a TrafficTarget that has latest_revision=
True will result in a Route that does not increment either its metadata.
generation or its observedGeneration, as new "latest ready" revisions from the
Configuration are processed without an update to the Route's spec.
Corresponds to the JSON property observedGeneration
5703 5704 5705 |
# File 'lib/google/apis/run_v1/classes.rb', line 5703 def observed_generation @observed_generation end |
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Traffic holds the configured traffic distribution. These entries will always
contain RevisionName references. When ConfigurationName appears in the spec,
this will hold the LatestReadyRevisionName that was last observed.
Corresponds to the JSON property traffic
5710 5711 5712 |
# File 'lib/google/apis/run_v1/classes.rb', line 5710 def traffic @traffic end |
#url ⇒ String
URL holds the url that will distribute traffic over the provided traffic
targets. It generally has the form: https://route-hash-project-hash-
cluster-level-suffix.a.run.app
Corresponds to the JSON property url
5717 5718 5719 |
# File 'lib/google/apis/run_v1/classes.rb', line 5717 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5724 5725 5726 5727 5728 5729 5730 |
# File 'lib/google/apis/run_v1/classes.rb', line 5724 def update!(**args) @address = args[:address] if args.key?(:address) @conditions = args[:conditions] if args.key?(:conditions) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @traffic = args[:traffic] if args.key?(:traffic) @url = args[:url] if args.key?(:url) end |