Class: Google::Apis::RunV1::RouteStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

RouteStatus communicates the observed state of the Route (from the controller).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteStatus

Returns a new instance of RouteStatus.



5698
5699
5700
# File 'lib/google/apis/run_v1/classes.rb', line 5698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressGoogle::Apis::RunV1::Addressable

Information for connecting over HTTP(s). Corresponds to the JSON property address



5665
5666
5667
# File 'lib/google/apis/run_v1/classes.rb', line 5665

def address
  @address
end

#conditionsArray<Google::Apis::RunV1::GoogleCloudRunV1Condition>

Conditions communicates information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world. Corresponds to the JSON property conditions



5671
5672
5673
# File 'lib/google/apis/run_v1/classes.rb', line 5671

def conditions
  @conditions
end

#observed_generationFixnum

ObservedGeneration is the 'Generation' of the Route that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition's status is True or False. Note that providing a TrafficTarget that has latest_revision= True will result in a Route that does not increment either its metadata. generation or its observedGeneration, as new "latest ready" revisions from the Configuration are processed without an update to the Route's spec. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


5682
5683
5684
# File 'lib/google/apis/run_v1/classes.rb', line 5682

def observed_generation
  @observed_generation
end

#trafficArray<Google::Apis::RunV1::TrafficTarget>

Traffic holds the configured traffic distribution. These entries will always contain RevisionName references. When ConfigurationName appears in the spec, this will hold the LatestReadyRevisionName that was last observed. Corresponds to the JSON property traffic



5689
5690
5691
# File 'lib/google/apis/run_v1/classes.rb', line 5689

def traffic
  @traffic
end

#urlString

URL holds the url that will distribute traffic over the provided traffic targets. It generally has the form: https://route-hash-project-hash- cluster-level-suffix.a.run.app Corresponds to the JSON property url

Returns:

  • (String)


5696
5697
5698
# File 'lib/google/apis/run_v1/classes.rb', line 5696

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5703
5704
5705
5706
5707
5708
5709
# File 'lib/google/apis/run_v1/classes.rb', line 5703

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @conditions = args[:conditions] if args.key?(:conditions)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @traffic = args[:traffic] if args.key?(:traffic)
  @url = args[:url] if args.key?(:url)
end