Class: Google::Apis::RunV1::RunJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Request message for creating a new execution of a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunJobRequest

Returns a new instance of RunJobRequest.



5308
5309
5310
# File 'lib/google/apis/run_v1/classes.rb', line 5308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#overridesGoogle::Apis::RunV1::Overrides

RunJob Overrides that contains Execution fields to be overridden on the go. Corresponds to the JSON property overrides



5306
5307
5308
# File 'lib/google/apis/run_v1/classes.rb', line 5306

def overrides
  @overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5313
5314
5315
# File 'lib/google/apis/run_v1/classes.rb', line 5313

def update!(**args)
  @overrides = args[:overrides] if args.key?(:overrides)
end