Class: Google::Apis::RunV1::SecretKeySelector
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::SecretKeySelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
SecretKeySelector selects a key of a Secret.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#local_object_reference ⇒ Google::Apis::RunV1::LocalObjectReference
Not supported by Cloud Run.
-
#name ⇒ String
The name of the secret in Cloud Secret Manager.
-
#optional ⇒ Boolean
(also: #optional?)
Specify whether the Secret or its key must be defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretKeySelector
constructor
A new instance of SecretKeySelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretKeySelector
Returns a new instance of SecretKeySelector.
5799 5800 5801 |
# File 'lib/google/apis/run_v1/classes.rb', line 5799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. A Cloud Secret Manager secret version. Must be 'latest' for the
latest version, an integer for a specific version, or a version alias. The key
of the secret to select from. Must be a valid secret key.
Corresponds to the JSON property key
5775 5776 5777 |
# File 'lib/google/apis/run_v1/classes.rb', line 5775 def key @key end |
#local_object_reference ⇒ Google::Apis::RunV1::LocalObjectReference
Not supported by Cloud Run. LocalObjectReference contains enough information
to let you locate the referenced object inside the same namespace.
Corresponds to the JSON property localObjectReference
5781 5782 5783 |
# File 'lib/google/apis/run_v1/classes.rb', line 5781 def local_object_reference @local_object_reference end |
#name ⇒ String
The name of the secret in Cloud Secret Manager. By default, the secret is
assumed to be in the same project. If the secret is in another project, you
must define an alias. An alias definition has the form: :projects//secrets/.
If multiple alias definitions are needed, they must be separated by commas.
The alias definitions must be set on the run.googleapis.com/secrets annotation.
The name of the secret in the pod's namespace to select from.
Corresponds to the JSON property name
5791 5792 5793 |
# File 'lib/google/apis/run_v1/classes.rb', line 5791 def name @name end |
#optional ⇒ Boolean Also known as: optional?
Specify whether the Secret or its key must be defined.
Corresponds to the JSON property optional
5796 5797 5798 |
# File 'lib/google/apis/run_v1/classes.rb', line 5796 def optional @optional end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5804 5805 5806 5807 5808 5809 |
# File 'lib/google/apis/run_v1/classes.rb', line 5804 def update!(**args) @key = args[:key] if args.key?(:key) @local_object_reference = args[:local_object_reference] if args.key?(:local_object_reference) @name = args[:name] if args.key?(:name) @optional = args[:optional] if args.key?(:optional) end |