Class: Google::Apis::RunV1::SecretKeySelector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

SecretKeySelector selects a key of a Secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretKeySelector

Returns a new instance of SecretKeySelector.



5571
5572
5573
# File 'lib/google/apis/run_v1/classes.rb', line 5571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. A Cloud Secret Manager secret version. Must be 'latest' for the latest version, an integer for a specific version, or a version alias. The key of the secret to select from. Must be a valid secret key. Corresponds to the JSON property key

Returns:

  • (String)


5547
5548
5549
# File 'lib/google/apis/run_v1/classes.rb', line 5547

def key
  @key
end

#local_object_referenceGoogle::Apis::RunV1::LocalObjectReference

Not supported by Cloud Run. LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace. Corresponds to the JSON property localObjectReference



5553
5554
5555
# File 'lib/google/apis/run_v1/classes.rb', line 5553

def local_object_reference
  @local_object_reference
end

#nameString

The name of the secret in Cloud Secret Manager. By default, the secret is assumed to be in the same project. If the secret is in another project, you must define an alias. An alias definition has the form: :projects//secrets/. If multiple alias definitions are needed, they must be separated by commas. The alias definitions must be set on the run.googleapis.com/secrets annotation. The name of the secret in the pod's namespace to select from. Corresponds to the JSON property name

Returns:

  • (String)


5563
5564
5565
# File 'lib/google/apis/run_v1/classes.rb', line 5563

def name
  @name
end

#optionalBoolean Also known as: optional?

Specify whether the Secret or its key must be defined. Corresponds to the JSON property optional

Returns:

  • (Boolean)


5568
5569
5570
# File 'lib/google/apis/run_v1/classes.rb', line 5568

def optional
  @optional
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5576
5577
5578
5579
5580
5581
# File 'lib/google/apis/run_v1/classes.rb', line 5576

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @local_object_reference = args[:local_object_reference] if args.key?(:local_object_reference)
  @name = args[:name] if args.key?(:name)
  @optional = args[:optional] if args.key?(:optional)
end