Class: Google::Apis::RunV1::SecurityContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Not supported by Cloud Run. SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext. When both are set, the values in SecurityContext take precedence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityContext

Returns a new instance of SecurityContext.



5905
5906
5907
# File 'lib/google/apis/run_v1/classes.rb', line 5905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#run_as_userFixnum

The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Corresponds to the JSON property runAsUser

Returns:

  • (Fixnum)


5903
5904
5905
# File 'lib/google/apis/run_v1/classes.rb', line 5903

def run_as_user
  @run_as_user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5910
5911
5912
# File 'lib/google/apis/run_v1/classes.rb', line 5910

def update!(**args)
  @run_as_user = args[:run_as_user] if args.key?(:run_as_user)
end