Class: Google::Apis::RunV1::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Service acts as a top-level container that manages a set of Routes and Configurations which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership. Service acts only as an orchestrator of the underlying Routes and Configurations (much as a kubernetes Deployment orchestrates ReplicaSets). The Service's controller will track the statuses of its owned Configuration and Route, reflecting their statuses and conditions as its own.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



5953
5954
5955
# File 'lib/google/apis/run_v1/classes.rb', line 5953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call. It must be "serving.knative.dev/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


5929
5930
5931
# File 'lib/google/apis/run_v1/classes.rb', line 5929

def api_version
  @api_version
end

#kindString

The kind of resource. It must be "Service". Corresponds to the JSON property kind

Returns:

  • (String)


5934
5935
5936
# File 'lib/google/apis/run_v1/classes.rb', line 5934

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



5940
5941
5942
# File 'lib/google/apis/run_v1/classes.rb', line 5940

def 
  @metadata
end

#specGoogle::Apis::RunV1::ServiceSpec

ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s). Corresponds to the JSON property spec



5946
5947
5948
# File 'lib/google/apis/run_v1/classes.rb', line 5946

def spec
  @spec
end

#statusGoogle::Apis::RunV1::ServiceStatus

The current state of the Service. Output only. Corresponds to the JSON property status



5951
5952
5953
# File 'lib/google/apis/run_v1/classes.rb', line 5951

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5958
5959
5960
5961
5962
5963
5964
# File 'lib/google/apis/run_v1/classes.rb', line 5958

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end