Class: Google::Apis::RunV1::Service
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Service acts as a top-level container that manages a set of Routes and Configurations which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership. Service acts only as an orchestrator of the underlying Routes and Configurations (much as a kubernetes Deployment orchestrates ReplicaSets). The Service's controller will track the statuses of its owned Configuration and Route, reflecting their statuses and conditions as its own.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call.
-
#kind ⇒ String
The kind of resource.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::ServiceSpec
ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s).
-
#status ⇒ Google::Apis::RunV1::ServiceStatus
The current state of the Service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
5937 5938 5939 |
# File 'lib/google/apis/run_v1/classes.rb', line 5937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call. It must be "serving.knative.dev/v1".
Corresponds to the JSON property apiVersion
5913 5914 5915 |
# File 'lib/google/apis/run_v1/classes.rb', line 5913 def api_version @api_version end |
#kind ⇒ String
The kind of resource. It must be "Service".
Corresponds to the JSON property kind
5918 5919 5920 |
# File 'lib/google/apis/run_v1/classes.rb', line 5918 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
5924 5925 5926 |
# File 'lib/google/apis/run_v1/classes.rb', line 5924 def @metadata end |
#spec ⇒ Google::Apis::RunV1::ServiceSpec
ServiceSpec holds the desired state of the Route (from the client), which is
used to manipulate the underlying Route and Configuration(s).
Corresponds to the JSON property spec
5930 5931 5932 |
# File 'lib/google/apis/run_v1/classes.rb', line 5930 def spec @spec end |
#status ⇒ Google::Apis::RunV1::ServiceStatus
The current state of the Service. Output only.
Corresponds to the JSON property status
5935 5936 5937 |
# File 'lib/google/apis/run_v1/classes.rb', line 5935 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/google/apis/run_v1/classes.rb', line 5942 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |