Class: Google::Apis::RunV1::ServiceSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceSpec

Returns a new instance of ServiceSpec.



5555
5556
5557
# File 'lib/google/apis/run_v1/classes.rb', line 5555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#templateGoogle::Apis::RunV1::RevisionTemplate

RevisionTemplateSpec describes the data a revision should have when created from a template. Corresponds to the JSON property template



5547
5548
5549
# File 'lib/google/apis/run_v1/classes.rb', line 5547

def template
  @template
end

#trafficArray<Google::Apis::RunV1::TrafficTarget>

Specifies how to distribute traffic over a collection of Knative Revisions and Configurations to the Service's main URL. Corresponds to the JSON property traffic



5553
5554
5555
# File 'lib/google/apis/run_v1/classes.rb', line 5553

def traffic
  @traffic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5560
5561
5562
5563
# File 'lib/google/apis/run_v1/classes.rb', line 5560

def update!(**args)
  @template = args[:template] if args.key?(:template)
  @traffic = args[:traffic] if args.key?(:traffic)
end