Class: Google::Apis::RunV1::ServiceStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ServiceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The current state of the Service. Output only.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the
specinline with the observed state of the world. -
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this Service's Configuration.
-
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this Service's Configuration that has had its
Readycondition becomeTrue. -
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system.
-
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Holds the configured traffic distribution.
-
#url ⇒ String
URL that will distribute traffic over the provided traffic targets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceStatus
constructor
A new instance of ServiceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceStatus
Returns a new instance of ServiceStatus.
6045 6046 6047 |
# File 'lib/google/apis/run_v1/classes.rb', line 6045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
Corresponds to the JSON property address
6001 6002 6003 |
# File 'lib/google/apis/run_v1/classes.rb', line 6001 def address @address end |
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the spec inline with the observed state of the world.
Service-specific conditions include: * ConfigurationsReady: True when the
underlying Configuration is ready. * RoutesReady: True when the underlying
Route is ready. * Ready: True when all underlying resources are ready.
Corresponds to the JSON property conditions
6010 6011 6012 |
# File 'lib/google/apis/run_v1/classes.rb', line 6010 def conditions @conditions end |
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this Service's Configuration.
It might not be ready yet, for that use LatestReadyRevisionName.
Corresponds to the JSON property latestCreatedRevisionName
6016 6017 6018 |
# File 'lib/google/apis/run_v1/classes.rb', line 6016 def latest_created_revision_name @latest_created_revision_name end |
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this Service's Configuration that has had its
Ready condition become True.
Corresponds to the JSON property latestReadyRevisionName
6022 6023 6024 |
# File 'lib/google/apis/run_v1/classes.rb', line 6022 def latest_ready_revision_name @latest_ready_revision_name end |
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system. Clients polling for completed
reconciliation should poll until observedGeneration = metadata.generation and
the Ready condition's status is True or False.
Corresponds to the JSON property observedGeneration
6029 6030 6031 |
# File 'lib/google/apis/run_v1/classes.rb', line 6029 def observed_generation @observed_generation end |
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Holds the configured traffic distribution. These entries will always contain
RevisionName references. When ConfigurationName appears in the spec, this will
hold the LatestReadyRevisionName that we last observed.
Corresponds to the JSON property traffic
6036 6037 6038 |
# File 'lib/google/apis/run_v1/classes.rb', line 6036 def traffic @traffic end |
#url ⇒ String
URL that will distribute traffic over the provided traffic targets. It
generally has the form https://route-hash-project-hash-cluster-level-
suffix.a.run.app
Corresponds to the JSON property url
6043 6044 6045 |
# File 'lib/google/apis/run_v1/classes.rb', line 6043 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/google/apis/run_v1/classes.rb', line 6050 def update!(**args) @address = args[:address] if args.key?(:address) @conditions = args[:conditions] if args.key?(:conditions) @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name) @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @traffic = args[:traffic] if args.key?(:traffic) @url = args[:url] if args.key?(:url) end |