Class: Google::Apis::RunV1::ServiceStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::ServiceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The current state of the Service. Output only.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the
specinline with the observed state of the world. -
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this Service's Configuration.
-
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this Service's Configuration that has had its
Readycondition becomeTrue. -
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system.
-
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Holds the configured traffic distribution.
-
#url ⇒ String
URL that will distribute traffic over the provided traffic targets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceStatus
constructor
A new instance of ServiceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceStatus
Returns a new instance of ServiceStatus.
5802 5803 5804 |
# File 'lib/google/apis/run_v1/classes.rb', line 5802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::RunV1::Addressable
Information for connecting over HTTP(s).
Corresponds to the JSON property address
5758 5759 5760 |
# File 'lib/google/apis/run_v1/classes.rb', line 5758 def address @address end |
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the spec inline with the observed state of the world.
Service-specific conditions include: * ConfigurationsReady: True when the
underlying Configuration is ready. * RoutesReady: True when the underlying
Route is ready. * Ready: True when all underlying resources are ready.
Corresponds to the JSON property conditions
5767 5768 5769 |
# File 'lib/google/apis/run_v1/classes.rb', line 5767 def conditions @conditions end |
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this Service's Configuration.
It might not be ready yet, for that use LatestReadyRevisionName.
Corresponds to the JSON property latestCreatedRevisionName
5773 5774 5775 |
# File 'lib/google/apis/run_v1/classes.rb', line 5773 def latest_created_revision_name @latest_created_revision_name end |
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this Service's Configuration that has had its
Ready condition become True.
Corresponds to the JSON property latestReadyRevisionName
5779 5780 5781 |
# File 'lib/google/apis/run_v1/classes.rb', line 5779 def latest_ready_revision_name @latest_ready_revision_name end |
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system. Clients polling for completed
reconciliation should poll until observedGeneration = metadata.generation and
the Ready condition's status is True or False.
Corresponds to the JSON property observedGeneration
5786 5787 5788 |
# File 'lib/google/apis/run_v1/classes.rb', line 5786 def observed_generation @observed_generation end |
#traffic ⇒ Array<Google::Apis::RunV1::TrafficTarget>
Holds the configured traffic distribution. These entries will always contain
RevisionName references. When ConfigurationName appears in the spec, this will
hold the LatestReadyRevisionName that we last observed.
Corresponds to the JSON property traffic
5793 5794 5795 |
# File 'lib/google/apis/run_v1/classes.rb', line 5793 def traffic @traffic end |
#url ⇒ String
URL that will distribute traffic over the provided traffic targets. It
generally has the form https://route-hash-project-hash-cluster-level-
suffix.a.run.app
Corresponds to the JSON property url
5800 5801 5802 |
# File 'lib/google/apis/run_v1/classes.rb', line 5800 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5807 5808 5809 5810 5811 5812 5813 5814 5815 |
# File 'lib/google/apis/run_v1/classes.rb', line 5807 def update!(**args) @address = args[:address] if args.key?(:address) @conditions = args[:conditions] if args.key?(:conditions) @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name) @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @traffic = args[:traffic] if args.key?(:traffic) @url = args[:url] if args.key?(:url) end |