Class: Google::Apis::RunV1::Status

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Status is a return value for calls that don't return other objects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Status

Returns a new instance of Status.



5925
5926
5927
# File 'lib/google/apis/run_v1/classes.rb', line 5925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

Suggested HTTP return code for this status, 0 if not set. Corresponds to the JSON property code

Returns:

  • (Fixnum)


5891
5892
5893
# File 'lib/google/apis/run_v1/classes.rb', line 5891

def code
  @code
end

#detailsGoogle::Apis::RunV1::StatusDetails

StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined. Corresponds to the JSON property details



5900
5901
5902
# File 'lib/google/apis/run_v1/classes.rb', line 5900

def details
  @details
end

#messageString

A human-readable description of the status of this operation. Corresponds to the JSON property message

Returns:

  • (String)


5905
5906
5907
# File 'lib/google/apis/run_v1/classes.rb', line 5905

def message
  @message
end

#metadataGoogle::Apis::RunV1::ListMeta

Metadata for synthetic resources like List. In Cloud Run, all List Resources Responses will have a ListMeta instead of ObjectMeta. Corresponds to the JSON property metadata



5911
5912
5913
# File 'lib/google/apis/run_v1/classes.rb', line 5911

def 
  @metadata
end

#reasonString

A machine-readable description of why this operation is in the "Failure" status. If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it. Corresponds to the JSON property reason

Returns:

  • (String)


5918
5919
5920
# File 'lib/google/apis/run_v1/classes.rb', line 5918

def reason
  @reason
end

#statusString

Status of the operation. One of: "Success" or "Failure". Corresponds to the JSON property status

Returns:

  • (String)


5923
5924
5925
# File 'lib/google/apis/run_v1/classes.rb', line 5923

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5930
5931
5932
5933
5934
5935
5936
5937
# File 'lib/google/apis/run_v1/classes.rb', line 5930

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
  @metadata = args[:metadata] if args.key?(:metadata)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
end