Class: Google::Apis::RunV1::StatusDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatusDetails

Returns a new instance of StatusDetails.



6272
6273
6274
# File 'lib/google/apis/run_v1/classes.rb', line 6272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#causesArray<Google::Apis::RunV1::StatusCause>

The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes. Corresponds to the JSON property causes



6240
6241
6242
# File 'lib/google/apis/run_v1/classes.rb', line 6240

def causes
  @causes
end

#groupString

The group attribute of the resource associated with the status StatusReason. Corresponds to the JSON property group

Returns:

  • (String)


6245
6246
6247
# File 'lib/google/apis/run_v1/classes.rb', line 6245

def group
  @group
end

#kindString

The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. Corresponds to the JSON property kind

Returns:

  • (String)


6251
6252
6253
# File 'lib/google/apis/run_v1/classes.rb', line 6251

def kind
  @kind
end

#nameString

The name attribute of the resource associated with the status StatusReason ( when there is a single name which can be described). Corresponds to the JSON property name

Returns:

  • (String)


6257
6258
6259
# File 'lib/google/apis/run_v1/classes.rb', line 6257

def name
  @name
end

#retry_after_secondsFixnum

If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action. Corresponds to the JSON property retryAfterSeconds

Returns:

  • (Fixnum)


6265
6266
6267
# File 'lib/google/apis/run_v1/classes.rb', line 6265

def retry_after_seconds
  @retry_after_seconds
end

#uidString

UID of the resource. (when there is a single resource which can be described). Corresponds to the JSON property uid

Returns:

  • (String)


6270
6271
6272
# File 'lib/google/apis/run_v1/classes.rb', line 6270

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6277
6278
6279
6280
6281
6282
6283
6284
# File 'lib/google/apis/run_v1/classes.rb', line 6277

def update!(**args)
  @causes = args[:causes] if args.key?(:causes)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @retry_after_seconds = args[:retry_after_seconds] if args.key?(:retry_after_seconds)
  @uid = args[:uid] if args.key?(:uid)
end