Class: Google::Apis::RunV1::Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

Task represents a single run of a container to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Task

Returns a new instance of Task.



6345
6346
6347
# File 'lib/google/apis/run_v1/classes.rb', line 6345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. Corresponds to the JSON property apiVersion

Returns:

  • (String)


6320
6321
6322
# File 'lib/google/apis/run_v1/classes.rb', line 6320

def api_version
  @api_version
end

#kindString

Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. Corresponds to the JSON property kind

Returns:

  • (String)


6327
6328
6329
# File 'lib/google/apis/run_v1/classes.rb', line 6327

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



6333
6334
6335
# File 'lib/google/apis/run_v1/classes.rb', line 6333

def 
  @metadata
end

#specGoogle::Apis::RunV1::TaskSpec

TaskSpec is a description of a task. Corresponds to the JSON property spec



6338
6339
6340
# File 'lib/google/apis/run_v1/classes.rb', line 6338

def spec
  @spec
end

#statusGoogle::Apis::RunV1::TaskStatus

TaskStatus represents the status of a task. Corresponds to the JSON property status



6343
6344
6345
# File 'lib/google/apis/run_v1/classes.rb', line 6343

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6350
6351
6352
6353
6354
6355
6356
# File 'lib/google/apis/run_v1/classes.rb', line 6350

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end