Class: Google::Apis::RunV1::Task
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Task represents a single run of a container to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
-
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Task
constructor
A new instance of Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Task
Returns a new instance of Task.
6283 6284 6285 |
# File 'lib/google/apis/run_v1/classes.rb', line 6283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
6258 6259 6260 |
# File 'lib/google/apis/run_v1/classes.rb', line 6258 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
6265 6266 6267 |
# File 'lib/google/apis/run_v1/classes.rb', line 6265 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
6271 6272 6273 |
# File 'lib/google/apis/run_v1/classes.rb', line 6271 def @metadata end |
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
Corresponds to the JSON property spec
6276 6277 6278 |
# File 'lib/google/apis/run_v1/classes.rb', line 6276 def spec @spec end |
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Corresponds to the JSON property status
6281 6282 6283 |
# File 'lib/google/apis/run_v1/classes.rb', line 6281 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6288 6289 6290 6291 6292 6293 6294 |
# File 'lib/google/apis/run_v1/classes.rb', line 6288 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |