Class: Google::Apis::RunV1::Task
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Task represents a single run of a container to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
-
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Task
constructor
A new instance of Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Task
Returns a new instance of Task.
6110 6111 6112 |
# File 'lib/google/apis/run_v1/classes.rb', line 6110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
6085 6086 6087 |
# File 'lib/google/apis/run_v1/classes.rb', line 6085 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
6092 6093 6094 |
# File 'lib/google/apis/run_v1/classes.rb', line 6092 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
6098 6099 6100 |
# File 'lib/google/apis/run_v1/classes.rb', line 6098 def @metadata end |
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
Corresponds to the JSON property spec
6103 6104 6105 |
# File 'lib/google/apis/run_v1/classes.rb', line 6103 def spec @spec end |
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Corresponds to the JSON property status
6108 6109 6110 |
# File 'lib/google/apis/run_v1/classes.rb', line 6108 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6115 6116 6117 6118 6119 6120 6121 |
# File 'lib/google/apis/run_v1/classes.rb', line 6115 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |