Class: Google::Apis::RunV1::Task
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Task represents a single run of a container to completion.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Optional.
-
#kind ⇒ String
Optional.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
-
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Task
constructor
A new instance of Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Task
Returns a new instance of Task.
5899 5900 5901 |
# File 'lib/google/apis/run_v1/classes.rb', line 5899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Optional. APIVersion defines the versioned schema of this representation of an
object. Servers should convert recognized schemas to the latest internal value,
and may reject unrecognized values.
Corresponds to the JSON property apiVersion
5874 5875 5876 |
# File 'lib/google/apis/run_v1/classes.rb', line 5874 def api_version @api_version end |
#kind ⇒ String
Optional. Kind is a string value representing the REST resource this object
represents. Servers may infer this from the endpoint the client submits
requests to. Cannot be updated. In CamelCase.
Corresponds to the JSON property kind
5881 5882 5883 |
# File 'lib/google/apis/run_v1/classes.rb', line 5881 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
5887 5888 5889 |
# File 'lib/google/apis/run_v1/classes.rb', line 5887 def @metadata end |
#spec ⇒ Google::Apis::RunV1::TaskSpec
TaskSpec is a description of a task.
Corresponds to the JSON property spec
5892 5893 5894 |
# File 'lib/google/apis/run_v1/classes.rb', line 5892 def spec @spec end |
#status ⇒ Google::Apis::RunV1::TaskStatus
TaskStatus represents the status of a task.
Corresponds to the JSON property status
5897 5898 5899 |
# File 'lib/google/apis/run_v1/classes.rb', line 5897 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5904 5905 5906 5907 5908 5909 5910 |
# File 'lib/google/apis/run_v1/classes.rb', line 5904 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |