Class: Google::Apis::RunV1::TaskAttemptResult
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::TaskAttemptResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Result of a task attempt.
Instance Attribute Summary collapse
-
#exit_code ⇒ Fixnum
Optional.
-
#status ⇒ Google::Apis::RunV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#term_signal ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskAttemptResult
constructor
A new instance of TaskAttemptResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskAttemptResult
Returns a new instance of TaskAttemptResult.
6381 6382 6383 |
# File 'lib/google/apis/run_v1/classes.rb', line 6381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exit_code ⇒ Fixnum
Optional. The exit code of this attempt. This may be unset if the container
was unable to exit cleanly with a code due to some other failure. See status
field for possible failure details. At most one of exit_code or term_signal
will be set.
Corresponds to the JSON property exitCode
6362 6363 6364 |
# File 'lib/google/apis/run_v1/classes.rb', line 6362 def exit_code @exit_code end |
#status ⇒ Google::Apis::RunV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
6372 6373 6374 |
# File 'lib/google/apis/run_v1/classes.rb', line 6372 def status @status end |
#term_signal ⇒ Fixnum
Optional. Termination signal of the container. This is set to non-zero if the
container is terminated by the system. At most one of exit_code or term_signal
will be set.
Corresponds to the JSON property termSignal
6379 6380 6381 |
# File 'lib/google/apis/run_v1/classes.rb', line 6379 def term_signal @term_signal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6386 6387 6388 6389 6390 |
# File 'lib/google/apis/run_v1/classes.rb', line 6386 def update!(**args) @exit_code = args[:exit_code] if args.key?(:exit_code) @status = args[:status] if args.key?(:status) @term_signal = args[:term_signal] if args.key?(:term_signal) end |