Class: Google::Apis::RunV1::TaskSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::TaskSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
TaskSpec is a description of a task.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::RunV1::Container>
Optional.
-
#max_retries ⇒ Fixnum
Optional.
-
#node_selector ⇒ Hash<String,String>
Optional.
-
#service_account_name ⇒ String
Optional.
-
#timeout_seconds ⇒ Fixnum
Optional.
-
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskSpec
constructor
A new instance of TaskSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskSpec
Returns a new instance of TaskSpec.
5998 5999 6000 |
# File 'lib/google/apis/run_v1/classes.rb', line 5998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::RunV1::Container>
Optional. List of containers belonging to the task. We disallow a number of
fields on this Container.
Corresponds to the JSON property containers
5962 5963 5964 |
# File 'lib/google/apis/run_v1/classes.rb', line 5962 def containers @containers end |
#max_retries ⇒ Fixnum
Optional. Number of retries allowed per task, before marking this job failed.
Defaults to 3.
Corresponds to the JSON property maxRetries
5968 5969 5970 |
# File 'lib/google/apis/run_v1/classes.rb', line 5968 def max_retries @max_retries end |
#node_selector ⇒ Hash<String,String>
Optional. The Node Selector configuration. Map of selector key to a value
which matches a node.
Corresponds to the JSON property nodeSelector
5974 5975 5976 |
# File 'lib/google/apis/run_v1/classes.rb', line 5974 def node_selector @node_selector end |
#service_account_name ⇒ String
Optional. Email address of the IAM service account associated with the task of
a job execution. The service account represents the identity of the running
task, and determines what permissions the task has. If not provided, the task
will use the project's default service account.
Corresponds to the JSON property serviceAccountName
5982 5983 5984 |
# File 'lib/google/apis/run_v1/classes.rb', line 5982 def service_account_name @service_account_name end |
#timeout_seconds ⇒ Fixnum
Optional. Duration in seconds the task may be active before the system will
actively try to mark it failed and kill associated containers. This applies
per attempt of a task, meaning each retry can run for the full timeout.
Defaults to 600 seconds.
Corresponds to the JSON property timeoutSeconds
5990 5991 5992 |
# File 'lib/google/apis/run_v1/classes.rb', line 5990 def timeout_seconds @timeout_seconds end |
#volumes ⇒ Array<Google::Apis::RunV1::Volume>
Optional. List of volumes that can be mounted by containers belonging to the
task.
Corresponds to the JSON property volumes
5996 5997 5998 |
# File 'lib/google/apis/run_v1/classes.rb', line 5996 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6003 6004 6005 6006 6007 6008 6009 6010 |
# File 'lib/google/apis/run_v1/classes.rb', line 6003 def update!(**args) @containers = args[:containers] if args.key?(:containers) @max_retries = args[:max_retries] if args.key?(:max_retries) @node_selector = args[:node_selector] if args.key?(:node_selector) @service_account_name = args[:service_account_name] if args.key?(:service_account_name) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) @volumes = args[:volumes] if args.key?(:volumes) end |