Class: Google::Apis::RunV1::TrafficTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

TrafficTarget holds a single entry of the routing table for a Route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrafficTarget

Returns a new instance of TrafficTarget.



6658
6659
6660
# File 'lib/google/apis/run_v1/classes.rb', line 6658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuration_nameString

[Deprecated] Not supported in Cloud Run. It must be empty. Corresponds to the JSON property configurationName

Returns:

  • (String)


6620
6621
6622
# File 'lib/google/apis/run_v1/classes.rb', line 6620

def configuration_name
  @configuration_name
end

#latest_revisionBoolean Also known as: latest_revision?

Uses the "status.latestReadyRevisionName" of the Service to determine the traffic target. When it changes, traffic will automatically migrate from the prior "latest ready" revision to the new one. This field must be false if RevisionName is set. This field defaults to true otherwise. If the field is set to true on Status, this means that the Revision was resolved from the Service's latest ready revision. Corresponds to the JSON property latestRevision

Returns:

  • (Boolean)


6630
6631
6632
# File 'lib/google/apis/run_v1/classes.rb', line 6630

def latest_revision
  @latest_revision
end

#percentFixnum

Percent specifies percent of the traffic to this Revision or Configuration. This defaults to zero if unspecified. Corresponds to the JSON property percent

Returns:

  • (Fixnum)


6637
6638
6639
# File 'lib/google/apis/run_v1/classes.rb', line 6637

def percent
  @percent
end

#revision_nameString

Points this traffic target to a specific Revision. This field is mutually exclusive with latest_revision. Corresponds to the JSON property revisionName

Returns:

  • (String)


6643
6644
6645
# File 'lib/google/apis/run_v1/classes.rb', line 6643

def revision_name
  @revision_name
end

#tagString

Tag is used to expose a dedicated url for referencing this target exclusively. Corresponds to the JSON property tag

Returns:

  • (String)


6648
6649
6650
# File 'lib/google/apis/run_v1/classes.rb', line 6648

def tag
  @tag
end

#urlString

Output only. URL displays the URL for accessing tagged traffic targets. URL is displayed in status, and is disallowed on spec. URL must contain a scheme (e.g. https://) and a hostname, but may not contain anything else (e.g. basic auth, url path, etc.) Corresponds to the JSON property url

Returns:

  • (String)


6656
6657
6658
# File 'lib/google/apis/run_v1/classes.rb', line 6656

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6663
6664
6665
6666
6667
6668
6669
6670
# File 'lib/google/apis/run_v1/classes.rb', line 6663

def update!(**args)
  @configuration_name = args[:configuration_name] if args.key?(:configuration_name)
  @latest_revision = args[:latest_revision] if args.key?(:latest_revision)
  @percent = args[:percent] if args.key?(:percent)
  @revision_name = args[:revision_name] if args.key?(:revision_name)
  @tag = args[:tag] if args.key?(:tag)
  @url = args[:url] if args.key?(:url)
end