Class: Google::Apis::RunV1::TrafficTarget
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::TrafficTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
TrafficTarget holds a single entry of the routing table for a Route.
Instance Attribute Summary collapse
-
#configuration_name ⇒ String
[Deprecated] Not supported in Cloud Run.
-
#latest_revision ⇒ Boolean
(also: #latest_revision?)
Uses the "status.latestReadyRevisionName" of the Service to determine the traffic target.
-
#percent ⇒ Fixnum
Percent specifies percent of the traffic to this Revision or Configuration.
-
#revision_name ⇒ String
Points this traffic target to a specific Revision.
-
#tag ⇒ String
Tag is used to expose a dedicated url for referencing this target exclusively.
-
#url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrafficTarget
constructor
A new instance of TrafficTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrafficTarget
Returns a new instance of TrafficTarget.
6573 6574 6575 |
# File 'lib/google/apis/run_v1/classes.rb', line 6573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration_name ⇒ String
[Deprecated] Not supported in Cloud Run. It must be empty.
Corresponds to the JSON property configurationName
6535 6536 6537 |
# File 'lib/google/apis/run_v1/classes.rb', line 6535 def configuration_name @configuration_name end |
#latest_revision ⇒ Boolean Also known as: latest_revision?
Uses the "status.latestReadyRevisionName" of the Service to determine the
traffic target. When it changes, traffic will automatically migrate from the
prior "latest ready" revision to the new one. This field must be false if
RevisionName is set. This field defaults to true otherwise. If the field is
set to true on Status, this means that the Revision was resolved from the
Service's latest ready revision.
Corresponds to the JSON property latestRevision
6545 6546 6547 |
# File 'lib/google/apis/run_v1/classes.rb', line 6545 def latest_revision @latest_revision end |
#percent ⇒ Fixnum
Percent specifies percent of the traffic to this Revision or Configuration.
This defaults to zero if unspecified.
Corresponds to the JSON property percent
6552 6553 6554 |
# File 'lib/google/apis/run_v1/classes.rb', line 6552 def percent @percent end |
#revision_name ⇒ String
Points this traffic target to a specific Revision. This field is mutually
exclusive with latest_revision.
Corresponds to the JSON property revisionName
6558 6559 6560 |
# File 'lib/google/apis/run_v1/classes.rb', line 6558 def revision_name @revision_name end |
#tag ⇒ String
Tag is used to expose a dedicated url for referencing this target exclusively.
Corresponds to the JSON property tag
6563 6564 6565 |
# File 'lib/google/apis/run_v1/classes.rb', line 6563 def tag @tag end |
#url ⇒ String
Output only. URL displays the URL for accessing tagged traffic targets. URL is
displayed in status, and is disallowed on spec. URL must contain a scheme (e.g.
https://) and a hostname, but may not contain anything else (e.g. basic auth,
url path, etc.)
Corresponds to the JSON property url
6571 6572 6573 |
# File 'lib/google/apis/run_v1/classes.rb', line 6571 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6578 6579 6580 6581 6582 6583 6584 6585 |
# File 'lib/google/apis/run_v1/classes.rb', line 6578 def update!(**args) @configuration_name = args[:configuration_name] if args.key?(:configuration_name) @latest_revision = args[:latest_revision] if args.key?(:latest_revision) @percent = args[:percent] if args.key?(:percent) @revision_name = args[:revision_name] if args.key?(:revision_name) @tag = args[:tag] if args.key?(:tag) @url = args[:url] if args.key?(:url) end |