Class: Google::Apis::RunV1::Volume
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::Volume
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
Volume represents a named volume in a container.
Instance Attribute Summary collapse
-
#config_map ⇒ Google::Apis::RunV1::ConfigMapVolumeSource
Not supported by Cloud Run.
-
#csi ⇒ Google::Apis::RunV1::CsiVolumeSource
Storage volume source using the Container Storage Interface.
-
#empty_dir ⇒ Google::Apis::RunV1::EmptyDirVolumeSource
In memory (tmpfs) ephemeral storage.
-
#name ⇒ String
Volume's name.
-
#nfs ⇒ Google::Apis::RunV1::NfsVolumeSource
Represents a persistent volume that will be mounted using NFS.
-
#secret ⇒ Google::Apis::RunV1::SecretVolumeSource
A volume representing a secret stored in Google Secret Manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Volume
constructor
A new instance of Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Volume
Returns a new instance of Volume.
6460 6461 6462 |
# File 'lib/google/apis/run_v1/classes.rb', line 6460 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_map ⇒ Google::Apis::RunV1::ConfigMapVolumeSource
Not supported by Cloud Run. Adapts a ConfigMap into a volume. The contents of
the target ConfigMap's Data field will be presented in a volume as files using
the keys in the Data field as the file names, unless the items element is
populated with specific mappings of keys to paths.
Corresponds to the JSON property configMap
6425 6426 6427 |
# File 'lib/google/apis/run_v1/classes.rb', line 6425 def config_map @config_map end |
#csi ⇒ Google::Apis::RunV1::CsiVolumeSource
Storage volume source using the Container Storage Interface.
Corresponds to the JSON property csi
6430 6431 6432 |
# File 'lib/google/apis/run_v1/classes.rb', line 6430 def csi @csi end |
#empty_dir ⇒ Google::Apis::RunV1::EmptyDirVolumeSource
In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when
the sandbox is taken down, the data is destroyed with it (it does not persist
across sandbox runs).
Corresponds to the JSON property emptyDir
6437 6438 6439 |
# File 'lib/google/apis/run_v1/classes.rb', line 6437 def empty_dir @empty_dir end |
#name ⇒ String
Volume's name. In Cloud Run Fully Managed, the name 'cloudsql' is reserved.
Corresponds to the JSON property name
6442 6443 6444 |
# File 'lib/google/apis/run_v1/classes.rb', line 6442 def name @name end |
#nfs ⇒ Google::Apis::RunV1::NfsVolumeSource
Represents a persistent volume that will be mounted using NFS. This volume
will be shared between all instances of the resource and data will not be
deleted when the instance is shut down.
Corresponds to the JSON property nfs
6449 6450 6451 |
# File 'lib/google/apis/run_v1/classes.rb', line 6449 def nfs @nfs end |
#secret ⇒ Google::Apis::RunV1::SecretVolumeSource
A volume representing a secret stored in Google Secret Manager. The secret's
value will be presented as the content of a file whose name is defined in the
item path. If no items are defined, the name of the file is the secret_name.
The contents of the target Secret's Data field will be presented in a volume
as files using the keys in the Data field as the file names.
Corresponds to the JSON property secret
6458 6459 6460 |
# File 'lib/google/apis/run_v1/classes.rb', line 6458 def secret @secret end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/google/apis/run_v1/classes.rb', line 6465 def update!(**args) @config_map = args[:config_map] if args.key?(:config_map) @csi = args[:csi] if args.key?(:csi) @empty_dir = args[:empty_dir] if args.key?(:empty_dir) @name = args[:name] if args.key?(:name) @nfs = args[:nfs] if args.key?(:nfs) @secret = args[:secret] if args.key?(:secret) end |