Class: Google::Apis::RunV1::WorkerPool
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
WorkerPool acts as a top-level container that manages a set instance splits among a set of Revisions and a template for creating new Revisions.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call.
-
#kind ⇒ String
The kind of resource.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and instance splits.
-
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPool
constructor
A new instance of WorkerPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPool
Returns a new instance of WorkerPool.
6777 6778 6779 |
# File 'lib/google/apis/run_v1/classes.rb', line 6777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call. It must be "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
6753 6754 6755 |
# File 'lib/google/apis/run_v1/classes.rb', line 6753 def api_version @api_version end |
#kind ⇒ String
The kind of resource. It must be "WorkerPool".
Corresponds to the JSON property kind
6758 6759 6760 |
# File 'lib/google/apis/run_v1/classes.rb', line 6758 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
6764 6765 6766 |
# File 'lib/google/apis/run_v1/classes.rb', line 6764 def @metadata end |
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and
instance splits.
Corresponds to the JSON property spec
6770 6771 6772 |
# File 'lib/google/apis/run_v1/classes.rb', line 6770 def spec @spec end |
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool. Output only.
Corresponds to the JSON property status
6775 6776 6777 |
# File 'lib/google/apis/run_v1/classes.rb', line 6775 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/google/apis/run_v1/classes.rb', line 6782 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |