Class: Google::Apis::RunV1::WorkerPool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb

Overview

WorkerPool acts as a top-level container that manages a set instance splits among a set of Revisions and a template for creating new Revisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerPool

Returns a new instance of WorkerPool.



6722
6723
6724
# File 'lib/google/apis/run_v1/classes.rb', line 6722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

The API version for this call. It must be "run.googleapis.com/v1". Corresponds to the JSON property apiVersion

Returns:

  • (String)


6698
6699
6700
# File 'lib/google/apis/run_v1/classes.rb', line 6698

def api_version
  @api_version
end

#kindString

The kind of resource. It must be "WorkerPool". Corresponds to the JSON property kind

Returns:

  • (String)


6703
6704
6705
# File 'lib/google/apis/run_v1/classes.rb', line 6703

def kind
  @kind
end

#metadataGoogle::Apis::RunV1::ObjectMeta

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. Corresponds to the JSON property metadata



6709
6710
6711
# File 'lib/google/apis/run_v1/classes.rb', line 6709

def 
  @metadata
end

#specGoogle::Apis::RunV1::WorkerPoolSpec

WorkerPoolSpec holds the desired state of the WorkerPool's template and instance splits. Corresponds to the JSON property spec



6715
6716
6717
# File 'lib/google/apis/run_v1/classes.rb', line 6715

def spec
  @spec
end

#statusGoogle::Apis::RunV1::WorkerPoolStatus

The current state of the WorkerPool. Output only. Corresponds to the JSON property status



6720
6721
6722
# File 'lib/google/apis/run_v1/classes.rb', line 6720

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6727
6728
6729
6730
6731
6732
6733
# File 'lib/google/apis/run_v1/classes.rb', line 6727

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
end