Class: Google::Apis::RunV1::WorkerPool
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
WorkerPool acts as a top-level container that manages a set instance splits among a set of Revisions and a template for creating new Revisions.
Instance Attribute Summary collapse
-
#api_version ⇒ String
The API version for this call.
-
#kind ⇒ String
The kind of resource.
-
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
-
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and instance splits.
-
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPool
constructor
A new instance of WorkerPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPool
Returns a new instance of WorkerPool.
6548 6549 6550 |
# File 'lib/google/apis/run_v1/classes.rb', line 6548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
The API version for this call. It must be "run.googleapis.com/v1".
Corresponds to the JSON property apiVersion
6524 6525 6526 |
# File 'lib/google/apis/run_v1/classes.rb', line 6524 def api_version @api_version end |
#kind ⇒ String
The kind of resource. It must be "WorkerPool".
Corresponds to the JSON property kind
6529 6530 6531 |
# File 'lib/google/apis/run_v1/classes.rb', line 6529 def kind @kind end |
#metadata ⇒ Google::Apis::RunV1::ObjectMeta
google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources
must have, which includes all objects users must create.
Corresponds to the JSON property metadata
6535 6536 6537 |
# File 'lib/google/apis/run_v1/classes.rb', line 6535 def @metadata end |
#spec ⇒ Google::Apis::RunV1::WorkerPoolSpec
WorkerPoolSpec holds the desired state of the WorkerPool's template and
instance splits.
Corresponds to the JSON property spec
6541 6542 6543 |
# File 'lib/google/apis/run_v1/classes.rb', line 6541 def spec @spec end |
#status ⇒ Google::Apis::RunV1::WorkerPoolStatus
The current state of the WorkerPool. Output only.
Corresponds to the JSON property status
6546 6547 6548 |
# File 'lib/google/apis/run_v1/classes.rb', line 6546 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6553 6554 6555 6556 6557 6558 6559 |
# File 'lib/google/apis/run_v1/classes.rb', line 6553 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @spec = args[:spec] if args.key?(:spec) @status = args[:status] if args.key?(:status) end |