Class: Google::Apis::RunV1::WorkerPoolSpec
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPoolSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
WorkerPoolSpec holds the desired state of the WorkerPool's template and instance splits.
Instance Attribute Summary collapse
-
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Specifies how to distribute instances over a collection of Revisions.
-
#template ⇒ Google::Apis::RunV1::RevisionTemplate
RevisionTemplateSpec describes the data a revision should have when created from a template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPoolSpec
constructor
A new instance of WorkerPoolSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPoolSpec
Returns a new instance of WorkerPoolSpec.
6367 6368 6369 |
# File 'lib/google/apis/run_v1/classes.rb', line 6367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Specifies how to distribute instances over a collection of Revisions.
Corresponds to the JSON property instanceSplits
6359 6360 6361 |
# File 'lib/google/apis/run_v1/classes.rb', line 6359 def instance_splits @instance_splits end |
#template ⇒ Google::Apis::RunV1::RevisionTemplate
RevisionTemplateSpec describes the data a revision should have when created
from a template.
Corresponds to the JSON property template
6365 6366 6367 |
# File 'lib/google/apis/run_v1/classes.rb', line 6365 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6372 6373 6374 6375 |
# File 'lib/google/apis/run_v1/classes.rb', line 6372 def update!(**args) @instance_splits = args[:instance_splits] if args.key?(:instance_splits) @template = args[:template] if args.key?(:template) end |