Class: Google::Apis::RunV1::WorkerPoolStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPoolStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The current state of the WorkerPool. Output only.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the
specinline with the observed state of the world. -
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution.
-
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template.
-
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Readycondition becomeTrue. -
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPoolStatus
constructor
A new instance of WorkerPoolStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPoolStatus
Returns a new instance of WorkerPoolStatus.
6884 6885 6886 |
# File 'lib/google/apis/run_v1/classes.rb', line 6884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the spec inline with the observed state of the world. *
Ready: True when all underlying resources are ready.
Corresponds to the JSON property conditions
6856 6857 6858 |
# File 'lib/google/apis/run_v1/classes.rb', line 6856 def conditions @conditions end |
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution. These entries will always contain
RevisionName references. When ConfigurationName appears in the spec, this will
hold the LatestReadyRevisionName that we last observed.
Corresponds to the JSON property instanceSplits
6863 6864 6865 |
# File 'lib/google/apis/run_v1/classes.rb', line 6863 def instance_splits @instance_splits end |
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template. It
might not be ready yet, for that use LatestReadyRevisionName.
Corresponds to the JSON property latestCreatedRevisionName
6869 6870 6871 |
# File 'lib/google/apis/run_v1/classes.rb', line 6869 def latest_created_revision_name @latest_created_revision_name end |
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Ready condition become True.
Corresponds to the JSON property latestReadyRevisionName
6875 6876 6877 |
# File 'lib/google/apis/run_v1/classes.rb', line 6875 def latest_ready_revision_name @latest_ready_revision_name end |
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system. Clients polling for completed
reconciliation should poll until observedGeneration = metadata.generation and
the Ready condition's status is True or False.
Corresponds to the JSON property observedGeneration
6882 6883 6884 |
# File 'lib/google/apis/run_v1/classes.rb', line 6882 def observed_generation @observed_generation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6889 6890 6891 6892 6893 6894 6895 |
# File 'lib/google/apis/run_v1/classes.rb', line 6889 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @instance_splits = args[:instance_splits] if args.key?(:instance_splits) @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name) @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) end |