Class: Google::Apis::RunV1::WorkerPoolStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPoolStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The current state of the WorkerPool. Output only.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the
specinline with the observed state of the world. -
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution.
-
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template.
-
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Readycondition becomeTrue. -
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPoolStatus
constructor
A new instance of WorkerPoolStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPoolStatus
Returns a new instance of WorkerPoolStatus.
6862 6863 6864 |
# File 'lib/google/apis/run_v1/classes.rb', line 6862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the spec inline with the observed state of the world. *
Ready: True when all underlying resources are ready.
Corresponds to the JSON property conditions
6834 6835 6836 |
# File 'lib/google/apis/run_v1/classes.rb', line 6834 def conditions @conditions end |
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution. These entries will always contain
RevisionName references. When ConfigurationName appears in the spec, this will
hold the LatestReadyRevisionName that we last observed.
Corresponds to the JSON property instanceSplits
6841 6842 6843 |
# File 'lib/google/apis/run_v1/classes.rb', line 6841 def instance_splits @instance_splits end |
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template. It
might not be ready yet, for that use LatestReadyRevisionName.
Corresponds to the JSON property latestCreatedRevisionName
6847 6848 6849 |
# File 'lib/google/apis/run_v1/classes.rb', line 6847 def latest_created_revision_name @latest_created_revision_name end |
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Ready condition become True.
Corresponds to the JSON property latestReadyRevisionName
6853 6854 6855 |
# File 'lib/google/apis/run_v1/classes.rb', line 6853 def latest_ready_revision_name @latest_ready_revision_name end |
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system. Clients polling for completed
reconciliation should poll until observedGeneration = metadata.generation and
the Ready condition's status is True or False.
Corresponds to the JSON property observedGeneration
6860 6861 6862 |
# File 'lib/google/apis/run_v1/classes.rb', line 6860 def observed_generation @observed_generation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6867 6868 6869 6870 6871 6872 6873 |
# File 'lib/google/apis/run_v1/classes.rb', line 6867 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @instance_splits = args[:instance_splits] if args.key?(:instance_splits) @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name) @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) end |