Class: Google::Apis::RunV1::WorkerPoolStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV1::WorkerPoolStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v1/classes.rb,
lib/google/apis/run_v1/representations.rb,
lib/google/apis/run_v1/representations.rb
Overview
The current state of the WorkerPool. Output only.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation processes that bring the
specinline with the observed state of the world. -
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution.
-
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template.
-
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Readycondition becomeTrue. -
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerPoolStatus
constructor
A new instance of WorkerPoolStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerPoolStatus
Returns a new instance of WorkerPoolStatus.
6626 6627 6628 |
# File 'lib/google/apis/run_v1/classes.rb', line 6626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::RunV1::GoogleCloudRunV1Condition>
Conditions communicate information about ongoing/complete reconciliation
processes that bring the spec inline with the observed state of the world. *
Ready: True when all underlying resources are ready.
Corresponds to the JSON property conditions
6598 6599 6600 |
# File 'lib/google/apis/run_v1/classes.rb', line 6598 def conditions @conditions end |
#instance_splits ⇒ Array<Google::Apis::RunV1::InstanceSplit>
Holds the configured workload distribution. These entries will always contain
RevisionName references. When ConfigurationName appears in the spec, this will
hold the LatestReadyRevisionName that we last observed.
Corresponds to the JSON property instanceSplits
6605 6606 6607 |
# File 'lib/google/apis/run_v1/classes.rb', line 6605 def instance_splits @instance_splits end |
#latest_created_revision_name ⇒ String
Name of the last revision that was created from this WorkerPool's template. It
might not be ready yet, for that use LatestReadyRevisionName.
Corresponds to the JSON property latestCreatedRevisionName
6611 6612 6613 |
# File 'lib/google/apis/run_v1/classes.rb', line 6611 def latest_created_revision_name @latest_created_revision_name end |
#latest_ready_revision_name ⇒ String
Name of the latest Revision from this WorkerPool's template that has had its
Ready condition become True.
Corresponds to the JSON property latestReadyRevisionName
6617 6618 6619 |
# File 'lib/google/apis/run_v1/classes.rb', line 6617 def latest_ready_revision_name @latest_ready_revision_name end |
#observed_generation ⇒ Fixnum
Returns the generation last seen by the system. Clients polling for completed
reconciliation should poll until observedGeneration = metadata.generation and
the Ready condition's status is True or False.
Corresponds to the JSON property observedGeneration
6624 6625 6626 |
# File 'lib/google/apis/run_v1/classes.rb', line 6624 def observed_generation @observed_generation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/google/apis/run_v1/classes.rb', line 6631 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @instance_splits = args[:instance_splits] if args.key?(:instance_splits) @latest_created_revision_name = args[:latest_created_revision_name] if args.key?(:latest_created_revision_name) @latest_ready_revision_name = args[:latest_ready_revision_name] if args.key?(:latest_ready_revision_name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) end |